<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'fóon: nit, nit, xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'fóon: nit, nit, xeesaayu der bu woyof, xeesaayu der bu yam',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'fóon: nit, nit, xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'fóon: nit, nit, xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'fóon: nit, nit, xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'fóon: nit, nit, xeesaayu der bu xeereer, xeesaayu der bu yam',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'fóon: nit, nit, xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'fóon: nit, nit, xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'fóon: nit, nit, xeesaayu der bu yam, xeesaayu der bu woyof',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'fóon: nit, nit, xeesaayu der bu yam, xeesaayu der bu xeereer',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'fóon: nit, nit, xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'fóon: nit, nit, xeesaayu der bu yam, xeesaayu der bu ñuul',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'fóon: nit, nit, xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'fóon: nit, nit, xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'fóon: nit, nit, xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'fóon: nit, nit, xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'fóon: nit, nit, xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'fóon: nit, nit, xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'fóon: nit, nit, xeesaayu der bu ñuul, xeesaayu der bu yam',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'fóon: nit, nit, xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '👨🏻‍❤‍💋‍👨🏻' => 'fóon: góor, góor, xeesaayu der bu woyof',
    '👨🏻‍❤‍💋‍👨🏼' => 'fóon: góor, góor, xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '👨🏻‍❤‍💋‍👨🏽' => 'fóon: góor, góor, xeesaayu der bu woyof, xeesaayu der bu yam',
    '👨🏻‍❤‍💋‍👨🏾' => 'fóon: góor, góor, xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '👨🏻‍❤‍💋‍👨🏿' => 'fóon: góor, góor, xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '👨🏼‍❤‍💋‍👨🏻' => 'fóon: góor, góor, xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '👨🏼‍❤‍💋‍👨🏼' => 'fóon: góor, góor, xeesaayu der bu xeereer',
    '👨🏼‍❤‍💋‍👨🏽' => 'fóon: góor, góor, xeesaayu der bu xeereer, xeesaayu der bu yam',
    '👨🏼‍❤‍💋‍👨🏾' => 'fóon: góor, góor, xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '👨🏼‍❤‍💋‍👨🏿' => 'fóon: góor, góor, xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '👨🏽‍❤‍💋‍👨🏻' => 'fóon: góor, góor, xeesaayu der bu yam, xeesaayu der bu woyof',
    '👨🏽‍❤‍💋‍👨🏼' => 'fóon: góor, góor, xeesaayu der bu yam, xeesaayu der bu xeereer',
    '👨🏽‍❤‍💋‍👨🏽' => 'fóon: góor, góor, xeesaayu der bu yam',
    '👨🏽‍❤‍💋‍👨🏾' => 'fóon: góor, góor, xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '👨🏽‍❤‍💋‍👨🏿' => 'fóon: góor, góor, xeesaayu der bu yam, xeesaayu der bu ñuul',
    '👨🏾‍❤‍💋‍👨🏻' => 'fóon: góor, góor, xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '👨🏾‍❤‍💋‍👨🏼' => 'fóon: góor, góor, xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '👨🏾‍❤‍💋‍👨🏽' => 'fóon: góor, góor, xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '👨🏾‍❤‍💋‍👨🏾' => 'fóon: góor, góor, xeesaayu der bu xawa ñuul',
    '👨🏾‍❤‍💋‍👨🏿' => 'fóon: góor, góor, xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '👨🏿‍❤‍💋‍👨🏻' => 'fóon: góor, góor, xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '👨🏿‍❤‍💋‍👨🏼' => 'fóon: góor, góor, xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '👨🏿‍❤‍💋‍👨🏽' => 'fóon: góor, góor, xeesaayu der bu ñuul, xeesaayu der bu yam',
    '👨🏿‍❤‍💋‍👨🏾' => 'fóon: góor, góor, xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '👨🏿‍❤‍💋‍👨🏿' => 'fóon: góor, góor, xeesaayu der bu ñuul',
    '👩🏻‍❤‍💋‍👨🏻' => 'fóon: jigéen, góor, xeesaayu der bu woyof',
    '👩🏻‍❤‍💋‍👨🏼' => 'fóon: jigéen, góor, xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '👩🏻‍❤‍💋‍👨🏽' => 'fóon: jigéen, góor, xeesaayu der bu woyof, xeesaayu der bu yam',
    '👩🏻‍❤‍💋‍👨🏾' => 'fóon: jigéen, góor, xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '👩🏻‍❤‍💋‍👨🏿' => 'fóon: jigéen, góor, xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '👩🏼‍❤‍💋‍👨🏻' => 'fóon: jigéen, góor, xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '👩🏼‍❤‍💋‍👨🏼' => 'fóon: jigéen, góor, xeesaayu der bu xeereer',
    '👩🏼‍❤‍💋‍👨🏽' => 'fóon: jigéen, góor, xeesaayu der bu xeereer, xeesaayu der bu yam',
    '👩🏼‍❤‍💋‍👨🏾' => 'fóon: jigéen, góor, xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '👩🏼‍❤‍💋‍👨🏿' => 'fóon: jigéen, góor, xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '👩🏽‍❤‍💋‍👨🏻' => 'fóon: jigéen, góor, xeesaayu der bu yam, xeesaayu der bu woyof',
    '👩🏽‍❤‍💋‍👨🏼' => 'fóon: jigéen, góor, xeesaayu der bu yam, xeesaayu der bu xeereer',
    '👩🏽‍❤‍💋‍👨🏽' => 'fóon: jigéen, góor, xeesaayu der bu yam',
    '👩🏽‍❤‍💋‍👨🏾' => 'fóon: jigéen, góor, xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '👩🏽‍❤‍💋‍👨🏿' => 'fóon: jigéen, góor, xeesaayu der bu yam, xeesaayu der bu ñuul',
    '👩🏾‍❤‍💋‍👨🏻' => 'fóon: jigéen, góor, xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '👩🏾‍❤‍💋‍👨🏼' => 'fóon: jigéen, góor, xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '👩🏾‍❤‍💋‍👨🏽' => 'fóon: jigéen, góor, xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '👩🏾‍❤‍💋‍👨🏾' => 'fóon: jigéen, góor, xeesaayu der bu xawa ñuul',
    '👩🏾‍❤‍💋‍👨🏿' => 'fóon: jigéen, góor, xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '👩🏿‍❤‍💋‍👨🏻' => 'fóon: jigéen, góor, xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '👩🏿‍❤‍💋‍👨🏼' => 'fóon: jigéen, góor, xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '👩🏿‍❤‍💋‍👨🏽' => 'fóon: jigéen, góor, xeesaayu der bu ñuul, xeesaayu der bu yam',
    '👩🏿‍❤‍💋‍👨🏾' => 'fóon: jigéen, góor, xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '👩🏿‍❤‍💋‍👨🏿' => 'fóon: jigéen, góor, xeesaayu der bu ñuul',
    '👩🏻‍❤‍💋‍👩🏻' => 'fóon: jigéen, jigéen, xeesaayu der bu woyof',
    '👩🏻‍❤‍💋‍👩🏼' => 'fóon: jigéen, jigéen, xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '👩🏻‍❤‍💋‍👩🏽' => 'fóon: jigéen, jigéen, xeesaayu der bu woyof, xeesaayu der bu yam',
    '👩🏻‍❤‍💋‍👩🏾' => 'fóon: jigéen, jigéen, xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '👩🏻‍❤‍💋‍👩🏿' => 'fóon: jigéen, jigéen, xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '👩🏼‍❤‍💋‍👩🏻' => 'fóon: jigéen, jigéen, xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '👩🏼‍❤‍💋‍👩🏼' => 'fóon: jigéen, jigéen, xeesaayu der bu xeereer',
    '👩🏼‍❤‍💋‍👩🏽' => 'fóon: jigéen, jigéen, xeesaayu der bu xeereer, xeesaayu der bu yam',
    '👩🏼‍❤‍💋‍👩🏾' => 'fóon: jigéen, jigéen, xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '👩🏼‍❤‍💋‍👩🏿' => 'fóon: jigéen, jigéen, xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '👩🏽‍❤‍💋‍👩🏻' => 'fóon: jigéen, jigéen, xeesaayu der bu yam, xeesaayu der bu woyof',
    '👩🏽‍❤‍💋‍👩🏼' => 'fóon: jigéen, jigéen, xeesaayu der bu yam, xeesaayu der bu xeereer',
    '👩🏽‍❤‍💋‍👩🏽' => 'fóon: jigéen, jigéen, xeesaayu der bu yam',
    '👩🏽‍❤‍💋‍👩🏾' => 'fóon: jigéen, jigéen, xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '👩🏽‍❤‍💋‍👩🏿' => 'fóon: jigéen, jigéen, xeesaayu der bu yam, xeesaayu der bu ñuul',
    '👩🏾‍❤‍💋‍👩🏻' => 'fóon: jigéen, jigéen, xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '👩🏾‍❤‍💋‍👩🏼' => 'fóon: jigéen, jigéen, xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '👩🏾‍❤‍💋‍👩🏽' => 'fóon: jigéen, jigéen, xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '👩🏾‍❤‍💋‍👩🏾' => 'fóon: jigéen, jigéen, xeesaayu der bu xawa ñuul',
    '👩🏾‍❤‍💋‍👩🏿' => 'fóon: jigéen, jigéen, xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '👩🏿‍❤‍💋‍👩🏻' => 'fóon: jigéen, jigéen, xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '👩🏿‍❤‍💋‍👩🏼' => 'fóon: jigéen, jigéen, xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '👩🏿‍❤‍💋‍👩🏽' => 'fóon: jigéen, jigéen, xeesaayu der bu ñuul, xeesaayu der bu yam',
    '👩🏿‍❤‍💋‍👩🏾' => 'fóon: jigéen, jigéen, xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '👩🏿‍❤‍💋‍👩🏿' => 'fóon: jigéen, jigéen, xeesaayu der bu ñuul',
    '🧑🏻‍🫯‍🧑🏼' => 'nit ñuy bëre: xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '🧑🏻‍🫯‍🧑🏽' => 'nit ñuy bëre: xeesaayu der bu woyof, xeesaayu der bu yam',
    '🧑🏻‍🫯‍🧑🏾' => 'nit ñuy bëre: xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '🧑🏻‍🫯‍🧑🏿' => 'nit ñuy bëre: xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '🧑🏼‍🫯‍🧑🏻' => 'nit ñuy bëre: xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '🧑🏼‍🫯‍🧑🏽' => 'nit ñuy bëre: xeesaayu der bu xeereer, xeesaayu der bu yam',
    '🧑🏼‍🫯‍🧑🏾' => 'nit ñuy bëre: xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '🧑🏼‍🫯‍🧑🏿' => 'nit ñuy bëre: xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '🧑🏽‍🫯‍🧑🏻' => 'nit ñuy bëre: xeesaayu der bu yam, xeesaayu der bu woyof',
    '🧑🏽‍🫯‍🧑🏼' => 'nit ñuy bëre: xeesaayu der bu yam, xeesaayu der bu xeereer',
    '🧑🏽‍🫯‍🧑🏾' => 'nit ñuy bëre: xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '🧑🏽‍🫯‍🧑🏿' => 'nit ñuy bëre: xeesaayu der bu yam, xeesaayu der bu ñuul',
    '🧑🏾‍🫯‍🧑🏻' => 'nit ñuy bëre: xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '🧑🏾‍🫯‍🧑🏼' => 'nit ñuy bëre: xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '🧑🏾‍🫯‍🧑🏽' => 'nit ñuy bëre: xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '🧑🏾‍🫯‍🧑🏿' => 'nit ñuy bëre: xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '🧑🏿‍🫯‍🧑🏻' => 'nit ñuy bëre: xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '🧑🏿‍🫯‍🧑🏼' => 'nit ñuy bëre: xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '🧑🏿‍🫯‍🧑🏽' => 'nit ñuy bëre: xeesaayu der bu ñuul, xeesaayu der bu yam',
    '🧑🏿‍🫯‍🧑🏾' => 'nit ñuy bëre: xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '🧑🏻‍❤‍🧑🏼' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '🧑🏻‍❤‍🧑🏽' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu woyof, xeesaayu der bu yam',
    '🧑🏻‍❤‍🧑🏾' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '🧑🏻‍❤‍🧑🏿' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '🧑🏼‍❤‍🧑🏻' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '🧑🏼‍❤‍🧑🏽' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu xeereer, xeesaayu der bu yam',
    '🧑🏼‍❤‍🧑🏾' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '🧑🏼‍❤‍🧑🏿' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '🧑🏽‍❤‍🧑🏻' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu yam, xeesaayu der bu woyof',
    '🧑🏽‍❤‍🧑🏼' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu yam, xeesaayu der bu xeereer',
    '🧑🏽‍❤‍🧑🏾' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '🧑🏽‍❤‍🧑🏿' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu yam, xeesaayu der bu ñuul',
    '🧑🏾‍❤‍🧑🏻' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '🧑🏾‍❤‍🧑🏼' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '🧑🏾‍❤‍🧑🏽' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '🧑🏾‍❤‍🧑🏿' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '🧑🏿‍❤‍🧑🏻' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '🧑🏿‍❤‍🧑🏼' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '🧑🏿‍❤‍🧑🏽' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu ñuul, xeesaayu der bu yam',
    '🧑🏿‍❤‍🧑🏾' => 'xol ak ñaar ñu bëggante: nit, nit, xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '🧑🏻‍🐰‍🧑🏼' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '🧑🏻‍🐰‍🧑🏽' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu woyof, xeesaayu der bu yam',
    '🧑🏻‍🐰‍🧑🏾' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '🧑🏻‍🐰‍🧑🏿' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '🧑🏼‍🐰‍🧑🏻' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '🧑🏼‍🐰‍🧑🏽' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu xeereer, xeesaayu der bu yam',
    '🧑🏼‍🐰‍🧑🏾' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '🧑🏼‍🐰‍🧑🏿' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '🧑🏽‍🐰‍🧑🏻' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu yam, xeesaayu der bu woyof',
    '🧑🏽‍🐰‍🧑🏼' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu yam, xeesaayu der bu xeereer',
    '🧑🏽‍🐰‍🧑🏾' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '🧑🏽‍🐰‍🧑🏿' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu yam, xeesaayu der bu ñuul',
    '🧑🏾‍🐰‍🧑🏻' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '🧑🏾‍🐰‍🧑🏼' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '🧑🏾‍🐰‍🧑🏽' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '🧑🏾‍🐰‍🧑🏿' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '🧑🏿‍🐰‍🧑🏻' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '🧑🏿‍🐰‍🧑🏼' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '🧑🏿‍🐰‍🧑🏽' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu ñuul, xeesaayu der bu yam',
    '🧑🏿‍🐰‍🧑🏾' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '👨🏻‍🫯‍👨🏼' => 'góor guy bëre: xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '👨🏻‍🫯‍👨🏽' => 'góor guy bëre: xeesaayu der bu woyof, xeesaayu der bu yam',
    '👨🏻‍🫯‍👨🏾' => 'góor guy bëre: xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '👨🏻‍🫯‍👨🏿' => 'góor guy bëre: xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '👨🏼‍🫯‍👨🏻' => 'góor guy bëre: xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '👨🏼‍🫯‍👨🏽' => 'góor guy bëre: xeesaayu der bu xeereer, xeesaayu der bu yam',
    '👨🏼‍🫯‍👨🏾' => 'góor guy bëre: xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '👨🏼‍🫯‍👨🏿' => 'góor guy bëre: xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '👨🏽‍🫯‍👨🏻' => 'góor guy bëre: xeesaayu der bu yam, xeesaayu der bu woyof',
    '👨🏽‍🫯‍👨🏼' => 'góor guy bëre: xeesaayu der bu yam, xeesaayu der bu xeereer',
    '👨🏽‍🫯‍👨🏾' => 'góor guy bëre: xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '👨🏽‍🫯‍👨🏿' => 'góor guy bëre: xeesaayu der bu yam, xeesaayu der bu ñuul',
    '👨🏾‍🫯‍👨🏻' => 'góor guy bëre: xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '👨🏾‍🫯‍👨🏼' => 'góor guy bëre: xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '👨🏾‍🫯‍👨🏽' => 'góor guy bëre: xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '👨🏾‍🫯‍👨🏿' => 'góor guy bëre: xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '👨🏿‍🫯‍👨🏻' => 'góor guy bëre: xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '👨🏿‍🫯‍👨🏼' => 'góor guy bëre: xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '👨🏿‍🫯‍👨🏽' => 'góor guy bëre: xeesaayu der bu ñuul, xeesaayu der bu yam',
    '👨🏿‍🫯‍👨🏾' => 'góor guy bëre: xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '👨🏻‍❤‍👨🏻' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu woyof',
    '👨🏻‍❤‍👨🏼' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '👨🏻‍❤‍👨🏽' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu woyof, xeesaayu der bu yam',
    '👨🏻‍❤‍👨🏾' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '👨🏻‍❤‍👨🏿' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '👨🏼‍❤‍👨🏻' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '👨🏼‍❤‍👨🏼' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu xeereer',
    '👨🏼‍❤‍👨🏽' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu xeereer, xeesaayu der bu yam',
    '👨🏼‍❤‍👨🏾' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '👨🏼‍❤‍👨🏿' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '👨🏽‍❤‍👨🏻' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu yam, xeesaayu der bu woyof',
    '👨🏽‍❤‍👨🏼' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu yam, xeesaayu der bu xeereer',
    '👨🏽‍❤‍👨🏽' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu yam',
    '👨🏽‍❤‍👨🏾' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '👨🏽‍❤‍👨🏿' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu yam, xeesaayu der bu ñuul',
    '👨🏾‍❤‍👨🏻' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '👨🏾‍❤‍👨🏼' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '👨🏾‍❤‍👨🏽' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '👨🏾‍❤‍👨🏾' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu xawa ñuul',
    '👨🏾‍❤‍👨🏿' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '👨🏿‍❤‍👨🏻' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '👨🏿‍❤‍👨🏼' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '👨🏿‍❤‍👨🏽' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu ñuul, xeesaayu der bu yam',
    '👨🏿‍❤‍👨🏾' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '👨🏿‍❤‍👨🏿' => 'xol ak ñaar ñu bëggante: góor, góor, xeesaayu der bu ñuul',
    '👨🏻‍🐰‍👨🏼' => 'góorak noppi lëks suwaare: xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '👨🏻‍🐰‍👨🏽' => 'góorak noppi lëks suwaare: xeesaayu der bu woyof, xeesaayu der bu yam',
    '👨🏻‍🐰‍👨🏾' => 'góorak noppi lëks suwaare: xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '👨🏻‍🐰‍👨🏿' => 'góorak noppi lëks suwaare: xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '👨🏼‍🐰‍👨🏻' => 'góorak noppi lëks suwaare: xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '👨🏼‍🐰‍👨🏽' => 'góorak noppi lëks suwaare: xeesaayu der bu xeereer, xeesaayu der bu yam',
    '👨🏼‍🐰‍👨🏾' => 'góorak noppi lëks suwaare: xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '👨🏼‍🐰‍👨🏿' => 'góorak noppi lëks suwaare: xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '👨🏽‍🐰‍👨🏻' => 'góorak noppi lëks suwaare: xeesaayu der bu yam, xeesaayu der bu woyof',
    '👨🏽‍🐰‍👨🏼' => 'góorak noppi lëks suwaare: xeesaayu der bu yam, xeesaayu der bu xeereer',
    '👨🏽‍🐰‍👨🏾' => 'góorak noppi lëks suwaare: xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '👨🏽‍🐰‍👨🏿' => 'góorak noppi lëks suwaare: xeesaayu der bu yam, xeesaayu der bu ñuul',
    '👨🏾‍🐰‍👨🏻' => 'góorak noppi lëks suwaare: xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '👨🏾‍🐰‍👨🏼' => 'góorak noppi lëks suwaare: xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '👨🏾‍🐰‍👨🏽' => 'góorak noppi lëks suwaare: xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '👨🏾‍🐰‍👨🏿' => 'góorak noppi lëks suwaare: xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '👨🏿‍🐰‍👨🏻' => 'góorak noppi lëks suwaare: xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '👨🏿‍🐰‍👨🏼' => 'góorak noppi lëks suwaare: xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '👨🏿‍🐰‍👨🏽' => 'góorak noppi lëks suwaare: xeesaayu der bu ñuul, xeesaayu der bu yam',
    '👨🏿‍🐰‍👨🏾' => 'góorak noppi lëks suwaare: xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '👩🏻‍🫯‍👩🏼' => 'jigéen juy bëre: xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '👩🏻‍🫯‍👩🏽' => 'jigéen juy bëre: xeesaayu der bu woyof, xeesaayu der bu yam',
    '👩🏻‍🫯‍👩🏾' => 'jigéen juy bëre: xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '👩🏻‍🫯‍👩🏿' => 'jigéen juy bëre: xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '👩🏼‍🫯‍👩🏻' => 'jigéen juy bëre: xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '👩🏼‍🫯‍👩🏽' => 'jigéen juy bëre: xeesaayu der bu xeereer, xeesaayu der bu yam',
    '👩🏼‍🫯‍👩🏾' => 'jigéen juy bëre: xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '👩🏼‍🫯‍👩🏿' => 'jigéen juy bëre: xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '👩🏽‍🫯‍👩🏻' => 'jigéen juy bëre: xeesaayu der bu yam, xeesaayu der bu woyof',
    '👩🏽‍🫯‍👩🏼' => 'jigéen juy bëre: xeesaayu der bu yam, xeesaayu der bu xeereer',
    '👩🏽‍🫯‍👩🏾' => 'jigéen juy bëre: xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '👩🏽‍🫯‍👩🏿' => 'jigéen juy bëre: xeesaayu der bu yam, xeesaayu der bu ñuul',
    '👩🏾‍🫯‍👩🏻' => 'jigéen juy bëre: xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '👩🏾‍🫯‍👩🏼' => 'jigéen juy bëre: xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '👩🏾‍🫯‍👩🏽' => 'jigéen juy bëre: xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '👩🏾‍🫯‍👩🏿' => 'jigéen juy bëre: xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '👩🏿‍🫯‍👩🏻' => 'jigéen juy bëre: xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '👩🏿‍🫯‍👩🏼' => 'jigéen juy bëre: xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '👩🏿‍🫯‍👩🏽' => 'jigéen juy bëre: xeesaayu der bu ñuul, xeesaayu der bu yam',
    '👩🏿‍🫯‍👩🏾' => 'jigéen juy bëre: xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '👩🏻‍❤‍👨🏻' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu woyof',
    '👩🏻‍❤‍👨🏼' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '👩🏻‍❤‍👨🏽' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu woyof, xeesaayu der bu yam',
    '👩🏻‍❤‍👨🏾' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '👩🏻‍❤‍👨🏿' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '👩🏼‍❤‍👨🏻' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '👩🏼‍❤‍👨🏼' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu xeereer',
    '👩🏼‍❤‍👨🏽' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu xeereer, xeesaayu der bu yam',
    '👩🏼‍❤‍👨🏾' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '👩🏼‍❤‍👨🏿' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '👩🏽‍❤‍👨🏻' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu yam, xeesaayu der bu woyof',
    '👩🏽‍❤‍👨🏼' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu yam, xeesaayu der bu xeereer',
    '👩🏽‍❤‍👨🏽' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu yam',
    '👩🏽‍❤‍👨🏾' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '👩🏽‍❤‍👨🏿' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu yam, xeesaayu der bu ñuul',
    '👩🏾‍❤‍👨🏻' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '👩🏾‍❤‍👨🏼' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '👩🏾‍❤‍👨🏽' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '👩🏾‍❤‍👨🏾' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu xawa ñuul',
    '👩🏾‍❤‍👨🏿' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '👩🏿‍❤‍👨🏻' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '👩🏿‍❤‍👨🏼' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '👩🏿‍❤‍👨🏽' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu ñuul, xeesaayu der bu yam',
    '👩🏿‍❤‍👨🏾' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '👩🏿‍❤‍👨🏿' => 'xol ak ñaar ñu bëggante: jigéen, góor, xeesaayu der bu ñuul',
    '👩🏻‍❤‍👩🏻' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu woyof',
    '👩🏻‍❤‍👩🏼' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '👩🏻‍❤‍👩🏽' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu woyof, xeesaayu der bu yam',
    '👩🏻‍❤‍👩🏾' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '👩🏻‍❤‍👩🏿' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '👩🏼‍❤‍👩🏻' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '👩🏼‍❤‍👩🏼' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu xeereer',
    '👩🏼‍❤‍👩🏽' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu xeereer, xeesaayu der bu yam',
    '👩🏼‍❤‍👩🏾' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '👩🏼‍❤‍👩🏿' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '👩🏽‍❤‍👩🏻' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu yam, xeesaayu der bu woyof',
    '👩🏽‍❤‍👩🏼' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu yam, xeesaayu der bu xeereer',
    '👩🏽‍❤‍👩🏽' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu yam',
    '👩🏽‍❤‍👩🏾' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '👩🏽‍❤‍👩🏿' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu yam, xeesaayu der bu ñuul',
    '👩🏾‍❤‍👩🏻' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '👩🏾‍❤‍👩🏼' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '👩🏾‍❤‍👩🏽' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '👩🏾‍❤‍👩🏾' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu xawa ñuul',
    '👩🏾‍❤‍👩🏿' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '👩🏿‍❤‍👩🏻' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '👩🏿‍❤‍👩🏼' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '👩🏿‍❤‍👩🏽' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu ñuul, xeesaayu der bu yam',
    '👩🏿‍❤‍👩🏾' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '👩🏿‍❤‍👩🏿' => 'xol ak ñaar ñu bëggante: jigéen, jigéen, xeesaayu der bu ñuul',
    '👩🏻‍🐰‍👩🏼' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '👩🏻‍🐰‍👩🏽' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu woyof, xeesaayu der bu yam',
    '👩🏻‍🐰‍👩🏾' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '👩🏻‍🐰‍👩🏿' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '👩🏼‍🐰‍👩🏻' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '👩🏼‍🐰‍👩🏽' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu xeereer, xeesaayu der bu yam',
    '👩🏼‍🐰‍👩🏾' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '👩🏼‍🐰‍👩🏿' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '👩🏽‍🐰‍👩🏻' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu yam, xeesaayu der bu woyof',
    '👩🏽‍🐰‍👩🏼' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu yam, xeesaayu der bu xeereer',
    '👩🏽‍🐰‍👩🏾' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '👩🏽‍🐰‍👩🏿' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu yam, xeesaayu der bu ñuul',
    '👩🏾‍🐰‍👩🏻' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '👩🏾‍🐰‍👩🏼' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '👩🏾‍🐰‍👩🏽' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '👩🏾‍🐰‍👩🏿' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '👩🏿‍🐰‍👩🏻' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '👩🏿‍🐰‍👩🏼' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '👩🏿‍🐰‍👩🏽' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu ñuul, xeesaayu der bu yam',
    '👩🏿‍🐰‍👩🏾' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '👩🏻‍🤝‍👩🏼' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '👩🏻‍🤝‍👩🏽' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu woyof, xeesaayu der bu yam',
    '👩🏻‍🤝‍👩🏾' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '👩🏻‍🤝‍👩🏿' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '👩🏼‍🤝‍👩🏻' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '👩🏼‍🤝‍👩🏽' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu xeereer, xeesaayu der bu yam',
    '👩🏼‍🤝‍👩🏾' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '👩🏼‍🤝‍👩🏿' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '👩🏽‍🤝‍👩🏻' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu yam, xeesaayu der bu woyof',
    '👩🏽‍🤝‍👩🏼' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu yam, xeesaayu der bu xeereer',
    '👩🏽‍🤝‍👩🏾' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '👩🏽‍🤝‍👩🏿' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu yam, xeesaayu der bu ñuul',
    '👩🏾‍🤝‍👩🏻' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '👩🏾‍🤝‍👩🏼' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '👩🏾‍🤝‍👩🏽' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '👩🏾‍🤝‍👩🏿' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '👩🏿‍🤝‍👩🏻' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '👩🏿‍🤝‍👩🏼' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '👩🏿‍🤝‍👩🏽' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu ñuul, xeesaayu der bu yam',
    '👩🏿‍🤝‍👩🏾' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '👩🏻‍🤝‍👨🏼' => 'góor ak jigéen jàppante loxo: xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '👩🏻‍🤝‍👨🏽' => 'góor ak jigéen jàppante loxo: xeesaayu der bu woyof, xeesaayu der bu yam',
    '👩🏻‍🤝‍👨🏾' => 'góor ak jigéen jàppante loxo: xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '👩🏻‍🤝‍👨🏿' => 'góor ak jigéen jàppante loxo: xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '👩🏼‍🤝‍👨🏻' => 'góor ak jigéen jàppante loxo: xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '👩🏼‍🤝‍👨🏽' => 'góor ak jigéen jàppante loxo: xeesaayu der bu xeereer, xeesaayu der bu yam',
    '👩🏼‍🤝‍👨🏾' => 'góor ak jigéen jàppante loxo: xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '👩🏼‍🤝‍👨🏿' => 'góor ak jigéen jàppante loxo: xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '👩🏽‍🤝‍👨🏻' => 'góor ak jigéen jàppante loxo: xeesaayu der bu yam, xeesaayu der bu woyof',
    '👩🏽‍🤝‍👨🏼' => 'góor ak jigéen jàppante loxo: xeesaayu der bu yam, xeesaayu der bu xeereer',
    '👩🏽‍🤝‍👨🏾' => 'góor ak jigéen jàppante loxo: xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '👩🏽‍🤝‍👨🏿' => 'góor ak jigéen jàppante loxo: xeesaayu der bu yam, xeesaayu der bu ñuul',
    '👩🏾‍🤝‍👨🏻' => 'góor ak jigéen jàppante loxo: xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '👩🏾‍🤝‍👨🏼' => 'góor ak jigéen jàppante loxo: xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '👩🏾‍🤝‍👨🏽' => 'góor ak jigéen jàppante loxo: xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '👩🏾‍🤝‍👨🏿' => 'góor ak jigéen jàppante loxo: xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '👩🏿‍🤝‍👨🏻' => 'góor ak jigéen jàppante loxo: xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '👩🏿‍🤝‍👨🏼' => 'góor ak jigéen jàppante loxo: xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '👩🏿‍🤝‍👨🏽' => 'góor ak jigéen jàppante loxo: xeesaayu der bu ñuul, xeesaayu der bu yam',
    '👩🏿‍🤝‍👨🏾' => 'góor ak jigéen jàppante loxo: xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '👨🏻‍🤝‍👨🏼' => 'ñaari góor yu jàppante loxo: xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '👨🏻‍🤝‍👨🏽' => 'ñaari góor yu jàppante loxo: xeesaayu der bu woyof, xeesaayu der bu yam',
    '👨🏻‍🤝‍👨🏾' => 'ñaari góor yu jàppante loxo: xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '👨🏻‍🤝‍👨🏿' => 'ñaari góor yu jàppante loxo: xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '👨🏼‍🤝‍👨🏻' => 'ñaari góor yu jàppante loxo: xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '👨🏼‍🤝‍👨🏽' => 'ñaari góor yu jàppante loxo: xeesaayu der bu xeereer, xeesaayu der bu yam',
    '👨🏼‍🤝‍👨🏾' => 'ñaari góor yu jàppante loxo: xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '👨🏼‍🤝‍👨🏿' => 'ñaari góor yu jàppante loxo: xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '👨🏽‍🤝‍👨🏻' => 'ñaari góor yu jàppante loxo: xeesaayu der bu yam, xeesaayu der bu woyof',
    '👨🏽‍🤝‍👨🏼' => 'ñaari góor yu jàppante loxo: xeesaayu der bu yam, xeesaayu der bu xeereer',
    '👨🏽‍🤝‍👨🏾' => 'ñaari góor yu jàppante loxo: xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '👨🏽‍🤝‍👨🏿' => 'ñaari góor yu jàppante loxo: xeesaayu der bu yam, xeesaayu der bu ñuul',
    '👨🏾‍🤝‍👨🏻' => 'ñaari góor yu jàppante loxo: xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '👨🏾‍🤝‍👨🏼' => 'ñaari góor yu jàppante loxo: xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '👨🏾‍🤝‍👨🏽' => 'ñaari góor yu jàppante loxo: xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '👨🏾‍🤝‍👨🏿' => 'ñaari góor yu jàppante loxo: xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '👨🏿‍🤝‍👨🏻' => 'ñaari góor yu jàppante loxo: xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '👨🏿‍🤝‍👨🏼' => 'ñaari góor yu jàppante loxo: xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '👨🏿‍🤝‍👨🏽' => 'ñaari góor yu jàppante loxo: xeesaayu der bu ñuul, xeesaayu der bu yam',
    '👨🏿‍🤝‍👨🏾' => 'ñaari góor yu jàppante loxo: xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '👩‍❤‍💋‍👨' => 'fóon: jigéen, góor',
    '👨‍❤‍💋‍👨' => 'fóon: góor, góor',
    '👩‍❤‍💋‍👩' => 'fóon: jigéen, jigéen',
    '👨‍👩‍👧‍👦' => 'bokk famiy: góor, jigéen, xale bu jigéen, xale bu góor',
    '👨‍👩‍👦‍👦' => 'bokk famiy: góor, jigéen, xale bu góor, xale bu góor',
    '👨‍👩‍👧‍👧' => 'bokk famiy: góor, jigéen, xale bu jigéen, xale bu jigéen',
    '👨‍👨‍👧‍👦' => 'bokk famiy: góor, góor, xale bu jigéen, xale bu góor',
    '👨‍👨‍👦‍👦' => 'bokk famiy: góor, góor, xale bu góor, xale bu góor',
    '👨‍👨‍👧‍👧' => 'bokk famiy: góor, góor, xale bu jigéen, xale bu jigéen',
    '👩‍👩‍👧‍👦' => 'bokk famiy: jigéen, jigéen, xale bu jigéen, xale bu góor',
    '👩‍👩‍👦‍👦' => 'bokk famiy: jigéen, jigéen, xale bu góor, xale bu góor',
    '👩‍👩‍👧‍👧' => 'bokk famiy: jigéen, jigéen, xale bu jigéen, xale bu jigéen',
    '🫱🏻‍🫲🏼' => 'joxante loxo: xeesaayu der bu woyof, xeesaayu der bu xeereer',
    '🫱🏻‍🫲🏽' => 'joxante loxo: xeesaayu der bu woyof, xeesaayu der bu yam',
    '🫱🏻‍🫲🏾' => 'joxante loxo: xeesaayu der bu woyof, xeesaayu der bu xawa ñuul',
    '🫱🏻‍🫲🏿' => 'joxante loxo: xeesaayu der bu woyof, xeesaayu der bu ñuul',
    '🫱🏼‍🫲🏻' => 'joxante loxo: xeesaayu der bu xeereer, xeesaayu der bu woyof',
    '🫱🏼‍🫲🏽' => 'joxante loxo: xeesaayu der bu xeereer, xeesaayu der bu yam',
    '🫱🏼‍🫲🏾' => 'joxante loxo: xeesaayu der bu xeereer, xeesaayu der bu xawa ñuul',
    '🫱🏼‍🫲🏿' => 'joxante loxo: xeesaayu der bu xeereer, xeesaayu der bu ñuul',
    '🫱🏽‍🫲🏻' => 'joxante loxo: xeesaayu der bu yam, xeesaayu der bu woyof',
    '🫱🏽‍🫲🏼' => 'joxante loxo: xeesaayu der bu yam, xeesaayu der bu xeereer',
    '🫱🏽‍🫲🏾' => 'joxante loxo: xeesaayu der bu yam, xeesaayu der bu xawa ñuul',
    '🫱🏽‍🫲🏿' => 'joxante loxo: xeesaayu der bu yam, xeesaayu der bu ñuul',
    '🫱🏾‍🫲🏻' => 'joxante loxo: xeesaayu der bu xawa ñuul, xeesaayu der bu woyof',
    '🫱🏾‍🫲🏼' => 'joxante loxo: xeesaayu der bu xawa ñuul, xeesaayu der bu xeereer',
    '🫱🏾‍🫲🏽' => 'joxante loxo: xeesaayu der bu xawa ñuul, xeesaayu der bu yam',
    '🫱🏾‍🫲🏿' => 'joxante loxo: xeesaayu der bu xawa ñuul, xeesaayu der bu ñuul',
    '🫱🏿‍🫲🏻' => 'joxante loxo: xeesaayu der bu ñuul, xeesaayu der bu woyof',
    '🫱🏿‍🫲🏼' => 'joxante loxo: xeesaayu der bu ñuul, xeesaayu der bu xeereer',
    '🫱🏿‍🫲🏽' => 'joxante loxo: xeesaayu der bu ñuul, xeesaayu der bu yam',
    '🫱🏿‍🫲🏾' => 'joxante loxo: xeesaayu der bu ñuul, xeesaayu der bu xawa ñuul',
    '👩‍❤‍👨' => 'xol ak ñaar ñu bëggante: jigéen, góor',
    '👨‍❤‍👨' => 'xol ak ñaar ñu bëggante: góor, góor',
    '👩‍❤‍👩' => 'xol ak ñaar ñu bëggante: jigéen, jigéen',
    '👨‍👩‍👦' => 'bokk famiy: góor, jigéen, xale bu góor',
    '👨‍👩‍👧' => 'bokk famiy: góor, jigéen, xale bu jigéen',
    '👨‍👨‍👦' => 'bokk famiy: góor, góor, xale bu góor',
    '👨‍👨‍👧' => 'bokk famiy: góor, góor, xale bu jigéen',
    '👩‍👩‍👦' => 'bokk famiy: jigéen, jigéen, xale bu góor',
    '👩‍👩‍👧' => 'bokk famiy: jigéen, jigéen, xale bu jigéen',
    '👨‍👦‍👦' => 'bokk famiy: góor, xale bu góor, xale bu góor',
    '👨‍👧‍👦' => 'bokk famiy: góor, xale bu jigéen, xale bu góor',
    '👨‍👧‍👧' => 'bokk famiy: góor, xale bu jigéen, xale bu jigéen',
    '👩‍👦‍👦' => 'bokk famiy: jigéen, xale bu góor, xale bu góor',
    '👩‍👧‍👦' => 'bokk famiy: jigéen, xale bu jigéen, xale bu góor',
    '👩‍👧‍👧' => 'bokk famiy: jigéen, xale bu jigéen, xale bu jigéen',
    '👱🏻‍♂' => 'góor gu am karaw gu mboq: xeesaayu der bu woyof',
    '👱🏼‍♂' => 'góor gu am karaw gu mboq: xeesaayu der bu xeereer',
    '👱🏽‍♂' => 'góor gu am karaw gu mboq: xeesaayu der bu yam',
    '👱🏾‍♂' => 'góor gu am karaw gu mboq: xeesaayu der bu xawa ñuul',
    '👱🏿‍♂' => 'góor gu am karaw gu mboq: xeesaayu der bu ñuul',
    '👱🏻‍♀' => 'karaw gu am kawar gu mboq jigéen: xeesaayu der bu woyof',
    '👱🏼‍♀' => 'karaw gu am kawar gu mboq jigéen: xeesaayu der bu xeereer',
    '👱🏽‍♀' => 'karaw gu am kawar gu mboq jigéen: xeesaayu der bu yam',
    '👱🏾‍♀' => 'karaw gu am kawar gu mboq jigéen: xeesaayu der bu xawa ñuul',
    '👱🏿‍♀' => 'karaw gu am kawar gu mboq jigéen: xeesaayu der bu ñuul',
    '🙍🏻‍♂' => 'góor aj-yéen: xeesaayu der bu woyof',
    '🙍🏼‍♂' => 'góor aj-yéen: xeesaayu der bu xeereer',
    '🙍🏽‍♂' => 'góor aj-yéen: xeesaayu der bu yam',
    '🙍🏾‍♂' => 'góor aj-yéen: xeesaayu der bu xawa ñuul',
    '🙍🏿‍♂' => 'góor aj-yéen: xeesaayu der bu ñuul',
    '🙍🏻‍♀' => 'jigéen aj-yéen: xeesaayu der bu woyof',
    '🙍🏼‍♀' => 'jigéen aj-yéen: xeesaayu der bu xeereer',
    '🙍🏽‍♀' => 'jigéen aj-yéen: xeesaayu der bu yam',
    '🙍🏾‍♀' => 'jigéen aj-yéen: xeesaayu der bu xawa ñuul',
    '🙍🏿‍♀' => 'jigéen aj-yéen: xeesaayu der bu ñuul',
    '🙎🏻‍♂' => 'góor puucatu: xeesaayu der bu woyof',
    '🙎🏼‍♂' => 'góor puucatu: xeesaayu der bu xeereer',
    '🙎🏽‍♂' => 'góor puucatu: xeesaayu der bu yam',
    '🙎🏾‍♂' => 'góor puucatu: xeesaayu der bu xawa ñuul',
    '🙎🏿‍♂' => 'góor puucatu: xeesaayu der bu ñuul',
    '🙎🏻‍♀' => 'jigéen puucatu: xeesaayu der bu woyof',
    '🙎🏼‍♀' => 'jigéen puucatu: xeesaayu der bu xeereer',
    '🙎🏽‍♀' => 'jigéen puucatu: xeesaayu der bu yam',
    '🙎🏾‍♀' => 'jigéen puucatu: xeesaayu der bu xawa ñuul',
    '🙎🏿‍♀' => 'jigéen puucatu: xeesaayu der bu ñuul',
    '🙅🏻‍♂' => 'góor buy liyaar Déet: xeesaayu der bu woyof',
    '🙅🏼‍♂' => 'góor buy liyaar Déet: xeesaayu der bu xeereer',
    '🙅🏽‍♂' => 'góor buy liyaar Déet: xeesaayu der bu yam',
    '🙅🏾‍♂' => 'góor buy liyaar Déet: xeesaayu der bu xawa ñuul',
    '🙅🏿‍♂' => 'góor buy liyaar Déet: xeesaayu der bu ñuul',
    '🙅🏻‍♀' => 'jigéen juy liyaar Déet: xeesaayu der bu woyof',
    '🙅🏼‍♀' => 'jigéen juy liyaar Déet: xeesaayu der bu xeereer',
    '🙅🏽‍♀' => 'jigéen juy liyaar Déet: xeesaayu der bu yam',
    '🙅🏾‍♀' => 'jigéen juy liyaar Déet: xeesaayu der bu xawa ñuul',
    '🙅🏿‍♀' => 'jigéen juy liyaar Déet: xeesaayu der bu ñuul',
    '🙆🏻‍♂' => 'góor buy liyaar waaw-kay: xeesaayu der bu woyof',
    '🙆🏼‍♂' => 'góor buy liyaar waaw-kay: xeesaayu der bu xeereer',
    '🙆🏽‍♂' => 'góor buy liyaar waaw-kay: xeesaayu der bu yam',
    '🙆🏾‍♂' => 'góor buy liyaar waaw-kay: xeesaayu der bu xawa ñuul',
    '🙆🏿‍♂' => 'góor buy liyaar waaw-kay: xeesaayu der bu ñuul',
    '🙆🏻‍♀' => 'jigéen juy liyaar waaw-kay: xeesaayu der bu woyof',
    '🙆🏼‍♀' => 'jigéen juy liyaar waaw-kay: xeesaayu der bu xeereer',
    '🙆🏽‍♀' => 'jigéen juy liyaar waaw-kay: xeesaayu der bu yam',
    '🙆🏾‍♀' => 'jigéen juy liyaar waaw-kay: xeesaayu der bu xawa ñuul',
    '🙆🏿‍♀' => 'jigéen juy liyaar waaw-kay: xeesaayu der bu ñuul',
    '💁🏻‍♂' => 'góor loxo jàppale: xeesaayu der bu woyof',
    '💁🏼‍♂' => 'góor loxo jàppale: xeesaayu der bu xeereer',
    '💁🏽‍♂' => 'góor loxo jàppale: xeesaayu der bu yam',
    '💁🏾‍♂' => 'góor loxo jàppale: xeesaayu der bu xawa ñuul',
    '💁🏿‍♂' => 'góor loxo jàppale: xeesaayu der bu ñuul',
    '💁🏻‍♀' => 'jigéen loxo jàppale: xeesaayu der bu woyof',
    '💁🏼‍♀' => 'jigéen loxo jàppale: xeesaayu der bu xeereer',
    '💁🏽‍♀' => 'jigéen loxo jàppale: xeesaayu der bu yam',
    '💁🏾‍♀' => 'jigéen loxo jàppale: xeesaayu der bu xawa ñuul',
    '💁🏿‍♀' => 'jigéen loxo jàppale: xeesaayu der bu ñuul',
    '🙋🏻‍♂' => 'góor yëkkati loxo: xeesaayu der bu woyof',
    '🙋🏼‍♂' => 'góor yëkkati loxo: xeesaayu der bu xeereer',
    '🙋🏽‍♂' => 'góor yëkkati loxo: xeesaayu der bu yam',
    '🙋🏾‍♂' => 'góor yëkkati loxo: xeesaayu der bu xawa ñuul',
    '🙋🏿‍♂' => 'góor yëkkati loxo: xeesaayu der bu ñuul',
    '🙋🏻‍♀' => 'jigéen yëkkati loxo: xeesaayu der bu woyof',
    '🙋🏼‍♀' => 'jigéen yëkkati loxo: xeesaayu der bu xeereer',
    '🙋🏽‍♀' => 'jigéen yëkkati loxo: xeesaayu der bu yam',
    '🙋🏾‍♀' => 'jigéen yëkkati loxo: xeesaayu der bu xawa ñuul',
    '🙋🏿‍♀' => 'jigéen yëkkati loxo: xeesaayu der bu ñuul',
    '🙇🏻‍♂' => 'góor sujjóotal: xeesaayu der bu woyof',
    '🙇🏼‍♂' => 'góor sujjóotal: xeesaayu der bu xeereer',
    '🙇🏽‍♂' => 'góor sujjóotal: xeesaayu der bu yam',
    '🙇🏾‍♂' => 'góor sujjóotal: xeesaayu der bu xawa ñuul',
    '🙇🏿‍♂' => 'góor sujjóotal: xeesaayu der bu ñuul',
    '🙇🏻‍♀' => 'jigéen sujjóotal: xeesaayu der bu woyof',
    '🙇🏼‍♀' => 'jigéen sujjóotal: xeesaayu der bu xeereer',
    '🙇🏽‍♀' => 'jigéen sujjóotal: xeesaayu der bu yam',
    '🙇🏾‍♀' => 'jigéen sujjóotal: xeesaayu der bu xawa ñuul',
    '🙇🏿‍♀' => 'jigéen sujjóotal: xeesaayu der bu ñuul',
    '🤦🏻‍♂' => 'góor gu taf loxo ci kanamam: xeesaayu der bu woyof',
    '🤦🏼‍♂' => 'góor gu taf loxo ci kanamam: xeesaayu der bu xeereer',
    '🤦🏽‍♂' => 'góor gu taf loxo ci kanamam: xeesaayu der bu yam',
    '🤦🏾‍♂' => 'góor gu taf loxo ci kanamam: xeesaayu der bu xawa ñuul',
    '🤦🏿‍♂' => 'góor gu taf loxo ci kanamam: xeesaayu der bu ñuul',
    '🤦🏻‍♀' => 'ju taf loxo ci kanamam: xeesaayu der bu woyof',
    '🤦🏼‍♀' => 'ju taf loxo ci kanamam: xeesaayu der bu xeereer',
    '🤦🏽‍♀' => 'ju taf loxo ci kanamam: xeesaayu der bu yam',
    '🤦🏾‍♀' => 'ju taf loxo ci kanamam: xeesaayu der bu xawa ñuul',
    '🤦🏿‍♀' => 'ju taf loxo ci kanamam: xeesaayu der bu ñuul',
    '🤷🏻‍♂' => 'góor aj mbagg: xeesaayu der bu woyof',
    '🤷🏼‍♂' => 'góor aj mbagg: xeesaayu der bu xeereer',
    '🤷🏽‍♂' => 'góor aj mbagg: xeesaayu der bu yam',
    '🤷🏾‍♂' => 'góor aj mbagg: xeesaayu der bu xawa ñuul',
    '🤷🏿‍♂' => 'góor aj mbagg: xeesaayu der bu ñuul',
    '🤷🏻‍♀' => 'jigéen aj mbagg: xeesaayu der bu woyof',
    '🤷🏼‍♀' => 'jigéen aj mbagg: xeesaayu der bu xeereer',
    '🤷🏽‍♀' => 'jigéen aj mbagg: xeesaayu der bu yam',
    '🤷🏾‍♀' => 'jigéen aj mbagg: xeesaayu der bu xawa ñuul',
    '🤷🏿‍♀' => 'jigéen aj mbagg: xeesaayu der bu ñuul',
    '👨🏻‍⚕' => 'fajkat bu góor: xeesaayu der bu woyof',
    '👨🏼‍⚕' => 'fajkat bu góor: xeesaayu der bu xeereer',
    '👨🏽‍⚕' => 'fajkat bu góor: xeesaayu der bu yam',
    '👨🏾‍⚕' => 'fajkat bu góor: xeesaayu der bu xawa ñuul',
    '👨🏿‍⚕' => 'fajkat bu góor: xeesaayu der bu ñuul',
    '👩🏻‍⚕' => 'fajkat bu jigéen: xeesaayu der bu woyof',
    '👩🏼‍⚕' => 'fajkat bu jigéen: xeesaayu der bu xeereer',
    '👩🏽‍⚕' => 'fajkat bu jigéen: xeesaayu der bu yam',
    '👩🏾‍⚕' => 'fajkat bu jigéen: xeesaayu der bu xawa ñuul',
    '👩🏿‍⚕' => 'fajkat bu jigéen: xeesaayu der bu ñuul',
    '👨🏻‍🎓' => 'ndongo bu góor: xeesaayu der bu woyof',
    '👨🏼‍🎓' => 'ndongo bu góor: xeesaayu der bu xeereer',
    '👨🏽‍🎓' => 'ndongo bu góor: xeesaayu der bu yam',
    '👨🏾‍🎓' => 'ndongo bu góor: xeesaayu der bu xawa ñuul',
    '👨🏿‍🎓' => 'ndongo bu góor: xeesaayu der bu ñuul',
    '👩🏻‍🎓' => 'ndongo lu jigéen: xeesaayu der bu woyof',
    '👩🏼‍🎓' => 'ndongo lu jigéen: xeesaayu der bu xeereer',
    '👩🏽‍🎓' => 'ndongo lu jigéen: xeesaayu der bu yam',
    '👩🏾‍🎓' => 'ndongo lu jigéen: xeesaayu der bu xawa ñuul',
    '👩🏿‍🎓' => 'ndongo lu jigéen: xeesaayu der bu ñuul',
    '👨🏻‍🏫' => 'jàngaletkat bu góor: xeesaayu der bu woyof',
    '👨🏼‍🏫' => 'jàngaletkat bu góor: xeesaayu der bu xeereer',
    '👨🏽‍🏫' => 'jàngaletkat bu góor: xeesaayu der bu yam',
    '👨🏾‍🏫' => 'jàngaletkat bu góor: xeesaayu der bu xawa ñuul',
    '👨🏿‍🏫' => 'jàngaletkat bu góor: xeesaayu der bu ñuul',
    '👩🏻‍🏫' => 'jàngalekat bu jigéen: xeesaayu der bu woyof',
    '👩🏼‍🏫' => 'jàngalekat bu jigéen: xeesaayu der bu xeereer',
    '👩🏽‍🏫' => 'jàngalekat bu jigéen: xeesaayu der bu yam',
    '👩🏾‍🏫' => 'jàngalekat bu jigéen: xeesaayu der bu xawa ñuul',
    '👩🏿‍🏫' => 'jàngalekat bu jigéen: xeesaayu der bu ñuul',
    '👨🏻‍⚖' => 'àttekat góor: xeesaayu der bu woyof',
    '👨🏼‍⚖' => 'àttekat góor: xeesaayu der bu xeereer',
    '👨🏽‍⚖' => 'àttekat góor: xeesaayu der bu yam',
    '👨🏾‍⚖' => 'àttekat góor: xeesaayu der bu xawa ñuul',
    '👨🏿‍⚖' => 'àttekat góor: xeesaayu der bu ñuul',
    '👩🏻‍⚖' => 'àttekat bu jigéen: xeesaayu der bu woyof',
    '👩🏼‍⚖' => 'àttekat bu jigéen: xeesaayu der bu xeereer',
    '👩🏽‍⚖' => 'àttekat bu jigéen: xeesaayu der bu yam',
    '👩🏾‍⚖' => 'àttekat bu jigéen: xeesaayu der bu xawa ñuul',
    '👩🏿‍⚖' => 'àttekat bu jigéen: xeesaayu der bu ñuul',
    '👨🏻‍🌾' => 'baykat bu góor: xeesaayu der bu woyof',
    '👨🏼‍🌾' => 'baykat bu góor: xeesaayu der bu xeereer',
    '👨🏽‍🌾' => 'baykat bu góor: xeesaayu der bu yam',
    '👨🏾‍🌾' => 'baykat bu góor: xeesaayu der bu xawa ñuul',
    '👨🏿‍🌾' => 'baykat bu góor: xeesaayu der bu ñuul',
    '👩🏻‍🌾' => 'baykat bu jigéen: xeesaayu der bu woyof',
    '👩🏼‍🌾' => 'baykat bu jigéen: xeesaayu der bu xeereer',
    '👩🏽‍🌾' => 'baykat bu jigéen: xeesaayu der bu yam',
    '👩🏾‍🌾' => 'baykat bu jigéen: xeesaayu der bu xawa ñuul',
    '👩🏿‍🌾' => 'baykat bu jigéen: xeesaayu der bu ñuul',
    '👨🏻‍🍳' => 'toggkat góor: xeesaayu der bu woyof',
    '👨🏼‍🍳' => 'toggkat góor: xeesaayu der bu xeereer',
    '👨🏽‍🍳' => 'toggkat góor: xeesaayu der bu yam',
    '👨🏾‍🍳' => 'toggkat góor: xeesaayu der bu xawa ñuul',
    '👨🏿‍🍳' => 'toggkat góor: xeesaayu der bu ñuul',
    '👩🏻‍🍳' => 'toggkat bu jigéen: xeesaayu der bu woyof',
    '👩🏼‍🍳' => 'toggkat bu jigéen: xeesaayu der bu xeereer',
    '👩🏽‍🍳' => 'toggkat bu jigéen: xeesaayu der bu yam',
    '👩🏾‍🍳' => 'toggkat bu jigéen: xeesaayu der bu xawa ñuul',
    '👩🏿‍🍳' => 'toggkat bu jigéen: xeesaayu der bu ñuul',
    '👨🏻‍🔧' => 'mekaniyee bu góor: xeesaayu der bu woyof',
    '👨🏼‍🔧' => 'mekaniyee bu góor: xeesaayu der bu xeereer',
    '👨🏽‍🔧' => 'mekaniyee bu góor: xeesaayu der bu yam',
    '👨🏾‍🔧' => 'mekaniyee bu góor: xeesaayu der bu xawa ñuul',
    '👨🏿‍🔧' => 'mekaniyee bu góor: xeesaayu der bu ñuul',
    '👩🏻‍🔧' => 'jigéen mekanik: xeesaayu der bu woyof',
    '👩🏼‍🔧' => 'jigéen mekanik: xeesaayu der bu xeereer',
    '👩🏽‍🔧' => 'jigéen mekanik: xeesaayu der bu yam',
    '👩🏾‍🔧' => 'jigéen mekanik: xeesaayu der bu xawa ñuul',
    '👩🏿‍🔧' => 'jigéen mekanik: xeesaayu der bu ñuul',
    '👨🏻‍🏭' => 'liggéeykatu isin bu góor: xeesaayu der bu woyof',
    '👨🏼‍🏭' => 'liggéeykatu isin bu góor: xeesaayu der bu xeereer',
    '👨🏽‍🏭' => 'liggéeykatu isin bu góor: xeesaayu der bu yam',
    '👨🏾‍🏭' => 'liggéeykatu isin bu góor: xeesaayu der bu xawa ñuul',
    '👨🏿‍🏭' => 'liggéeykatu isin bu góor: xeesaayu der bu ñuul',
    '👩🏻‍🏭' => 'jigéen juy liggéeykat ci isin: xeesaayu der bu woyof',
    '👩🏼‍🏭' => 'jigéen juy liggéeykat ci isin: xeesaayu der bu xeereer',
    '👩🏽‍🏭' => 'jigéen juy liggéeykat ci isin: xeesaayu der bu yam',
    '👩🏾‍🏭' => 'jigéen juy liggéeykat ci isin: xeesaayu der bu xawa ñuul',
    '👩🏿‍🏭' => 'jigéen juy liggéeykat ci isin: xeesaayu der bu ñuul',
    '👨🏻‍💼' => 'kuy liggéey ci biro: xeesaayu der bu woyof',
    '👨🏼‍💼' => 'kuy liggéey ci biro: xeesaayu der bu xeereer',
    '👨🏽‍💼' => 'kuy liggéey ci biro: xeesaayu der bu yam',
    '👨🏾‍💼' => 'kuy liggéey ci biro: xeesaayu der bu xawa ñuul',
    '👨🏿‍💼' => 'kuy liggéey ci biro: xeesaayu der bu ñuul',
    '👩🏻‍💼' => 'jigéen biro liggéeykat: xeesaayu der bu woyof',
    '👩🏼‍💼' => 'jigéen biro liggéeykat: xeesaayu der bu xeereer',
    '👩🏽‍💼' => 'jigéen biro liggéeykat: xeesaayu der bu yam',
    '👩🏾‍💼' => 'jigéen biro liggéeykat: xeesaayu der bu xawa ñuul',
    '👩🏿‍💼' => 'jigéen biro liggéeykat: xeesaayu der bu ñuul',
    '👨🏻‍🔬' => 'xaralakat bu góor: xeesaayu der bu woyof',
    '👨🏼‍🔬' => 'xaralakat bu góor: xeesaayu der bu xeereer',
    '👨🏽‍🔬' => 'xaralakat bu góor: xeesaayu der bu yam',
    '👨🏾‍🔬' => 'xaralakat bu góor: xeesaayu der bu xawa ñuul',
    '👨🏿‍🔬' => 'xaralakat bu góor: xeesaayu der bu ñuul',
    '👩🏻‍🔬' => 'jigéen wu-xarala: xeesaayu der bu woyof',
    '👩🏼‍🔬' => 'jigéen wu-xarala: xeesaayu der bu xeereer',
    '👩🏽‍🔬' => 'jigéen wu-xarala: xeesaayu der bu yam',
    '👩🏾‍🔬' => 'jigéen wu-xarala: xeesaayu der bu xawa ñuul',
    '👩🏿‍🔬' => 'jigéen wu-xarala: xeesaayu der bu ñuul',
    '👨🏻‍💻' => 'góor teknolosist: xeesaayu der bu woyof',
    '👨🏼‍💻' => 'góor teknolosist: xeesaayu der bu xeereer',
    '👨🏽‍💻' => 'góor teknolosist: xeesaayu der bu yam',
    '👨🏾‍💻' => 'góor teknolosist: xeesaayu der bu xawa ñuul',
    '👨🏿‍💻' => 'góor teknolosist: xeesaayu der bu ñuul',
    '👩🏻‍💻' => 'jigéen teknolosist: xeesaayu der bu woyof',
    '👩🏼‍💻' => 'jigéen teknolosist: xeesaayu der bu xeereer',
    '👩🏽‍💻' => 'jigéen teknolosist: xeesaayu der bu yam',
    '👩🏾‍💻' => 'jigéen teknolosist: xeesaayu der bu xawa ñuul',
    '👩🏿‍💻' => 'jigéen teknolosist: xeesaayu der bu ñuul',
    '👨🏻‍🎤' => 'góor waykat: xeesaayu der bu woyof',
    '👨🏼‍🎤' => 'góor waykat: xeesaayu der bu xeereer',
    '👨🏽‍🎤' => 'góor waykat: xeesaayu der bu yam',
    '👨🏾‍🎤' => 'góor waykat: xeesaayu der bu xawa ñuul',
    '👨🏿‍🎤' => 'góor waykat: xeesaayu der bu ñuul',
    '👩🏻‍🎤' => 'jigéen waykat: xeesaayu der bu woyof',
    '👩🏼‍🎤' => 'jigéen waykat: xeesaayu der bu xeereer',
    '👩🏽‍🎤' => 'jigéen waykat: xeesaayu der bu yam',
    '👩🏾‍🎤' => 'jigéen waykat: xeesaayu der bu xawa ñuul',
    '👩🏿‍🎤' => 'jigéen waykat: xeesaayu der bu ñuul',
    '👨🏻‍🎨' => 'artist bu góor: xeesaayu der bu woyof',
    '👨🏼‍🎨' => 'artist bu góor: xeesaayu der bu xeereer',
    '👨🏽‍🎨' => 'artist bu góor: xeesaayu der bu yam',
    '👨🏾‍🎨' => 'artist bu góor: xeesaayu der bu xawa ñuul',
    '👨🏿‍🎨' => 'artist bu góor: xeesaayu der bu ñuul',
    '👩🏻‍🎨' => 'artist bu jigéen: xeesaayu der bu woyof',
    '👩🏼‍🎨' => 'artist bu jigéen: xeesaayu der bu xeereer',
    '👩🏽‍🎨' => 'artist bu jigéen: xeesaayu der bu yam',
    '👩🏾‍🎨' => 'artist bu jigéen: xeesaayu der bu xawa ñuul',
    '👩🏿‍🎨' => 'artist bu jigéen: xeesaayu der bu ñuul',
    '👨🏻‍✈' => 'góor piloot: xeesaayu der bu woyof',
    '👨🏼‍✈' => 'góor piloot: xeesaayu der bu xeereer',
    '👨🏽‍✈' => 'góor piloot: xeesaayu der bu yam',
    '👨🏾‍✈' => 'góor piloot: xeesaayu der bu xawa ñuul',
    '👨🏿‍✈' => 'góor piloot: xeesaayu der bu ñuul',
    '👩🏻‍✈' => 'piloot bu jigéen: xeesaayu der bu woyof',
    '👩🏼‍✈' => 'piloot bu jigéen: xeesaayu der bu xeereer',
    '👩🏽‍✈' => 'piloot bu jigéen: xeesaayu der bu yam',
    '👩🏾‍✈' => 'piloot bu jigéen: xeesaayu der bu xawa ñuul',
    '👩🏿‍✈' => 'piloot bu jigéen: xeesaayu der bu ñuul',
    '👨🏻‍🚀' => 'astronot bu góor: xeesaayu der bu woyof',
    '👨🏼‍🚀' => 'astronot bu góor: xeesaayu der bu xeereer',
    '👨🏽‍🚀' => 'astronot bu góor: xeesaayu der bu yam',
    '👨🏾‍🚀' => 'astronot bu góor: xeesaayu der bu xawa ñuul',
    '👨🏿‍🚀' => 'astronot bu góor: xeesaayu der bu ñuul',
    '👩🏻‍🚀' => 'astronot bu jigéen: xeesaayu der bu woyof',
    '👩🏼‍🚀' => 'astronot bu jigéen: xeesaayu der bu xeereer',
    '👩🏽‍🚀' => 'astronot bu jigéen: xeesaayu der bu yam',
    '👩🏾‍🚀' => 'astronot bu jigéen: xeesaayu der bu xawa ñuul',
    '👩🏿‍🚀' => 'astronot bu jigéen: xeesaayu der bu ñuul',
    '👨🏻‍🚒' => 'sapër bu góor: xeesaayu der bu woyof',
    '👨🏼‍🚒' => 'sapër bu góor: xeesaayu der bu xeereer',
    '👨🏽‍🚒' => 'sapër bu góor: xeesaayu der bu yam',
    '👨🏾‍🚒' => 'sapër bu góor: xeesaayu der bu xawa ñuul',
    '👨🏿‍🚒' => 'sapër bu góor: xeesaayu der bu ñuul',
    '👩🏻‍🚒' => 'pompiyee bu jigéen: xeesaayu der bu woyof',
    '👩🏼‍🚒' => 'pompiyee bu jigéen: xeesaayu der bu xeereer',
    '👩🏽‍🚒' => 'pompiyee bu jigéen: xeesaayu der bu yam',
    '👩🏾‍🚒' => 'pompiyee bu jigéen: xeesaayu der bu xawa ñuul',
    '👩🏿‍🚒' => 'pompiyee bu jigéen: xeesaayu der bu ñuul',
    '👮🏻‍♂' => 'góor poliis liggéeykat bu góor: xeesaayu der bu woyof',
    '👮🏼‍♂' => 'góor poliis liggéeykat bu góor: xeesaayu der bu xeereer',
    '👮🏽‍♂' => 'góor poliis liggéeykat bu góor: xeesaayu der bu yam',
    '👮🏾‍♂' => 'góor poliis liggéeykat bu góor: xeesaayu der bu xawa ñuul',
    '👮🏿‍♂' => 'góor poliis liggéeykat bu góor: xeesaayu der bu ñuul',
    '👮🏻‍♀' => 'polisiyee bu jigéen: xeesaayu der bu woyof',
    '👮🏼‍♀' => 'polisiyee bu jigéen: xeesaayu der bu xeereer',
    '👮🏽‍♀' => 'polisiyee bu jigéen: xeesaayu der bu yam',
    '👮🏾‍♀' => 'polisiyee bu jigéen: xeesaayu der bu xawa ñuul',
    '👮🏿‍♀' => 'polisiyee bu jigéen: xeesaayu der bu ñuul',
    '🕵🏻‍♂' => 'góor detektif: xeesaayu der bu woyof',
    '🕵🏼‍♂' => 'góor detektif: xeesaayu der bu xeereer',
    '🕵🏽‍♂' => 'góor detektif: xeesaayu der bu yam',
    '🕵🏾‍♂' => 'góor detektif: xeesaayu der bu xawa ñuul',
    '🕵🏿‍♂' => 'góor detektif: xeesaayu der bu ñuul',
    '🕵🏻‍♀' => 'jigéen detektif: xeesaayu der bu woyof',
    '🕵🏼‍♀' => 'jigéen detektif: xeesaayu der bu xeereer',
    '🕵🏽‍♀' => 'jigéen detektif: xeesaayu der bu yam',
    '🕵🏾‍♀' => 'jigéen detektif: xeesaayu der bu xawa ñuul',
    '🕵🏿‍♀' => 'jigéen detektif: xeesaayu der bu ñuul',
    '💂🏻‍♂' => 'góor guy wattu: xeesaayu der bu woyof',
    '💂🏼‍♂' => 'góor guy wattu: xeesaayu der bu xeereer',
    '💂🏽‍♂' => 'góor guy wattu: xeesaayu der bu yam',
    '💂🏾‍♂' => 'góor guy wattu: xeesaayu der bu xawa ñuul',
    '💂🏿‍♂' => 'góor guy wattu: xeesaayu der bu ñuul',
    '💂🏻‍♀' => 'jigéen juy wattu: xeesaayu der bu woyof',
    '💂🏼‍♀' => 'jigéen juy wattu: xeesaayu der bu xeereer',
    '💂🏽‍♀' => 'jigéen juy wattu: xeesaayu der bu yam',
    '💂🏾‍♀' => 'jigéen juy wattu: xeesaayu der bu xawa ñuul',
    '💂🏿‍♀' => 'jigéen juy wattu: xeesaayu der bu ñuul',
    '👷🏻‍♂' => 'góor tabax liggéeykat: xeesaayu der bu woyof',
    '👷🏼‍♂' => 'góor tabax liggéeykat: xeesaayu der bu xeereer',
    '👷🏽‍♂' => 'góor tabax liggéeykat: xeesaayu der bu yam',
    '👷🏾‍♂' => 'góor tabax liggéeykat: xeesaayu der bu xawa ñuul',
    '👷🏿‍♂' => 'góor tabax liggéeykat: xeesaayu der bu ñuul',
    '👷🏻‍♀' => 'jigéen tabax liggéeykat: xeesaayu der bu woyof',
    '👷🏼‍♀' => 'jigéen tabax liggéeykat: xeesaayu der bu xeereer',
    '👷🏽‍♀' => 'jigéen tabax liggéeykat: xeesaayu der bu yam',
    '👷🏾‍♀' => 'jigéen tabax liggéeykat: xeesaayu der bu xawa ñuul',
    '👷🏿‍♀' => 'jigéen tabax liggéeykat: xeesaayu der bu ñuul',
    '👳🏻‍♂' => 'góor gu kaalawu: xeesaayu der bu woyof',
    '👳🏼‍♂' => 'góor gu kaalawu: xeesaayu der bu xeereer',
    '👳🏽‍♂' => 'góor gu kaalawu: xeesaayu der bu yam',
    '👳🏾‍♂' => 'góor gu kaalawu: xeesaayu der bu xawa ñuul',
    '👳🏿‍♂' => 'góor gu kaalawu: xeesaayu der bu ñuul',
    '👳🏻‍♀' => 'jigéen ju kaalawu: xeesaayu der bu woyof',
    '👳🏼‍♀' => 'jigéen ju kaalawu: xeesaayu der bu xeereer',
    '👳🏽‍♀' => 'jigéen ju kaalawu: xeesaayu der bu yam',
    '👳🏾‍♀' => 'jigéen ju kaalawu: xeesaayu der bu xawa ñuul',
    '👳🏿‍♀' => 'jigéen ju kaalawu: xeesaayu der bu ñuul',
    '🧙🏻‍♂' => 'mage bu góor: xeesaayu der bu woyof',
    '🧙🏼‍♂' => 'mage bu góor: xeesaayu der bu xeereer',
    '🧙🏽‍♂' => 'mage bu góor: xeesaayu der bu yam',
    '🧙🏾‍♂' => 'mage bu góor: xeesaayu der bu xawa ñuul',
    '🧙🏿‍♂' => 'mage bu góor: xeesaayu der bu ñuul',
    '🧙🏻‍♀' => 'mage bu jigéen: xeesaayu der bu woyof',
    '🧙🏼‍♀' => 'mage bu jigéen: xeesaayu der bu xeereer',
    '🧙🏽‍♀' => 'mage bu jigéen: xeesaayu der bu yam',
    '🧙🏾‍♀' => 'mage bu jigéen: xeesaayu der bu xawa ñuul',
    '🧙🏿‍♀' => 'mage bu jigéen: xeesaayu der bu ñuul',
    '🧚🏻‍♂' => 'fee bu góor: xeesaayu der bu woyof',
    '🧚🏼‍♂' => 'fee bu góor: xeesaayu der bu xeereer',
    '🧚🏽‍♂' => 'fee bu góor: xeesaayu der bu yam',
    '🧚🏾‍♂' => 'fee bu góor: xeesaayu der bu xawa ñuul',
    '🧚🏿‍♂' => 'fee bu góor: xeesaayu der bu ñuul',
    '🧚🏻‍♀' => 'fee bu jigéen: xeesaayu der bu woyof',
    '🧚🏼‍♀' => 'fee bu jigéen: xeesaayu der bu xeereer',
    '🧚🏽‍♀' => 'fee bu jigéen: xeesaayu der bu yam',
    '🧚🏾‍♀' => 'fee bu jigéen: xeesaayu der bu xawa ñuul',
    '🧚🏿‍♀' => 'fee bu jigéen: xeesaayu der bu ñuul',
    '🧛🏻‍♂' => 'wàmpiir bu góor: xeesaayu der bu woyof',
    '🧛🏼‍♂' => 'wàmpiir bu góor: xeesaayu der bu xeereer',
    '🧛🏽‍♂' => 'wàmpiir bu góor: xeesaayu der bu yam',
    '🧛🏾‍♂' => 'wàmpiir bu góor: xeesaayu der bu xawa ñuul',
    '🧛🏿‍♂' => 'wàmpiir bu góor: xeesaayu der bu ñuul',
    '🧛🏻‍♀' => 'wàmpiir bu jigéen: xeesaayu der bu woyof',
    '🧛🏼‍♀' => 'wàmpiir bu jigéen: xeesaayu der bu xeereer',
    '🧛🏽‍♀' => 'wàmpiir bu jigéen: xeesaayu der bu yam',
    '🧛🏾‍♀' => 'wàmpiir bu jigéen: xeesaayu der bu xawa ñuul',
    '🧛🏿‍♀' => 'wàmpiir bu jigéen: xeesaayu der bu ñuul',
    '🧜🏻‍♂' => 'sireen bu góor: xeesaayu der bu woyof',
    '🧜🏼‍♂' => 'sireen bu góor: xeesaayu der bu xeereer',
    '🧜🏽‍♂' => 'sireen bu góor: xeesaayu der bu yam',
    '🧜🏾‍♂' => 'sireen bu góor: xeesaayu der bu xawa ñuul',
    '🧜🏿‍♂' => 'sireen bu góor: xeesaayu der bu ñuul',
    '🧜🏻‍♀' => 'sireen: xeesaayu der bu woyof',
    '🧜🏼‍♀' => 'sireen: xeesaayu der bu xeereer',
    '🧜🏽‍♀' => 'sireen: xeesaayu der bu yam',
    '🧜🏾‍♀' => 'sireen: xeesaayu der bu xawa ñuul',
    '🧜🏿‍♀' => 'sireen: xeesaayu der bu ñuul',
    '🧝🏻‍♂' => 'elfe bu góor: xeesaayu der bu woyof',
    '🧝🏼‍♂' => 'elfe bu góor: xeesaayu der bu xeereer',
    '🧝🏽‍♂' => 'elfe bu góor: xeesaayu der bu yam',
    '🧝🏾‍♂' => 'elfe bu góor: xeesaayu der bu xawa ñuul',
    '🧝🏿‍♂' => 'elfe bu góor: xeesaayu der bu ñuul',
    '🧝🏻‍♀' => 'elfe bu jigéen: xeesaayu der bu woyof',
    '🧝🏼‍♀' => 'elfe bu jigéen: xeesaayu der bu xeereer',
    '🧝🏽‍♀' => 'elfe bu jigéen: xeesaayu der bu yam',
    '🧝🏾‍♀' => 'elfe bu jigéen: xeesaayu der bu xawa ñuul',
    '🧝🏿‍♀' => 'elfe bu jigéen: xeesaayu der bu ñuul',
    '💆🏻‍♂' => 'góor bu ñuy dàmp: xeesaayu der bu woyof',
    '💆🏼‍♂' => 'góor bu ñuy dàmp: xeesaayu der bu xeereer',
    '💆🏽‍♂' => 'góor bu ñuy dàmp: xeesaayu der bu yam',
    '💆🏾‍♂' => 'góor bu ñuy dàmp: xeesaayu der bu xawa ñuul',
    '💆🏿‍♂' => 'góor bu ñuy dàmp: xeesaayu der bu ñuul',
    '💆🏻‍♀' => 'jigéen bu ñuy dàmp: xeesaayu der bu woyof',
    '💆🏼‍♀' => 'jigéen bu ñuy dàmp: xeesaayu der bu xeereer',
    '💆🏽‍♀' => 'jigéen bu ñuy dàmp: xeesaayu der bu yam',
    '💆🏾‍♀' => 'jigéen bu ñuy dàmp: xeesaayu der bu xawa ñuul',
    '💆🏿‍♀' => 'jigéen bu ñuy dàmp: xeesaayu der bu ñuul',
    '💇🏻‍♂' => 'góor bu ñuy wat: xeesaayu der bu woyof',
    '💇🏼‍♂' => 'góor bu ñuy wat: xeesaayu der bu xeereer',
    '💇🏽‍♂' => 'góor bu ñuy wat: xeesaayu der bu yam',
    '💇🏾‍♂' => 'góor bu ñuy wat: xeesaayu der bu xawa ñuul',
    '💇🏿‍♂' => 'góor bu ñuy wat: xeesaayu der bu ñuul',
    '💇🏻‍♀' => 'jigéen bu ñuy wat: xeesaayu der bu woyof',
    '💇🏼‍♀' => 'jigéen bu ñuy wat: xeesaayu der bu xeereer',
    '💇🏽‍♀' => 'jigéen bu ñuy wat: xeesaayu der bu yam',
    '💇🏾‍♀' => 'jigéen bu ñuy wat: xeesaayu der bu xawa ñuul',
    '💇🏿‍♀' => 'jigéen bu ñuy wat: xeesaayu der bu ñuul',
    '🚶🏻‍♂' => 'góor dox: xeesaayu der bu woyof',
    '🚶🏼‍♂' => 'góor dox: xeesaayu der bu xeereer',
    '🚶🏽‍♂' => 'góor dox: xeesaayu der bu yam',
    '🚶🏾‍♂' => 'góor dox: xeesaayu der bu xawa ñuul',
    '🚶🏿‍♂' => 'góor dox: xeesaayu der bu ñuul',
    '🚶🏻‍♀' => 'jigéen dox: xeesaayu der bu woyof',
    '🚶🏼‍♀' => 'jigéen dox: xeesaayu der bu xeereer',
    '🚶🏽‍♀' => 'jigéen dox: xeesaayu der bu yam',
    '🚶🏾‍♀' => 'jigéen dox: xeesaayu der bu xawa ñuul',
    '🚶🏿‍♀' => 'jigéen dox: xeesaayu der bu ñuul',
    '🏃🏻‍♂' => 'góor daw: xeesaayu der bu woyof',
    '🏃🏼‍♂' => 'góor daw: xeesaayu der bu xeereer',
    '🏃🏽‍♂' => 'góor daw: xeesaayu der bu yam',
    '🏃🏾‍♂' => 'góor daw: xeesaayu der bu xawa ñuul',
    '🏃🏿‍♂' => 'góor daw: xeesaayu der bu ñuul',
    '🏃🏻‍♀' => 'jigéen daw: xeesaayu der bu woyof',
    '🏃🏼‍♀' => 'jigéen daw: xeesaayu der bu xeereer',
    '🏃🏽‍♀' => 'jigéen daw: xeesaayu der bu yam',
    '🏃🏾‍♀' => 'jigéen daw: xeesaayu der bu xawa ñuul',
    '🏃🏿‍♀' => 'jigéen daw: xeesaayu der bu ñuul',
    '👯🏻‍♀' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu woyof',
    '👯🏼‍♀' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu xeereer',
    '👯🏽‍♀' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu yam',
    '👯🏾‍♀' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu xawa ñuul',
    '👯🏿‍♀' => 'jigéen ak noppi lëks suwaare: xeesaayu der bu ñuul',
    '👯🏻‍♂' => 'góorak noppi lëks suwaare: xeesaayu der bu woyof',
    '👯🏼‍♂' => 'góorak noppi lëks suwaare: xeesaayu der bu xeereer',
    '👯🏽‍♂' => 'góorak noppi lëks suwaare: xeesaayu der bu yam',
    '👯🏾‍♂' => 'góorak noppi lëks suwaare: xeesaayu der bu xawa ñuul',
    '👯🏿‍♂' => 'góorak noppi lëks suwaare: xeesaayu der bu ñuul',
    '🧖🏻‍♂' => 'góor ci néegu wapër: xeesaayu der bu woyof',
    '🧖🏼‍♂' => 'góor ci néegu wapër: xeesaayu der bu xeereer',
    '🧖🏽‍♂' => 'góor ci néegu wapër: xeesaayu der bu yam',
    '🧖🏾‍♂' => 'góor ci néegu wapër: xeesaayu der bu xawa ñuul',
    '🧖🏿‍♂' => 'góor ci néegu wapër: xeesaayu der bu ñuul',
    '🧖🏻‍♀' => 'jigéen ci néegu wapër: xeesaayu der bu woyof',
    '🧖🏼‍♀' => 'jigéen ci néegu wapër: xeesaayu der bu xeereer',
    '🧖🏽‍♀' => 'jigéen ci néegu wapër: xeesaayu der bu yam',
    '🧖🏾‍♀' => 'jigéen ci néegu wapër: xeesaayu der bu xawa ñuul',
    '🧖🏿‍♀' => 'jigéen ci néegu wapër: xeesaayu der bu ñuul',
    '🧗🏻‍♂' => 'góor guy yéeg: xeesaayu der bu woyof',
    '🧗🏼‍♂' => 'góor guy yéeg: xeesaayu der bu xeereer',
    '🧗🏽‍♂' => 'góor guy yéeg: xeesaayu der bu yam',
    '🧗🏾‍♂' => 'góor guy yéeg: xeesaayu der bu xawa ñuul',
    '🧗🏿‍♂' => 'góor guy yéeg: xeesaayu der bu ñuul',
    '🧗🏻‍♀' => 'jigéen juy yéeg: xeesaayu der bu woyof',
    '🧗🏼‍♀' => 'jigéen juy yéeg: xeesaayu der bu xeereer',
    '🧗🏽‍♀' => 'jigéen juy yéeg: xeesaayu der bu yam',
    '🧗🏾‍♀' => 'jigéen juy yéeg: xeesaayu der bu xawa ñuul',
    '🧗🏿‍♀' => 'jigéen juy yéeg: xeesaayu der bu ñuul',
    '🏌🏻‍♂' => 'góor guy golf: xeesaayu der bu woyof',
    '🏌🏼‍♂' => 'góor guy golf: xeesaayu der bu xeereer',
    '🏌🏽‍♂' => 'góor guy golf: xeesaayu der bu yam',
    '🏌🏾‍♂' => 'góor guy golf: xeesaayu der bu xawa ñuul',
    '🏌🏿‍♂' => 'góor guy golf: xeesaayu der bu ñuul',
    '🏌🏻‍♀' => 'jigéen juy golf: xeesaayu der bu woyof',
    '🏌🏼‍♀' => 'jigéen juy golf: xeesaayu der bu xeereer',
    '🏌🏽‍♀' => 'jigéen juy golf: xeesaayu der bu yam',
    '🏌🏾‍♀' => 'jigéen juy golf: xeesaayu der bu xawa ñuul',
    '🏌🏿‍♀' => 'jigéen juy golf: xeesaayu der bu ñuul',
    '🏄🏻‍♂' => 'góor guy sërfe: xeesaayu der bu woyof',
    '🏄🏼‍♂' => 'góor guy sërfe: xeesaayu der bu xeereer',
    '🏄🏽‍♂' => 'góor guy sërfe: xeesaayu der bu yam',
    '🏄🏾‍♂' => 'góor guy sërfe: xeesaayu der bu xawa ñuul',
    '🏄🏿‍♂' => 'góor guy sërfe: xeesaayu der bu ñuul',
    '🏄🏻‍♀' => 'jigéen juy sërfe: xeesaayu der bu woyof',
    '🏄🏼‍♀' => 'jigéen juy sërfe: xeesaayu der bu xeereer',
    '🏄🏽‍♀' => 'jigéen juy sërfe: xeesaayu der bu yam',
    '🏄🏾‍♀' => 'jigéen juy sërfe: xeesaayu der bu xawa ñuul',
    '🏄🏿‍♀' => 'jigéen juy sërfe: xeesaayu der bu ñuul',
    '🚣🏻‍♂' => 'góor guy joow gaal: xeesaayu der bu woyof',
    '🚣🏼‍♂' => 'góor guy joow gaal: xeesaayu der bu xeereer',
    '🚣🏽‍♂' => 'góor guy joow gaal: xeesaayu der bu yam',
    '🚣🏾‍♂' => 'góor guy joow gaal: xeesaayu der bu xawa ñuul',
    '🚣🏿‍♂' => 'góor guy joow gaal: xeesaayu der bu ñuul',
    '🚣🏻‍♀' => 'jigéen juy joow gaal: xeesaayu der bu woyof',
    '🚣🏼‍♀' => 'jigéen juy joow gaal: xeesaayu der bu xeereer',
    '🚣🏽‍♀' => 'jigéen juy joow gaal: xeesaayu der bu yam',
    '🚣🏾‍♀' => 'jigéen juy joow gaal: xeesaayu der bu xawa ñuul',
    '🚣🏿‍♀' => 'jigéen juy joow gaal: xeesaayu der bu ñuul',
    '🏊🏻‍♂' => 'góor guy féey: xeesaayu der bu woyof',
    '🏊🏼‍♂' => 'góor guy féey: xeesaayu der bu xeereer',
    '🏊🏽‍♂' => 'góor guy féey: xeesaayu der bu yam',
    '🏊🏾‍♂' => 'góor guy féey: xeesaayu der bu xawa ñuul',
    '🏊🏿‍♂' => 'góor guy féey: xeesaayu der bu ñuul',
    '🏊🏻‍♀' => 'jigéen juy féey: xeesaayu der bu woyof',
    '🏊🏼‍♀' => 'jigéen juy féey: xeesaayu der bu xeereer',
    '🏊🏽‍♀' => 'jigéen juy féey: xeesaayu der bu yam',
    '🏊🏾‍♀' => 'jigéen juy féey: xeesaayu der bu xawa ñuul',
    '🏊🏿‍♀' => 'jigéen juy féey: xeesaayu der bu ñuul',
    '⛹🏻‍♂' => 'góor guy bondeel bal: xeesaayu der bu woyof',
    '⛹🏼‍♂' => 'góor guy bondeel bal: xeesaayu der bu xeereer',
    '⛹🏽‍♂' => 'góor guy bondeel bal: xeesaayu der bu yam',
    '⛹🏾‍♂' => 'góor guy bondeel bal: xeesaayu der bu xawa ñuul',
    '⛹🏿‍♂' => 'góor guy bondeel bal: xeesaayu der bu ñuul',
    '⛹🏻‍♀' => 'jigéen juy bondeel bal: xeesaayu der bu woyof',
    '⛹🏼‍♀' => 'jigéen juy bondeel bal: xeesaayu der bu xeereer',
    '⛹🏽‍♀' => 'jigéen juy bondeel bal: xeesaayu der bu yam',
    '⛹🏾‍♀' => 'jigéen juy bondeel bal: xeesaayu der bu xawa ñuul',
    '⛹🏿‍♀' => 'jigéen juy bondeel bal: xeesaayu der bu ñuul',
    '🏋🏻‍♂' => 'góor guy yëkkati lu diis: xeesaayu der bu woyof',
    '🏋🏼‍♂' => 'góor guy yëkkati lu diis: xeesaayu der bu xeereer',
    '🏋🏽‍♂' => 'góor guy yëkkati lu diis: xeesaayu der bu yam',
    '🏋🏾‍♂' => 'góor guy yëkkati lu diis: xeesaayu der bu xawa ñuul',
    '🏋🏿‍♂' => 'góor guy yëkkati lu diis: xeesaayu der bu ñuul',
    '🏋🏻‍♀' => 'jigéen juy yëkkati lu diis: xeesaayu der bu woyof',
    '🏋🏼‍♀' => 'jigéen juy yëkkati lu diis: xeesaayu der bu xeereer',
    '🏋🏽‍♀' => 'jigéen juy yëkkati lu diis: xeesaayu der bu yam',
    '🏋🏾‍♀' => 'jigéen juy yëkkati lu diis: xeesaayu der bu xawa ñuul',
    '🏋🏿‍♀' => 'jigéen juy yëkkati lu diis: xeesaayu der bu ñuul',
    '🚴🏻‍♂' => 'góor guy dawal welo: xeesaayu der bu woyof',
    '🚴🏼‍♂' => 'góor guy dawal welo: xeesaayu der bu xeereer',
    '🚴🏽‍♂' => 'góor guy dawal welo: xeesaayu der bu yam',
    '🚴🏾‍♂' => 'góor guy dawal welo: xeesaayu der bu xawa ñuul',
    '🚴🏿‍♂' => 'góor guy dawal welo: xeesaayu der bu ñuul',
    '🚴🏻‍♀' => 'jigéen juy dawal welo: xeesaayu der bu woyof',
    '🚴🏼‍♀' => 'jigéen juy dawal welo: xeesaayu der bu xeereer',
    '🚴🏽‍♀' => 'jigéen juy dawal welo: xeesaayu der bu yam',
    '🚴🏾‍♀' => 'jigéen juy dawal welo: xeesaayu der bu xawa ñuul',
    '🚴🏿‍♀' => 'jigéen juy dawal welo: xeesaayu der bu ñuul',
    '🚵🏻‍♂' => 'góor guy dawal welo ci montaañ: xeesaayu der bu woyof',
    '🚵🏼‍♂' => 'góor guy dawal welo ci montaañ: xeesaayu der bu xeereer',
    '🚵🏽‍♂' => 'góor guy dawal welo ci montaañ: xeesaayu der bu yam',
    '🚵🏾‍♂' => 'góor guy dawal welo ci montaañ: xeesaayu der bu xawa ñuul',
    '🚵🏿‍♂' => 'góor guy dawal welo ci montaañ: xeesaayu der bu ñuul',
    '🚵🏻‍♀' => 'jigéen juy dawal welo ci montaañ: xeesaayu der bu woyof',
    '🚵🏼‍♀' => 'jigéen juy dawal welo ci montaañ: xeesaayu der bu xeereer',
    '🚵🏽‍♀' => 'jigéen juy dawal welo ci montaañ: xeesaayu der bu yam',
    '🚵🏾‍♀' => 'jigéen juy dawal welo ci montaañ: xeesaayu der bu xawa ñuul',
    '🚵🏿‍♀' => 'jigéen juy dawal welo ci montaañ: xeesaayu der bu ñuul',
    '🤸🏻‍♂' => 'góor guy pëno-sareet: xeesaayu der bu woyof',
    '🤸🏼‍♂' => 'góor guy pëno-sareet: xeesaayu der bu xeereer',
    '🤸🏽‍♂' => 'góor guy pëno-sareet: xeesaayu der bu yam',
    '🤸🏾‍♂' => 'góor guy pëno-sareet: xeesaayu der bu xawa ñuul',
    '🤸🏿‍♂' => 'góor guy pëno-sareet: xeesaayu der bu ñuul',
    '🤸🏻‍♀' => 'jigéen juy pëno-sareet: xeesaayu der bu woyof',
    '🤸🏼‍♀' => 'jigéen juy pëno-sareet: xeesaayu der bu xeereer',
    '🤸🏽‍♀' => 'jigéen juy pëno-sareet: xeesaayu der bu yam',
    '🤸🏾‍♀' => 'jigéen juy pëno-sareet: xeesaayu der bu xawa ñuul',
    '🤸🏿‍♀' => 'jigéen juy pëno-sareet: xeesaayu der bu ñuul',
    '🤼🏻‍♀' => 'jigéen juy bëre: xeesaayu der bu woyof',
    '🤼🏼‍♀' => 'jigéen juy bëre: xeesaayu der bu xeereer',
    '🤼🏽‍♀' => 'jigéen juy bëre: xeesaayu der bu yam',
    '🤼🏾‍♀' => 'jigéen juy bëre: xeesaayu der bu xawa ñuul',
    '🤼🏿‍♀' => 'jigéen juy bëre: xeesaayu der bu ñuul',
    '🤼🏻‍♂' => 'góor guy bëre: xeesaayu der bu woyof',
    '🤼🏼‍♂' => 'góor guy bëre: xeesaayu der bu xeereer',
    '🤼🏽‍♂' => 'góor guy bëre: xeesaayu der bu yam',
    '🤼🏾‍♂' => 'góor guy bëre: xeesaayu der bu xawa ñuul',
    '🤼🏿‍♂' => 'góor guy bëre: xeesaayu der bu ñuul',
    '🤽🏻‍♂' => 'góor guy polo ci ndox: xeesaayu der bu woyof',
    '🤽🏼‍♂' => 'góor guy polo ci ndox: xeesaayu der bu xeereer',
    '🤽🏽‍♂' => 'góor guy polo ci ndox: xeesaayu der bu yam',
    '🤽🏾‍♂' => 'góor guy polo ci ndox: xeesaayu der bu xawa ñuul',
    '🤽🏿‍♂' => 'góor guy polo ci ndox: xeesaayu der bu ñuul',
    '🤽🏻‍♀' => 'jigéen juy polo ci ndox: xeesaayu der bu woyof',
    '🤽🏼‍♀' => 'jigéen juy polo ci ndox: xeesaayu der bu xeereer',
    '🤽🏽‍♀' => 'jigéen juy polo ci ndox: xeesaayu der bu yam',
    '🤽🏾‍♀' => 'jigéen juy polo ci ndox: xeesaayu der bu xawa ñuul',
    '🤽🏿‍♀' => 'jigéen juy polo ci ndox: xeesaayu der bu ñuul',
    '🤾🏻‍♂' => 'góor guy handball: xeesaayu der bu woyof',
    '🤾🏼‍♂' => 'góor guy handball: xeesaayu der bu xeereer',
    '🤾🏽‍♂' => 'góor guy handball: xeesaayu der bu yam',
    '🤾🏾‍♂' => 'góor guy handball: xeesaayu der bu xawa ñuul',
    '🤾🏿‍♂' => 'góor guy handball: xeesaayu der bu ñuul',
    '🤾🏻‍♀' => 'jigéen juy handball: xeesaayu der bu woyof',
    '🤾🏼‍♀' => 'jigéen juy handball: xeesaayu der bu xeereer',
    '🤾🏽‍♀' => 'jigéen juy handball: xeesaayu der bu yam',
    '🤾🏾‍♀' => 'jigéen juy handball: xeesaayu der bu xawa ñuul',
    '🤾🏿‍♀' => 'jigéen juy handball: xeesaayu der bu ñuul',
    '🤹🏻‍♂' => 'góor guy sànni-kapte: xeesaayu der bu woyof',
    '🤹🏼‍♂' => 'góor guy sànni-kapte: xeesaayu der bu xeereer',
    '🤹🏽‍♂' => 'góor guy sànni-kapte: xeesaayu der bu yam',
    '🤹🏾‍♂' => 'góor guy sànni-kapte: xeesaayu der bu xawa ñuul',
    '🤹🏿‍♂' => 'góor guy sànni-kapte: xeesaayu der bu ñuul',
    '🤹🏻‍♀' => 'jigéen juy sànni-kapte: xeesaayu der bu woyof',
    '🤹🏼‍♀' => 'jigéen juy sànni-kapte: xeesaayu der bu xeereer',
    '🤹🏽‍♀' => 'jigéen juy sànni-kapte: xeesaayu der bu yam',
    '🤹🏾‍♀' => 'jigéen juy sànni-kapte: xeesaayu der bu xawa ñuul',
    '🤹🏿‍♀' => 'jigéen juy sànni-kapte: xeesaayu der bu ñuul',
    '🧘🏻‍♂' => 'góor gu farankulaayu: xeesaayu der bu woyof',
    '🧘🏼‍♂' => 'góor gu farankulaayu: xeesaayu der bu xeereer',
    '🧘🏽‍♂' => 'góor gu farankulaayu: xeesaayu der bu yam',
    '🧘🏾‍♂' => 'góor gu farankulaayu: xeesaayu der bu xawa ñuul',
    '🧘🏿‍♂' => 'góor gu farankulaayu: xeesaayu der bu ñuul',
    '🧘🏻‍♀' => 'jigéen ju farankulaayu: xeesaayu der bu woyof',
    '🧘🏼‍♀' => 'jigéen ju farankulaayu: xeesaayu der bu xeereer',
    '🧘🏽‍♀' => 'jigéen ju farankulaayu: xeesaayu der bu yam',
    '🧘🏾‍♀' => 'jigéen ju farankulaayu: xeesaayu der bu xawa ñuul',
    '🧘🏿‍♀' => 'jigéen ju farankulaayu: xeesaayu der bu ñuul',
    '👨‍👦' => 'bokk famiy: góor, xale bu góor',
    '👨‍👧' => 'bokk famiy: góor, xale bu jigéen',
    '👩‍👦' => 'bokk famiy: jigéen, xale bu góor',
    '👩‍👧' => 'bokk famiy: jigéen, xale bu jigéen',
    '😶‍🌫' => 'kanam ci niir yi',
    '😮‍💨' => 'kanam guy nooyi',
    '🙂‍↕' => 'yëngal sa bop ci anam gu taxaw',
    '😵‍💫' => 'kanam gu am ay gêt yu rod',
    '❤‍🔥' => 'xolu safara',
    '❤‍🩹' => 'xol buy defar',
    '👁‍🗨' => 'bët ci rëddu-bind-wax',
    '👱‍♂' => 'góor gu am karaw gu mboq',
    '👱‍♀' => 'karaw gu am kawar gu mboq jigéen',
    '🙍‍♂' => 'góor aj-yéen',
    '🙍‍♀' => 'jigéen aj-yéen',
    '🙎‍♂' => 'góor puucatu',
    '🙎‍♀' => 'jigéen puucatu',
    '🙅‍♂' => 'góor buy liyaar Déet',
    '🙅‍♀' => 'jigéen juy liyaar Déet',
    '🙆‍♂' => 'góor buy liyaar waaw-kay',
    '🙆‍♀' => 'jigéen juy liyaar waaw-kay',
    '💁‍♂' => 'góor loxo jàppale',
    '💁‍♀' => 'jigéen loxo jàppale',
    '🙋‍♂' => 'góor yëkkati loxo',
    '🙋‍♀' => 'jigéen yëkkati loxo',
    '🙇‍♂' => 'góor sujjóotal',
    '🙇‍♀' => 'jigéen sujjóotal',
    '🤦‍♂' => 'góor gu taf loxo ci kanamam',
    '🤦‍♀' => 'ju taf loxo ci kanamam',
    '🤷‍♂' => 'góor aj mbagg',
    '🤷‍♀' => 'jigéen aj mbagg',
    '👨‍⚕' => 'fajkat bu góor',
    '👩‍⚕' => 'fajkat bu jigéen',
    '👨‍🎓' => 'ndongo bu góor',
    '👩‍🎓' => 'ndongo lu jigéen',
    '👨‍🏫' => 'jàngaletkat bu góor',
    '👩‍🏫' => 'jàngalekat bu jigéen',
    '👨‍⚖' => 'àttekat góor',
    '👩‍⚖' => 'àttekat bu jigéen',
    '👨‍🌾' => 'baykat bu góor',
    '👩‍🌾' => 'baykat bu jigéen',
    '👨‍🍳' => 'toggkat góor',
    '👩‍🍳' => 'toggkat bu jigéen',
    '👨‍🔧' => 'mekaniyee bu góor',
    '👩‍🔧' => 'jigéen mekanik',
    '👨‍🏭' => 'liggéeykatu isin bu góor',
    '👩‍🏭' => 'jigéen juy liggéeykat ci isin',
    '👨‍💼' => 'kuy liggéey ci biro',
    '👩‍💼' => 'jigéen biro liggéeykat',
    '👨‍🔬' => 'xaralakat bu góor',
    '👩‍🔬' => 'jigéen wu-xarala',
    '👨‍💻' => 'góor teknolosist',
    '👩‍💻' => 'jigéen teknolosist',
    '👨‍🎤' => 'góor waykat',
    '👩‍🎤' => 'jigéen waykat',
    '👨‍🎨' => 'artist bu góor',
    '👩‍🎨' => 'artist bu jigéen',
    '👨‍✈' => 'góor piloot',
    '👩‍✈' => 'piloot bu jigéen',
    '👨‍🚀' => 'astronot bu góor',
    '👩‍🚀' => 'astronot bu jigéen',
    '👨‍🚒' => 'sapër bu góor',
    '👩‍🚒' => 'pompiyee bu jigéen',
    '👮‍♂' => 'góor poliis liggéeykat bu góor',
    '👮‍♀' => 'polisiyee bu jigéen',
    '🕵‍♂' => 'góor detektif',
    '🕵‍♀' => 'jigéen detektif',
    '💂‍♂' => 'góor guy wattu',
    '💂‍♀' => 'jigéen juy wattu',
    '👷‍♂' => 'góor tabax liggéeykat',
    '👷‍♀' => 'jigéen tabax liggéeykat',
    '👳‍♂' => 'góor gu kaalawu',
    '👳‍♀' => 'jigéen ju kaalawu',
    '🧙‍♂' => 'mage bu góor',
    '🧙‍♀' => 'mage bu jigéen',
    '🧚‍♂' => 'fee bu góor',
    '🧚‍♀' => 'fee bu jigéen',
    '🧛‍♂' => 'wàmpiir bu góor',
    '🧛‍♀' => 'wàmpiir bu jigéen',
    '🧜‍♂' => 'sireen bu góor',
    '🧜‍♀' => 'sireen',
    '🧝‍♂' => 'elfe bu góor',
    '🧝‍♀' => 'elfe bu jigéen',
    '🧞‍♂' => 'jinne ju góor',
    '🧞‍♀' => 'jinne ju jigéen',
    '🧟‍♂' => 'zombi bu góor',
    '🧟‍♀' => 'zombi bu jigéen',
    '💆‍♂' => 'góor bu ñuy dàmp',
    '💆‍♀' => 'jigéen bu ñuy dàmp',
    '💇‍♂' => 'góor bu ñuy wat',
    '💇‍♀' => 'jigéen bu ñuy wat',
    '🚶‍♂' => 'góor dox',
    '🚶‍♀' => 'jigéen dox',
    '🏃‍♂' => 'góor daw',
    '🏃‍♀' => 'jigéen daw',
    '👯‍♂' => 'góorak noppi lëks suwaare',
    '👯‍♀' => 'jigéen ak noppi lëks suwaare',
    '🧖‍♂' => 'góor ci néegu wapër',
    '🧖‍♀' => 'jigéen ci néegu wapër',
    '🧗‍♂' => 'góor guy yéeg',
    '🧗‍♀' => 'jigéen juy yéeg',
    '🏌‍♂' => 'góor guy golf',
    '🏌‍♀' => 'jigéen juy golf',
    '🏄‍♂' => 'góor guy sërfe',
    '🏄‍♀' => 'jigéen juy sërfe',
    '🚣‍♂' => 'góor guy joow gaal',
    '🚣‍♀' => 'jigéen juy joow gaal',
    '🏊‍♂' => 'góor guy féey',
    '🏊‍♀' => 'jigéen juy féey',
    '⛹‍♂' => 'góor guy bondeel bal',
    '⛹‍♀' => 'jigéen juy bondeel bal',
    '🏋‍♂' => 'góor guy yëkkati lu diis',
    '🏋‍♀' => 'jigéen juy yëkkati lu diis',
    '🚴‍♂' => 'góor guy dawal welo',
    '🚴‍♀' => 'jigéen juy dawal welo',
    '🚵‍♂' => 'góor guy dawal welo ci montaañ',
    '🚵‍♀' => 'jigéen juy dawal welo ci montaañ',
    '🤸‍♂' => 'góor guy pëno-sareet',
    '🤸‍♀' => 'jigéen juy pëno-sareet',
    '🤼‍♂' => 'góor guy bëre',
    '🤼‍♀' => 'jigéen juy bëre',
    '🤽‍♂' => 'góor guy polo ci ndox',
    '🤽‍♀' => 'jigéen juy polo ci ndox',
    '🤾‍♂' => 'góor guy handball',
    '🤾‍♀' => 'jigéen juy handball',
    '🤹‍♂' => 'góor guy sànni-kapte',
    '🤹‍♀' => 'jigéen juy sànni-kapte',
    '🧘‍♂' => 'góor gu farankulaayu',
    '🧘‍♀' => 'jigéen ju farankulaayu',
    '🏳‍🌈' => 'raaya xon',
    '👋🏻' => 'tàllal loxo: xeesaayu der bu woyof',
    '👋🏼' => 'tàllal loxo: xeesaayu der bu xeereer',
    '👋🏽' => 'tàllal loxo: xeesaayu der bu yam',
    '👋🏾' => 'tàllal loxo: xeesaayu der bu xawa ñuul',
    '👋🏿' => 'tàllal loxo: xeesaayu der bu ñuul',
    '🤚🏻' => 'ginaawu loxo bu jog: xeesaayu der bu woyof',
    '🤚🏼' => 'ginaawu loxo bu jog: xeesaayu der bu xeereer',
    '🤚🏽' => 'ginaawu loxo bu jog: xeesaayu der bu yam',
    '🤚🏾' => 'ginaawu loxo bu jog: xeesaayu der bu xawa ñuul',
    '🤚🏿' => 'ginaawu loxo bu jog: xeesaayu der bu ñuul',
    '🖐🏻' => 'buñ yëkkati loxo ak baaraam yuñ tàllal: xeesaayu der bu woyof',
    '🖐🏼' => 'buñ yëkkati loxo ak baaraam yuñ tàllal: xeesaayu der bu xeereer',
    '🖐🏽' => 'buñ yëkkati loxo ak baaraam yuñ tàllal: xeesaayu der bu yam',
    '🖐🏾' => 'buñ yëkkati loxo ak baaraam yuñ tàllal: xeesaayu der bu xawa ñuul',
    '🖐🏿' => 'buñ yëkkati loxo ak baaraam yuñ tàllal: xeesaayu der bu ñuul',
    '✋🏻' => 'loxo bu jog: xeesaayu der bu woyof',
    '✋🏼' => 'loxo bu jog: xeesaayu der bu xeereer',
    '✋🏽' => 'loxo bu jog: xeesaayu der bu yam',
    '✋🏾' => 'loxo bu jog: xeesaayu der bu xawa ñuul',
    '✋🏿' => 'loxo bu jog: xeesaayu der bu ñuul',
    '🖖🏻' => 'loxo xaajale ñeenti baaraam: xeesaayu der bu woyof',
    '🖖🏼' => 'loxo xaajale ñeenti baaraam: xeesaayu der bu xeereer',
    '🖖🏽' => 'loxo xaajale ñeenti baaraam: xeesaayu der bu yam',
    '🖖🏾' => 'loxo xaajale ñeenti baaraam: xeesaayu der bu xawa ñuul',
    '🖖🏿' => 'loxo xaajale ñeenti baaraam: xeesaayu der bu ñuul',
    '👌🏻' => 'laxo waaw-kay: xeesaayu der bu woyof',
    '👌🏼' => 'laxo waaw-kay: xeesaayu der bu xeereer',
    '👌🏽' => 'laxo waaw-kay: xeesaayu der bu yam',
    '👌🏾' => 'laxo waaw-kay: xeesaayu der bu xawa ñuul',
    '👌🏿' => 'laxo waaw-kay: xeesaayu der bu ñuul',
    '🤌🏻' => 'dompat baaraam: xeesaayu der bu woyof',
    '🤌🏼' => 'dompat baaraam: xeesaayu der bu xeereer',
    '🤌🏽' => 'dompat baaraam: xeesaayu der bu yam',
    '🤌🏾' => 'dompat baaraam: xeesaayu der bu xawa ñuul',
    '🤌🏿' => 'dompat baaraam: xeesaayu der bu ñuul',
    '✌🏻' => 'loxo ndam: xeesaayu der bu woyof',
    '✌🏼' => 'loxo ndam: xeesaayu der bu xeereer',
    '✌🏽' => 'loxo ndam: xeesaayu der bu yam',
    '✌🏾' => 'loxo ndam: xeesaayu der bu xawa ñuul',
    '✌🏿' => 'loxo ndam: xeesaayu der bu ñuul',
    '🤞🏻' => 'laxasante ñaari baaraam: xeesaayu der bu woyof',
    '🤞🏼' => 'laxasante ñaari baaraam: xeesaayu der bu xeereer',
    '🤞🏽' => 'laxasante ñaari baaraam: xeesaayu der bu yam',
    '🤞🏾' => 'laxasante ñaari baaraam: xeesaayu der bu xawa ñuul',
    '🤞🏿' => 'laxasante ñaari baaraam: xeesaayu der bu ñuul',
    '🤟🏻' => 'liyaar mbëggeel: xeesaayu der bu woyof',
    '🤟🏼' => 'liyaar mbëggeel: xeesaayu der bu xeereer',
    '🤟🏽' => 'liyaar mbëggeel: xeesaayu der bu yam',
    '🤟🏾' => 'liyaar mbëggeel: xeesaayu der bu xawa ñuul',
    '🤟🏿' => 'liyaar mbëggeel: xeesaayu der bu ñuul',
    '🤘🏻' => 'loxo def màndarga béjjen: xeesaayu der bu woyof',
    '🤘🏼' => 'loxo def màndarga béjjen: xeesaayu der bu xeereer',
    '🤘🏽' => 'loxo def màndarga béjjen: xeesaayu der bu yam',
    '🤘🏾' => 'loxo def màndarga béjjen: xeesaayu der bu xawa ñuul',
    '🤘🏿' => 'loxo def màndarga béjjen: xeesaayu der bu ñuul',
    '🤙🏻' => 'loxo nanga ma woo: xeesaayu der bu woyof',
    '🤙🏼' => 'loxo nanga ma woo: xeesaayu der bu xeereer',
    '🤙🏽' => 'loxo nanga ma woo: xeesaayu der bu yam',
    '🤙🏾' => 'loxo nanga ma woo: xeesaayu der bu xawa ñuul',
    '🤙🏿' => 'loxo nanga ma woo: xeesaayu der bu ñuul',
    '👈🏻' => 'ginaaw loxo buy joxoñ càmmoñ: xeesaayu der bu woyof',
    '👈🏼' => 'ginaaw loxo buy joxoñ càmmoñ: xeesaayu der bu xeereer',
    '👈🏽' => 'ginaaw loxo buy joxoñ càmmoñ: xeesaayu der bu yam',
    '👈🏾' => 'ginaaw loxo buy joxoñ càmmoñ: xeesaayu der bu xawa ñuul',
    '👈🏿' => 'ginaaw loxo buy joxoñ càmmoñ: xeesaayu der bu ñuul',
    '👉🏻' => 'ginaaw loxo buy joxoñ ndijoor: xeesaayu der bu woyof',
    '👉🏼' => 'ginaaw loxo buy joxoñ ndijoor: xeesaayu der bu xeereer',
    '👉🏽' => 'ginaaw loxo buy joxoñ ndijoor: xeesaayu der bu yam',
    '👉🏾' => 'ginaaw loxo buy joxoñ ndijoor: xeesaayu der bu xawa ñuul',
    '👉🏿' => 'ginaaw loxo buy joxoñ ndijoor: xeesaayu der bu ñuul',
    '👆🏻' => 'ginaaw loxo buy joxoñ ci kaw: xeesaayu der bu woyof',
    '👆🏼' => 'ginaaw loxo buy joxoñ ci kaw: xeesaayu der bu xeereer',
    '👆🏽' => 'ginaaw loxo buy joxoñ ci kaw: xeesaayu der bu yam',
    '👆🏾' => 'ginaaw loxo buy joxoñ ci kaw: xeesaayu der bu xawa ñuul',
    '👆🏿' => 'ginaaw loxo buy joxoñ ci kaw: xeesaayu der bu ñuul',
    '🖕🏻' => 'baaraamu digg: xeesaayu der bu woyof',
    '🖕🏼' => 'baaraamu digg: xeesaayu der bu xeereer',
    '🖕🏽' => 'baaraamu digg: xeesaayu der bu yam',
    '🖕🏾' => 'baaraamu digg: xeesaayu der bu xawa ñuul',
    '🖕🏿' => 'baaraamu digg: xeesaayu der bu ñuul',
    '👇🏻' => 'ginaaw loxo buy joxoñ ci suuf: xeesaayu der bu woyof',
    '👇🏼' => 'ginaaw loxo buy joxoñ ci suuf: xeesaayu der bu xeereer',
    '👇🏽' => 'ginaaw loxo buy joxoñ ci suuf: xeesaayu der bu yam',
    '👇🏾' => 'ginaaw loxo buy joxoñ ci suuf: xeesaayu der bu xawa ñuul',
    '👇🏿' => 'ginaaw loxo buy joxoñ ci suuf: xeesaayu der bu ñuul',
    '☝🏻' => 'baaraamu joxoñ buy joxoñ ci kaw: xeesaayu der bu woyof',
    '☝🏼' => 'baaraamu joxoñ buy joxoñ ci kaw: xeesaayu der bu xeereer',
    '☝🏽' => 'baaraamu joxoñ buy joxoñ ci kaw: xeesaayu der bu yam',
    '☝🏾' => 'baaraamu joxoñ buy joxoñ ci kaw: xeesaayu der bu xawa ñuul',
    '☝🏿' => 'baaraamu joxoñ buy joxoñ ci kaw: xeesaayu der bu ñuul',
    '👍🏻' => 'baaraamu waaw: xeesaayu der bu woyof',
    '👍🏼' => 'baaraamu waaw: xeesaayu der bu xeereer',
    '👍🏽' => 'baaraamu waaw: xeesaayu der bu yam',
    '👍🏾' => 'baaraamu waaw: xeesaayu der bu xawa ñuul',
    '👍🏿' => 'baaraamu waaw: xeesaayu der bu ñuul',
    '👎🏻' => 'baaraamu déet: xeesaayu der bu woyof',
    '👎🏼' => 'baaraamu déet: xeesaayu der bu xeereer',
    '👎🏽' => 'baaraamu déet: xeesaayu der bu yam',
    '👎🏾' => 'baaraamu déet: xeesaayu der bu xawa ñuul',
    '👎🏿' => 'baaraamu déet: xeesaayu der bu ñuul',
    '✊🏻' => 'kurfañ bu jog: xeesaayu der bu woyof',
    '✊🏼' => 'kurfañ bu jog: xeesaayu der bu xeereer',
    '✊🏽' => 'kurfañ bu jog: xeesaayu der bu yam',
    '✊🏾' => 'kurfañ bu jog: xeesaayu der bu xawa ñuul',
    '✊🏿' => 'kurfañ bu jog: xeesaayu der bu ñuul',
    '👊🏻' => 'kurfañ buy ñëw: xeesaayu der bu woyof',
    '👊🏼' => 'kurfañ buy ñëw: xeesaayu der bu xeereer',
    '👊🏽' => 'kurfañ buy ñëw: xeesaayu der bu yam',
    '👊🏾' => 'kurfañ buy ñëw: xeesaayu der bu xawa ñuul',
    '👊🏿' => 'kurfañ buy ñëw: xeesaayu der bu ñuul',
    '🤛🏻' => 'kurfañu càmmoñ: xeesaayu der bu woyof',
    '🤛🏼' => 'kurfañu càmmoñ: xeesaayu der bu xeereer',
    '🤛🏽' => 'kurfañu càmmoñ: xeesaayu der bu yam',
    '🤛🏾' => 'kurfañu càmmoñ: xeesaayu der bu xawa ñuul',
    '🤛🏿' => 'kurfañu càmmoñ: xeesaayu der bu ñuul',
    '🤜🏻' => 'kurfañu ndijoor: xeesaayu der bu woyof',
    '🤜🏼' => 'kurfañu ndijoor: xeesaayu der bu xeereer',
    '🤜🏽' => 'kurfañu ndijoor: xeesaayu der bu yam',
    '🤜🏾' => 'kurfañu ndijoor: xeesaayu der bu xawa ñuul',
    '🤜🏿' => 'kurfañu ndijoor: xeesaayu der bu ñuul',
    '👏🏻' => 'loxo yuy tàccu: xeesaayu der bu woyof',
    '👏🏼' => 'loxo yuy tàccu: xeesaayu der bu xeereer',
    '👏🏽' => 'loxo yuy tàccu: xeesaayu der bu yam',
    '👏🏾' => 'loxo yuy tàccu: xeesaayu der bu xawa ñuul',
    '👏🏿' => 'loxo yuy tàccu: xeesaayu der bu ñuul',
    '🙌🏻' => 'yëkkati ay loxo: xeesaayu der bu woyof',
    '🙌🏼' => 'yëkkati ay loxo: xeesaayu der bu xeereer',
    '🙌🏽' => 'yëkkati ay loxo: xeesaayu der bu yam',
    '🙌🏾' => 'yëkkati ay loxo: xeesaayu der bu xawa ñuul',
    '🙌🏿' => 'yëkkati ay loxo: xeesaayu der bu ñuul',
    '👐🏻' => 'loxo yu ubbeeku: xeesaayu der bu woyof',
    '👐🏼' => 'loxo yu ubbeeku: xeesaayu der bu xeereer',
    '👐🏽' => 'loxo yu ubbeeku: xeesaayu der bu yam',
    '👐🏾' => 'loxo yu ubbeeku: xeesaayu der bu xawa ñuul',
    '👐🏿' => 'loxo yu ubbeeku: xeesaayu der bu ñuul',
    '🤲🏻' => 'tallal loxo ñaan: xeesaayu der bu woyof',
    '🤲🏼' => 'tallal loxo ñaan: xeesaayu der bu xeereer',
    '🤲🏽' => 'tallal loxo ñaan: xeesaayu der bu yam',
    '🤲🏾' => 'tallal loxo ñaan: xeesaayu der bu xawa ñuul',
    '🤲🏿' => 'tallal loxo ñaan: xeesaayu der bu ñuul',
    '🤝🏻' => 'joxante loxo: xeesaayu der bu woyof',
    '🤝🏼' => 'joxante loxo: xeesaayu der bu xeereer',
    '🤝🏽' => 'joxante loxo: xeesaayu der bu yam',
    '🤝🏾' => 'joxante loxo: xeesaayu der bu xawa ñuul',
    '🤝🏿' => 'joxante loxo: xeesaayu der bu ñuul',
    '🙏🏻' => 'lem ay loxo: xeesaayu der bu woyof',
    '🙏🏼' => 'lem ay loxo: xeesaayu der bu xeereer',
    '🙏🏽' => 'lem ay loxo: xeesaayu der bu yam',
    '🙏🏾' => 'lem ay loxo: xeesaayu der bu xawa ñuul',
    '🙏🏿' => 'lem ay loxo: xeesaayu der bu ñuul',
    '✍🏻' => 'loxo buy bind: xeesaayu der bu woyof',
    '✍🏼' => 'loxo buy bind: xeesaayu der bu xeereer',
    '✍🏽' => 'loxo buy bind: xeesaayu der bu yam',
    '✍🏾' => 'loxo buy bind: xeesaayu der bu xawa ñuul',
    '✍🏿' => 'loxo buy bind: xeesaayu der bu ñuul',
    '💅🏻' => 'jakkal wew: xeesaayu der bu woyof',
    '💅🏼' => 'jakkal wew: xeesaayu der bu xeereer',
    '💅🏽' => 'jakkal wew: xeesaayu der bu yam',
    '💅🏾' => 'jakkal wew: xeesaayu der bu xawa ñuul',
    '💅🏿' => 'jakkal wew: xeesaayu der bu ñuul',
    '🤳🏻' => 'selfie: xeesaayu der bu woyof',
    '🤳🏼' => 'selfie: xeesaayu der bu xeereer',
    '🤳🏽' => 'selfie: xeesaayu der bu yam',
    '🤳🏾' => 'selfie: xeesaayu der bu xawa ñuul',
    '🤳🏿' => 'selfie: xeesaayu der bu ñuul',
    '💪🏻' => 'wane doole: xeesaayu der bu woyof',
    '💪🏼' => 'wane doole: xeesaayu der bu xeereer',
    '💪🏽' => 'wane doole: xeesaayu der bu yam',
    '💪🏾' => 'wane doole: xeesaayu der bu xawa ñuul',
    '💪🏿' => 'wane doole: xeesaayu der bu ñuul',
    '👂🏻' => 'nopp: xeesaayu der bu woyof',
    '👂🏼' => 'nopp: xeesaayu der bu xeereer',
    '👂🏽' => 'nopp: xeesaayu der bu yam',
    '👂🏾' => 'nopp: xeesaayu der bu xawa ñuul',
    '👂🏿' => 'nopp: xeesaayu der bu ñuul',
    '👃🏻' => 'bakkan: xeesaayu der bu woyof',
    '👃🏼' => 'bakkan: xeesaayu der bu xeereer',
    '👃🏽' => 'bakkan: xeesaayu der bu yam',
    '👃🏾' => 'bakkan: xeesaayu der bu xawa ñuul',
    '👃🏿' => 'bakkan: xeesaayu der bu ñuul',
    '👶🏻' => 'liir: xeesaayu der bu woyof',
    '👶🏼' => 'liir: xeesaayu der bu xeereer',
    '👶🏽' => 'liir: xeesaayu der bu yam',
    '👶🏾' => 'liir: xeesaayu der bu xawa ñuul',
    '👶🏿' => 'liir: xeesaayu der bu ñuul',
    '🧒🏻' => 'xale: xeesaayu der bu woyof',
    '🧒🏼' => 'xale: xeesaayu der bu xeereer',
    '🧒🏽' => 'xale: xeesaayu der bu yam',
    '🧒🏾' => 'xale: xeesaayu der bu xawa ñuul',
    '🧒🏿' => 'xale: xeesaayu der bu ñuul',
    '👦🏻' => 'xale bu góor: xeesaayu der bu woyof',
    '👦🏼' => 'xale bu góor: xeesaayu der bu xeereer',
    '👦🏽' => 'xale bu góor: xeesaayu der bu yam',
    '👦🏾' => 'xale bu góor: xeesaayu der bu xawa ñuul',
    '👦🏿' => 'xale bu góor: xeesaayu der bu ñuul',
    '👧🏻' => 'xale bu jigéen: xeesaayu der bu woyof',
    '👧🏼' => 'xale bu jigéen: xeesaayu der bu xeereer',
    '👧🏽' => 'xale bu jigéen: xeesaayu der bu yam',
    '👧🏾' => 'xale bu jigéen: xeesaayu der bu xawa ñuul',
    '👧🏿' => 'xale bu jigéen: xeesaayu der bu ñuul',
    '🧑🏻' => 'nit: xeesaayu der bu woyof',
    '🧑🏼' => 'nit: xeesaayu der bu xeereer',
    '🧑🏽' => 'nit: xeesaayu der bu yam',
    '🧑🏾' => 'nit: xeesaayu der bu xawa ñuul',
    '🧑🏿' => 'nit: xeesaayu der bu ñuul',
    '👱🏻' => 'nit ku karaw yu weex: xeesaayu der bu woyof',
    '👱🏼' => 'nit ku karaw yu weex: xeesaayu der bu xeereer',
    '👱🏽' => 'nit ku karaw yu weex: xeesaayu der bu yam',
    '👱🏾' => 'nit ku karaw yu weex: xeesaayu der bu xawa ñuul',
    '👱🏿' => 'nit ku karaw yu weex: xeesaayu der bu ñuul',
    '👨🏻' => 'góor: xeesaayu der bu woyof',
    '👨🏼' => 'góor: xeesaayu der bu xeereer',
    '👨🏽' => 'góor: xeesaayu der bu yam',
    '👨🏾' => 'góor: xeesaayu der bu xawa ñuul',
    '👨🏿' => 'góor: xeesaayu der bu ñuul',
    '🧔🏻' => 'nit am sikkim: xeesaayu der bu woyof',
    '🧔🏼' => 'nit am sikkim: xeesaayu der bu xeereer',
    '🧔🏽' => 'nit am sikkim: xeesaayu der bu yam',
    '🧔🏾' => 'nit am sikkim: xeesaayu der bu xawa ñuul',
    '🧔🏿' => 'nit am sikkim: xeesaayu der bu ñuul',
    '👩🏻' => 'jigéen: xeesaayu der bu woyof',
    '👩🏼' => 'jigéen: xeesaayu der bu xeereer',
    '👩🏽' => 'jigéen: xeesaayu der bu yam',
    '👩🏾' => 'jigéen: xeesaayu der bu xawa ñuul',
    '👩🏿' => 'jigéen: xeesaayu der bu ñuul',
    '🧓🏻' => 'mag mu gën a màgget: xeesaayu der bu woyof',
    '🧓🏼' => 'mag mu gën a màgget: xeesaayu der bu xeereer',
    '🧓🏽' => 'mag mu gën a màgget: xeesaayu der bu yam',
    '🧓🏾' => 'mag mu gën a màgget: xeesaayu der bu xawa ñuul',
    '🧓🏿' => 'mag mu gën a màgget: xeesaayu der bu ñuul',
    '👴🏻' => 'màgget gu góor: xeesaayu der bu woyof',
    '👴🏼' => 'màgget gu góor: xeesaayu der bu xeereer',
    '👴🏽' => 'màgget gu góor: xeesaayu der bu yam',
    '👴🏾' => 'màgget gu góor: xeesaayu der bu xawa ñuul',
    '👴🏿' => 'màgget gu góor: xeesaayu der bu ñuul',
    '👵🏻' => 'màgget gu jigéen: xeesaayu der bu woyof',
    '👵🏼' => 'màgget gu jigéen: xeesaayu der bu xeereer',
    '👵🏽' => 'màgget gu jigéen: xeesaayu der bu yam',
    '👵🏾' => 'màgget gu jigéen: xeesaayu der bu xawa ñuul',
    '👵🏿' => 'màgget gu jigéen: xeesaayu der bu ñuul',
    '🙍🏻' => 'nit ku yéen yi lemu: xeesaayu der bu woyof',
    '🙍🏼' => 'nit ku yéen yi lemu: xeesaayu der bu xeereer',
    '🙍🏽' => 'nit ku yéen yi lemu: xeesaayu der bu yam',
    '🙍🏾' => 'nit ku yéen yi lemu: xeesaayu der bu xawa ñuul',
    '🙍🏿' => 'nit ku yéen yi lemu: xeesaayu der bu ñuul',
    '🙎🏻' => 'nit kuy puucatu: xeesaayu der bu woyof',
    '🙎🏼' => 'nit kuy puucatu: xeesaayu der bu xeereer',
    '🙎🏽' => 'nit kuy puucatu: xeesaayu der bu yam',
    '🙎🏾' => 'nit kuy puucatu: xeesaayu der bu xawa ñuul',
    '🙎🏿' => 'nit kuy puucatu: xeesaayu der bu ñuul',
    '🙅🏻' => 'nit ku naan déedet: xeesaayu der bu woyof',
    '🙅🏼' => 'nit ku naan déedet: xeesaayu der bu xeereer',
    '🙅🏽' => 'nit ku naan déedet: xeesaayu der bu yam',
    '🙅🏾' => 'nit ku naan déedet: xeesaayu der bu xawa ñuul',
    '🙅🏿' => 'nit ku naan déedet: xeesaayu der bu ñuul',
    '🙆🏻' => 'nit ku naan waaw-kay: xeesaayu der bu woyof',
    '🙆🏼' => 'nit ku naan waaw-kay: xeesaayu der bu xeereer',
    '🙆🏽' => 'nit ku naan waaw-kay: xeesaayu der bu yam',
    '🙆🏾' => 'nit ku naan waaw-kay: xeesaayu der bu xawa ñuul',
    '🙆🏿' => 'nit ku naan waaw-kay: xeesaayu der bu ñuul',
    '💁🏻' => 'nit kuy joxee wet: xeesaayu der bu woyof',
    '💁🏼' => 'nit kuy joxee wet: xeesaayu der bu xeereer',
    '💁🏽' => 'nit kuy joxee wet: xeesaayu der bu yam',
    '💁🏾' => 'nit kuy joxee wet: xeesaayu der bu xawa ñuul',
    '💁🏿' => 'nit kuy joxee wet: xeesaayu der bu ñuul',
    '🙋🏻' => 'nit kuy yëkkati loxo: xeesaayu der bu woyof',
    '🙋🏼' => 'nit kuy yëkkati loxo: xeesaayu der bu xeereer',
    '🙋🏽' => 'nit kuy yëkkati loxo: xeesaayu der bu yam',
    '🙋🏾' => 'nit kuy yëkkati loxo: xeesaayu der bu xawa ñuul',
    '🙋🏿' => 'nit kuy yëkkati loxo: xeesaayu der bu ñuul',
    '🙇🏻' => 'nit kuy sëgg-nuyoo: xeesaayu der bu woyof',
    '🙇🏼' => 'nit kuy sëgg-nuyoo: xeesaayu der bu xeereer',
    '🙇🏽' => 'nit kuy sëgg-nuyoo: xeesaayu der bu yam',
    '🙇🏾' => 'nit kuy sëgg-nuyoo: xeesaayu der bu xawa ñuul',
    '🙇🏿' => 'nit kuy sëgg-nuyoo: xeesaayu der bu ñuul',
    '🤦🏻' => 'nit ku taf loxo ci kanamam: xeesaayu der bu woyof',
    '🤦🏼' => 'nit ku taf loxo ci kanamam: xeesaayu der bu xeereer',
    '🤦🏽' => 'nit ku taf loxo ci kanamam: xeesaayu der bu yam',
    '🤦🏾' => 'nit ku taf loxo ci kanamam: xeesaayu der bu xawa ñuul',
    '🤦🏿' => 'nit ku taf loxo ci kanamam: xeesaayu der bu ñuul',
    '🤷🏻' => 'nit ku aj mbaggam: xeesaayu der bu woyof',
    '🤷🏼' => 'nit ku aj mbaggam: xeesaayu der bu xeereer',
    '🤷🏽' => 'nit ku aj mbaggam: xeesaayu der bu yam',
    '🤷🏾' => 'nit ku aj mbaggam: xeesaayu der bu xawa ñuul',
    '🤷🏿' => 'nit ku aj mbaggam: xeesaayu der bu ñuul',
    '👮🏻' => 'polisiyee: xeesaayu der bu woyof',
    '👮🏼' => 'polisiyee: xeesaayu der bu xeereer',
    '👮🏽' => 'polisiyee: xeesaayu der bu yam',
    '👮🏾' => 'polisiyee: xeesaayu der bu xawa ñuul',
    '👮🏿' => 'polisiyee: xeesaayu der bu ñuul',
    '🕵🏻' => 'detektif: xeesaayu der bu woyof',
    '🕵🏼' => 'detektif: xeesaayu der bu xeereer',
    '🕵🏽' => 'detektif: xeesaayu der bu yam',
    '🕵🏾' => 'detektif: xeesaayu der bu xawa ñuul',
    '🕵🏿' => 'detektif: xeesaayu der bu ñuul',
    '💂🏻' => 'gardiñe: xeesaayu der bu woyof',
    '💂🏼' => 'gardiñe: xeesaayu der bu xeereer',
    '💂🏽' => 'gardiñe: xeesaayu der bu yam',
    '💂🏾' => 'gardiñe: xeesaayu der bu xawa ñuul',
    '💂🏿' => 'gardiñe: xeesaayu der bu ñuul',
    '👷🏻' => 'tabaxkat: xeesaayu der bu woyof',
    '👷🏼' => 'tabaxkat: xeesaayu der bu xeereer',
    '👷🏽' => 'tabaxkat: xeesaayu der bu yam',
    '👷🏾' => 'tabaxkat: xeesaayu der bu xawa ñuul',
    '👷🏿' => 'tabaxkat: xeesaayu der bu ñuul',
    '🤴🏻' => 'doomu-buur bu góor: xeesaayu der bu woyof',
    '🤴🏼' => 'doomu-buur bu góor: xeesaayu der bu xeereer',
    '🤴🏽' => 'doomu-buur bu góor: xeesaayu der bu yam',
    '🤴🏾' => 'doomu-buur bu góor: xeesaayu der bu xawa ñuul',
    '🤴🏿' => 'doomu-buur bu góor: xeesaayu der bu ñuul',
    '👸🏻' => 'doomu buur bu jigéen: xeesaayu der bu woyof',
    '👸🏼' => 'doomu buur bu jigéen: xeesaayu der bu xeereer',
    '👸🏽' => 'doomu buur bu jigéen: xeesaayu der bu yam',
    '👸🏾' => 'doomu buur bu jigéen: xeesaayu der bu xawa ñuul',
    '👸🏿' => 'doomu buur bu jigéen: xeesaayu der bu ñuul',
    '👳🏻' => 'nit ku kaalawu: xeesaayu der bu woyof',
    '👳🏼' => 'nit ku kaalawu: xeesaayu der bu xeereer',
    '👳🏽' => 'nit ku kaalawu: xeesaayu der bu yam',
    '👳🏾' => 'nit ku kaalawu: xeesaayu der bu xawa ñuul',
    '👳🏿' => 'nit ku kaalawu: xeesaayu der bu ñuul',
    '👲🏻' => 'góor gu sol mbaxane sinuwaa: xeesaayu der bu woyof',
    '👲🏼' => 'góor gu sol mbaxane sinuwaa: xeesaayu der bu xeereer',
    '👲🏽' => 'góor gu sol mbaxane sinuwaa: xeesaayu der bu yam',
    '👲🏾' => 'góor gu sol mbaxane sinuwaa: xeesaayu der bu xawa ñuul',
    '👲🏿' => 'góor gu sol mbaxane sinuwaa: xeesaayu der bu ñuul',
    '🧕🏻' => 'jigéen ju musóoru: xeesaayu der bu woyof',
    '🧕🏼' => 'jigéen ju musóoru: xeesaayu der bu xeereer',
    '🧕🏽' => 'jigéen ju musóoru: xeesaayu der bu yam',
    '🧕🏾' => 'jigéen ju musóoru: xeesaayu der bu xawa ñuul',
    '🧕🏿' => 'jigéen ju musóoru: xeesaayu der bu ñuul',
    '🤵🏻' => 'góor gu sol kostim: xeesaayu der bu woyof',
    '🤵🏼' => 'góor gu sol kostim: xeesaayu der bu xeereer',
    '🤵🏽' => 'góor gu sol kostim: xeesaayu der bu yam',
    '🤵🏾' => 'góor gu sol kostim: xeesaayu der bu xawa ñuul',
    '🤵🏿' => 'góor gu sol kostim: xeesaayu der bu ñuul',
    '👰🏻' => 'séet bu móoru: xeesaayu der bu woyof',
    '👰🏼' => 'séet bu móoru: xeesaayu der bu xeereer',
    '👰🏽' => 'séet bu móoru: xeesaayu der bu yam',
    '👰🏾' => 'séet bu móoru: xeesaayu der bu xawa ñuul',
    '👰🏿' => 'séet bu móoru: xeesaayu der bu ñuul',
    '🤰🏻' => 'jigéen ju ëmb: xeesaayu der bu woyof',
    '🤰🏼' => 'jigéen ju ëmb: xeesaayu der bu xeereer',
    '🤰🏽' => 'jigéen ju ëmb: xeesaayu der bu yam',
    '🤰🏾' => 'jigéen ju ëmb: xeesaayu der bu xawa ñuul',
    '🤰🏿' => 'jigéen ju ëmb: xeesaayu der bu ñuul',
    '🤱🏻' => 'nàppalee ween: xeesaayu der bu woyof',
    '🤱🏼' => 'nàppalee ween: xeesaayu der bu xeereer',
    '🤱🏽' => 'nàppalee ween: xeesaayu der bu yam',
    '🤱🏾' => 'nàppalee ween: xeesaayu der bu xawa ñuul',
    '🤱🏿' => 'nàppalee ween: xeesaayu der bu ñuul',
    '👼🏻' => 'liiru malaaka: xeesaayu der bu woyof',
    '👼🏼' => 'liiru malaaka: xeesaayu der bu xeereer',
    '👼🏽' => 'liiru malaaka: xeesaayu der bu yam',
    '👼🏾' => 'liiru malaaka: xeesaayu der bu xawa ñuul',
    '👼🏿' => 'liiru malaaka: xeesaayu der bu ñuul',
    '🎅🏻' => 'Pere nowel: xeesaayu der bu woyof',
    '🎅🏼' => 'Pere nowel: xeesaayu der bu xeereer',
    '🎅🏽' => 'Pere nowel: xeesaayu der bu yam',
    '🎅🏾' => 'Pere nowel: xeesaayu der bu xawa ñuul',
    '🎅🏿' => 'Pere nowel: xeesaayu der bu ñuul',
    '🤶🏻' => 'meer nowel: xeesaayu der bu woyof',
    '🤶🏼' => 'meer nowel: xeesaayu der bu xeereer',
    '🤶🏽' => 'meer nowel: xeesaayu der bu yam',
    '🤶🏾' => 'meer nowel: xeesaayu der bu xawa ñuul',
    '🤶🏿' => 'meer nowel: xeesaayu der bu ñuul',
    '🧙🏻' => 'mage: xeesaayu der bu woyof',
    '🧙🏼' => 'mage: xeesaayu der bu xeereer',
    '🧙🏽' => 'mage: xeesaayu der bu yam',
    '🧙🏾' => 'mage: xeesaayu der bu xawa ñuul',
    '🧙🏿' => 'mage: xeesaayu der bu ñuul',
    '🧚🏻' => 'fee: xeesaayu der bu woyof',
    '🧚🏼' => 'fee: xeesaayu der bu xeereer',
    '🧚🏽' => 'fee: xeesaayu der bu yam',
    '🧚🏾' => 'fee: xeesaayu der bu xawa ñuul',
    '🧚🏿' => 'fee: xeesaayu der bu ñuul',
    '🧛🏻' => 'wàmpiir: xeesaayu der bu woyof',
    '🧛🏼' => 'wàmpiir: xeesaayu der bu xeereer',
    '🧛🏽' => 'wàmpiir: xeesaayu der bu yam',
    '🧛🏾' => 'wàmpiir: xeesaayu der bu xawa ñuul',
    '🧛🏿' => 'wàmpiir: xeesaayu der bu ñuul',
    '🧜🏻' => 'sireen bu nit: xeesaayu der bu woyof',
    '🧜🏼' => 'sireen bu nit: xeesaayu der bu xeereer',
    '🧜🏽' => 'sireen bu nit: xeesaayu der bu yam',
    '🧜🏾' => 'sireen bu nit: xeesaayu der bu xawa ñuul',
    '🧜🏿' => 'sireen bu nit: xeesaayu der bu ñuul',
    '🧝🏻' => 'elfe: xeesaayu der bu woyof',
    '🧝🏼' => 'elfe: xeesaayu der bu xeereer',
    '🧝🏽' => 'elfe: xeesaayu der bu yam',
    '🧝🏾' => 'elfe: xeesaayu der bu xawa ñuul',
    '🧝🏿' => 'elfe: xeesaayu der bu ñuul',
    '💆🏻' => 'nit ku ñuy dàmp: xeesaayu der bu woyof',
    '💆🏼' => 'nit ku ñuy dàmp: xeesaayu der bu xeereer',
    '💆🏽' => 'nit ku ñuy dàmp: xeesaayu der bu yam',
    '💆🏾' => 'nit ku ñuy dàmp: xeesaayu der bu xawa ñuul',
    '💆🏿' => 'nit ku ñuy dàmp: xeesaayu der bu ñuul',
    '💇🏻' => 'nit kuy watu: xeesaayu der bu woyof',
    '💇🏼' => 'nit kuy watu: xeesaayu der bu xeereer',
    '💇🏽' => 'nit kuy watu: xeesaayu der bu yam',
    '💇🏾' => 'nit kuy watu: xeesaayu der bu xawa ñuul',
    '💇🏿' => 'nit kuy watu: xeesaayu der bu ñuul',
    '🚶🏻' => 'nit kuy dox: xeesaayu der bu woyof',
    '🚶🏼' => 'nit kuy dox: xeesaayu der bu xeereer',
    '🚶🏽' => 'nit kuy dox: xeesaayu der bu yam',
    '🚶🏾' => 'nit kuy dox: xeesaayu der bu xawa ñuul',
    '🚶🏿' => 'nit kuy dox: xeesaayu der bu ñuul',
    '🏃🏻' => 'nit kuy daw: xeesaayu der bu woyof',
    '🏃🏼' => 'nit kuy daw: xeesaayu der bu xeereer',
    '🏃🏽' => 'nit kuy daw: xeesaayu der bu yam',
    '🏃🏾' => 'nit kuy daw: xeesaayu der bu xawa ñuul',
    '🏃🏿' => 'nit kuy daw: xeesaayu der bu ñuul',
    '💃🏻' => 'jigéen juy fecc: xeesaayu der bu woyof',
    '💃🏼' => 'jigéen juy fecc: xeesaayu der bu xeereer',
    '💃🏽' => 'jigéen juy fecc: xeesaayu der bu yam',
    '💃🏾' => 'jigéen juy fecc: xeesaayu der bu xawa ñuul',
    '💃🏿' => 'jigéen juy fecc: xeesaayu der bu ñuul',
    '🕺🏻' => 'góor guy fecc: xeesaayu der bu woyof',
    '🕺🏼' => 'góor guy fecc: xeesaayu der bu xeereer',
    '🕺🏽' => 'góor guy fecc: xeesaayu der bu yam',
    '🕺🏾' => 'góor guy fecc: xeesaayu der bu xawa ñuul',
    '🕺🏿' => 'góor guy fecc: xeesaayu der bu ñuul',
    '🕴🏻' => 'góor ci bisnes kostim lewitasiyoŋ: xeesaayu der bu woyof',
    '🕴🏼' => 'góor ci bisnes kostim lewitasiyoŋ: xeesaayu der bu xeereer',
    '🕴🏽' => 'góor ci bisnes kostim lewitasiyoŋ: xeesaayu der bu yam',
    '🕴🏾' => 'góor ci bisnes kostim lewitasiyoŋ: xeesaayu der bu xawa ñuul',
    '🕴🏿' => 'góor ci bisnes kostim lewitasiyoŋ: xeesaayu der bu ñuul',
    '👯🏻' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu woyof',
    '👯🏼' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu xeereer',
    '👯🏽' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu yam',
    '👯🏾' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu xawa ñuul',
    '👯🏿' => 'nit ñuy fecc, ak noppi lëk: xeesaayu der bu ñuul',
    '🧖🏻' => 'nit ci néegu wapër: xeesaayu der bu woyof',
    '🧖🏼' => 'nit ci néegu wapër: xeesaayu der bu xeereer',
    '🧖🏽' => 'nit ci néegu wapër: xeesaayu der bu yam',
    '🧖🏾' => 'nit ci néegu wapër: xeesaayu der bu xawa ñuul',
    '🧖🏿' => 'nit ci néegu wapër: xeesaayu der bu ñuul',
    '🧗🏻' => 'nit kuy yéeg: xeesaayu der bu woyof',
    '🧗🏼' => 'nit kuy yéeg: xeesaayu der bu xeereer',
    '🧗🏽' => 'nit kuy yéeg: xeesaayu der bu yam',
    '🧗🏾' => 'nit kuy yéeg: xeesaayu der bu xawa ñuul',
    '🧗🏿' => 'nit kuy yéeg: xeesaayu der bu ñuul',
    '🏇🏻' => 'kursu fas: xeesaayu der bu woyof',
    '🏇🏼' => 'kursu fas: xeesaayu der bu xeereer',
    '🏇🏽' => 'kursu fas: xeesaayu der bu yam',
    '🏇🏾' => 'kursu fas: xeesaayu der bu xawa ñuul',
    '🏇🏿' => 'kursu fas: xeesaayu der bu ñuul',
    '🏂🏻' => 'kuy pateŋ ci nees: xeesaayu der bu woyof',
    '🏂🏼' => 'kuy pateŋ ci nees: xeesaayu der bu xeereer',
    '🏂🏽' => 'kuy pateŋ ci nees: xeesaayu der bu yam',
    '🏂🏾' => 'kuy pateŋ ci nees: xeesaayu der bu xawa ñuul',
    '🏂🏿' => 'kuy pateŋ ci nees: xeesaayu der bu ñuul',
    '🏌🏻' => 'nit kuy golf: xeesaayu der bu woyof',
    '🏌🏼' => 'nit kuy golf: xeesaayu der bu xeereer',
    '🏌🏽' => 'nit kuy golf: xeesaayu der bu yam',
    '🏌🏾' => 'nit kuy golf: xeesaayu der bu xawa ñuul',
    '🏌🏿' => 'nit kuy golf: xeesaayu der bu ñuul',
    '🏄🏻' => 'nit kuy sërfe: xeesaayu der bu woyof',
    '🏄🏼' => 'nit kuy sërfe: xeesaayu der bu xeereer',
    '🏄🏽' => 'nit kuy sërfe: xeesaayu der bu yam',
    '🏄🏾' => 'nit kuy sërfe: xeesaayu der bu xawa ñuul',
    '🏄🏿' => 'nit kuy sërfe: xeesaayu der bu ñuul',
    '🚣🏻' => 'nit joow gaal: xeesaayu der bu woyof',
    '🚣🏼' => 'nit joow gaal: xeesaayu der bu xeereer',
    '🚣🏽' => 'nit joow gaal: xeesaayu der bu yam',
    '🚣🏾' => 'nit joow gaal: xeesaayu der bu xawa ñuul',
    '🚣🏿' => 'nit joow gaal: xeesaayu der bu ñuul',
    '🏊🏻' => 'nit kuy féey: xeesaayu der bu woyof',
    '🏊🏼' => 'nit kuy féey: xeesaayu der bu xeereer',
    '🏊🏽' => 'nit kuy féey: xeesaayu der bu yam',
    '🏊🏾' => 'nit kuy féey: xeesaayu der bu xawa ñuul',
    '🏊🏿' => 'nit kuy féey: xeesaayu der bu ñuul',
    '⛹🏻' => 'nit kuy bondeel bal: xeesaayu der bu woyof',
    '⛹🏼' => 'nit kuy bondeel bal: xeesaayu der bu xeereer',
    '⛹🏽' => 'nit kuy bondeel bal: xeesaayu der bu yam',
    '⛹🏾' => 'nit kuy bondeel bal: xeesaayu der bu xawa ñuul',
    '⛹🏿' => 'nit kuy bondeel bal: xeesaayu der bu ñuul',
    '🏋🏻' => 'nit kuy yëkkati lu diis: xeesaayu der bu woyof',
    '🏋🏼' => 'nit kuy yëkkati lu diis: xeesaayu der bu xeereer',
    '🏋🏽' => 'nit kuy yëkkati lu diis: xeesaayu der bu yam',
    '🏋🏾' => 'nit kuy yëkkati lu diis: xeesaayu der bu xawa ñuul',
    '🏋🏿' => 'nit kuy yëkkati lu diis: xeesaayu der bu ñuul',
    '🚴🏻' => 'nit kuy dawal welo: xeesaayu der bu woyof',
    '🚴🏼' => 'nit kuy dawal welo: xeesaayu der bu xeereer',
    '🚴🏽' => 'nit kuy dawal welo: xeesaayu der bu yam',
    '🚴🏾' => 'nit kuy dawal welo: xeesaayu der bu xawa ñuul',
    '🚴🏿' => 'nit kuy dawal welo: xeesaayu der bu ñuul',
    '🚵🏻' => 'nit kuy dawal vtt: xeesaayu der bu woyof',
    '🚵🏼' => 'nit kuy dawal vtt: xeesaayu der bu xeereer',
    '🚵🏽' => 'nit kuy dawal vtt: xeesaayu der bu yam',
    '🚵🏾' => 'nit kuy dawal vtt: xeesaayu der bu xawa ñuul',
    '🚵🏿' => 'nit kuy dawal vtt: xeesaayu der bu ñuul',
    '🤸🏻' => 'nit ñuy ànd bërëŋu: xeesaayu der bu woyof',
    '🤸🏼' => 'nit ñuy ànd bërëŋu: xeesaayu der bu xeereer',
    '🤸🏽' => 'nit ñuy ànd bërëŋu: xeesaayu der bu yam',
    '🤸🏾' => 'nit ñuy ànd bërëŋu: xeesaayu der bu xawa ñuul',
    '🤸🏿' => 'nit ñuy ànd bërëŋu: xeesaayu der bu ñuul',
    '🤼🏻' => 'nit ñuy bëre: xeesaayu der bu woyof',
    '🤼🏼' => 'nit ñuy bëre: xeesaayu der bu xeereer',
    '🤼🏽' => 'nit ñuy bëre: xeesaayu der bu yam',
    '🤼🏾' => 'nit ñuy bëre: xeesaayu der bu xawa ñuul',
    '🤼🏿' => 'nit ñuy bëre: xeesaayu der bu ñuul',
    '🤽🏻' => 'nit kuy polo ci ndox: xeesaayu der bu woyof',
    '🤽🏼' => 'nit kuy polo ci ndox: xeesaayu der bu xeereer',
    '🤽🏽' => 'nit kuy polo ci ndox: xeesaayu der bu yam',
    '🤽🏾' => 'nit kuy polo ci ndox: xeesaayu der bu xawa ñuul',
    '🤽🏿' => 'nit kuy polo ci ndox: xeesaayu der bu ñuul',
    '🤾🏻' => 'nit kuy aanbóol: xeesaayu der bu woyof',
    '🤾🏼' => 'nit kuy aanbóol: xeesaayu der bu xeereer',
    '🤾🏽' => 'nit kuy aanbóol: xeesaayu der bu yam',
    '🤾🏾' => 'nit kuy aanbóol: xeesaayu der bu xawa ñuul',
    '🤾🏿' => 'nit kuy aanbóol: xeesaayu der bu ñuul',
    '🤹🏻' => 'nit kuy sànni-kapte: xeesaayu der bu woyof',
    '🤹🏼' => 'nit kuy sànni-kapte: xeesaayu der bu xeereer',
    '🤹🏽' => 'nit kuy sànni-kapte: xeesaayu der bu yam',
    '🤹🏾' => 'nit kuy sànni-kapte: xeesaayu der bu xawa ñuul',
    '🤹🏿' => 'nit kuy sànni-kapte: xeesaayu der bu ñuul',
    '🧘🏻' => 'nit ku farankulaayu: xeesaayu der bu woyof',
    '🧘🏼' => 'nit ku farankulaayu: xeesaayu der bu xeereer',
    '🧘🏽' => 'nit ku farankulaayu: xeesaayu der bu yam',
    '🧘🏾' => 'nit ku farankulaayu: xeesaayu der bu xawa ñuul',
    '🧘🏿' => 'nit ku farankulaayu: xeesaayu der bu ñuul',
    '🛀🏻' => 'nit kuy sangu: xeesaayu der bu woyof',
    '🛀🏼' => 'nit kuy sangu: xeesaayu der bu xeereer',
    '🛀🏽' => 'nit kuy sangu: xeesaayu der bu yam',
    '🛀🏾' => 'nit kuy sangu: xeesaayu der bu xawa ñuul',
    '🛀🏿' => 'nit kuy sangu: xeesaayu der bu ñuul',
    '🛌🏻' => 'nit ci kaw lal: xeesaayu der bu woyof',
    '🛌🏼' => 'nit ci kaw lal: xeesaayu der bu xeereer',
    '🛌🏽' => 'nit ci kaw lal: xeesaayu der bu yam',
    '🛌🏾' => 'nit ci kaw lal: xeesaayu der bu xawa ñuul',
    '🛌🏿' => 'nit ci kaw lal: xeesaayu der bu ñuul',
    '👭🏻' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu woyof',
    '👭🏼' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu xeereer',
    '👭🏽' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu yam',
    '👭🏾' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu xawa ñuul',
    '👭🏿' => 'ñaari jigéen yu jàppante loxo: xeesaayu der bu ñuul',
    '👫🏻' => 'góor ak jigéen jàppante loxo: xeesaayu der bu woyof',
    '👫🏼' => 'góor ak jigéen jàppante loxo: xeesaayu der bu xeereer',
    '👫🏽' => 'góor ak jigéen jàppante loxo: xeesaayu der bu yam',
    '👫🏾' => 'góor ak jigéen jàppante loxo: xeesaayu der bu xawa ñuul',
    '👫🏿' => 'góor ak jigéen jàppante loxo: xeesaayu der bu ñuul',
    '👬🏻' => 'ñaari góor yu jàppante loxo: xeesaayu der bu woyof',
    '👬🏼' => 'ñaari góor yu jàppante loxo: xeesaayu der bu xeereer',
    '👬🏽' => 'ñaari góor yu jàppante loxo: xeesaayu der bu yam',
    '👬🏾' => 'ñaari góor yu jàppante loxo: xeesaayu der bu xawa ñuul',
    '👬🏿' => 'ñaari góor yu jàppante loxo: xeesaayu der bu ñuul',
    '💏🏻' => 'fóon: xeesaayu der bu woyof',
    '💏🏼' => 'fóon: xeesaayu der bu xeereer',
    '💏🏽' => 'fóon: xeesaayu der bu yam',
    '💏🏾' => 'fóon: xeesaayu der bu xawa ñuul',
    '💏🏿' => 'fóon: xeesaayu der bu ñuul',
    '💑🏻' => 'xol ak ñaar ñu bëggante: xeesaayu der bu woyof',
    '💑🏼' => 'xol ak ñaar ñu bëggante: xeesaayu der bu xeereer',
    '💑🏽' => 'xol ak ñaar ñu bëggante: xeesaayu der bu yam',
    '💑🏾' => 'xol ak ñaar ñu bëggante: xeesaayu der bu xawa ñuul',
    '💑🏿' => 'xol ak ñaar ñu bëggante: xeesaayu der bu ñuul',
    '🏻' => 'xeesaayu der bu woyof',
    '🏼' => 'xeesaayu der bu xeereer',
    '🏽' => 'xeesaayu der bu yam',
    '🏾' => 'xeesaayu der bu xawa ñuul',
    '🏿' => 'xeesaayu der bu ñuul',
    '😀' => 'kanam guy gaññi',
    '😃' => 'kanam ak gémmiñ gu ubbeeku di muuñ',
    '😄' => 'kanam guy muuñ ak ubbeeku gémmiñ ak muuñ bët',
    '😁' => 'kanam guy gaññi ak bët yuy muuñ',
    '😆' => 'kanam guy muuñ ak ubbeeku gémmiñ ak buñ tëj bët',
    '😅' => 'kanam guy muuñ ak ubbeeku gémmiñ ak ñàqu tiitaange',
    '🤣' => 'ree ba xalangu ci suuf',
    '😂' => 'kanam gu am rangooñu bànneex',
    '🙂' => 'kanam gu muuñ tuuti',
    '🙃' => 'kanam gu dëppu',
    '🫠' => 'kanam buñu jaxase',
    '😉' => 'piis benn bët',
    '😊' => 'kanamu mbegte ak bët yuy muuñ',
    '😇' => 'kanam guy muuñ ak serkal ci kawam',
    '🥰' => 'kanam bu muuñ ak ay xol',
    '😍' => 'muuñ, kanam, xol, bët',
    '🤩' => 'dóor-biddeew',
    '😘' => 'kanam guy ëf fóon',
    '😗' => 'kanam guy fóon',
    '☺' => 'kanam guy muuñ',
    '😚' => 'kanam guy fóon ak bët yu gëmm',
    '😙' => 'kanam guy fóon ak bëti muuñ',
    '🥲' => 'kanam buy muuñ ak ragal',
    '😋' => 'kanam, bànneexu, ñeex, ñam',
    '😛' => 'kanam bu ànd ak làmmiñ wuñ tàllal',
    '😜' => 'kanam ak tàllal làmmiñ ak bët buy piis',
    '🤪' => 'kanamu dof',
    '😝' => 'kanam ak tàllal làmmiñ ak buñ tëj bët',
    '🤑' => 'kanamu gémmiñu xaalis',
    '🤗' => 'kanamu kottante',
    '🤭' => 'kanam ak loxo bu dar gémmiñ',
    '🫢' => 'kanam bu am ay gët yu ubbeeku ak loxo ci gemmiñ',
    '🫣' => 'kanam gu am ay gët yuy gaawantu',
    '🤫' => 'kanamu shuut noppil',
    '🤔' => 'kanamu guy xalaat',
    '🫡' => 'kanam guy niyoo',
    '🤐' => 'kanam ak gémiñ guñ fermitiir',
    '🤨' => 'kanam ak buñ yëkkati yéen',
    '😐' => 'kanam gu ni tekk',
    '😑' => 'kanam gu melul nenn',
    '😶' => 'kanam gu amul gémmiñ',
    '🫥' => 'kanam buñu def ay tomb',
    '😏' => 'kanam gu bëgg-waccu',
    '😒' => 'kanam gu ñàkk xorom',
    '🙄' => 'kanam guy regeju',
    '😬' => 'kanam guy def yëfi golo',
    '🤥' => 'kanamu fenkat',
    '🫨' => 'kanam guy lox',
    '😌' => 'kanam féex',
    '😔' => 'kanamu kuy xalaat',
    '😪' => 'kanam guy nelaw',
    '🤤' => 'kanam guy yuut',
    '😴' => 'kanam gu nelaw',
    '😷' => 'kanam guñ bàndaas',
    '🤒' => 'kanam gu ànd ak termomeetar',
    '🤕' => 'kanam guñ laxas ak bàndaas',
    '🤢' => 'kanamu guy teey xel',
    '🤮' => 'kanam guy waccu',
    '🤧' => 'kanamu tissooli',
    '🥵' => 'kanam gu tang',
    '🥶' => 'kanam gu sédd',
    '🥴' => 'kanam gu xawa feebar',
    '😵' => 'kanam gu diis',
    '🤯' => 'bopp buy toj',
    '🤠' => 'kanam gu sol mbaxane kaboy',
    '🥳' => 'kanam buy feetu',
    '🥸' => 'kanam gu deguisewu',
    '😎' => 'muuñ, kanam, nuwaarfime',
    '🤓' => 'kanamu bëñu lëk',
    '🧐' => 'kanam ak lunet-bennbët',
    '😕' => 'kanam gu jaaxasoo',
    '🫤' => 'kanam bi am gemmiñ bu jagonaal',
    '😟' => 'kanam gu jaaxle',
    '🙁' => 'kanam gu ànd ak yéen yu xawa lemu',
    '☹' => 'aj-yéen kanam',
    '😮' => 'kanam ak gémiñ gu ubbeeku',
    '😯' => 'kanam guñ juutal',
    '😲' => 'kanam gu waaru',
    '😳' => 'kanam gu am tomb yu xonk',
    '🥺' => 'kanam guy ñaan njegal',
    '🥹' => 'Kanam guy teye rongoñ',
    '😦' => 'kanam gu ànd ak yéen yu lemu ak gémmiñ gu ubbiku',
    '😧' => 'kanam gu xawa jaaxle',
    '😨' => 'kanam guy tiitaleete',
    '😰' => 'kanam ak ubbeeku gémmiñ ak ñàqu tiitaange',
    '😥' => 'kanamu mbetteel te féex',
    '😢' => 'kanam guy jooy',
    '😭' => 'kanam guy jooy ca kaw',
    '😱' => 'kanam guy jooy te tiit',
    '😖' => 'kanam gu jaawale',
    '😣' => 'kanam guy ñafe',
    '😞' => 'kanam gu am mbetteel',
    '😓' => 'kanam ak ñaq wu sedd',
    '😩' => 'kanamu coono',
    '😫' => 'kanam gu sonn',
    '🥱' => 'kanam guy obali',
    '😤' => 'kanam gu ànd ak saxaaru bakkan',
    '😡' => 'kanam guy puucatu',
    '😠' => 'kanam gu mer',
    '🤬' => 'kanam ak màndarga ci gémmiñ',
    '😈' => 'kanam gu am ay béjjen',
    '👿' => 'kanam gu mer am ay béjjen',
    '💀' => 'yaxu-bopp',
    '☠' => 'kraan and yax yu kruwaase',
    '💩' => 'julu puup',
    '🤡' => 'kanamu kluun',
    '👹' => 'oogar',
    '👺' => 'kus-kondoroŋ',
    '👻' => 'fàntom',
    '👽' => 'aliyeen',
    '👾' => 'jiney aliyeen',
    '🤖' => 'kanamu roboo',
    '😺' => 'kanamu muus muy muuñ ak gémmiñ gu ubbeeku',
    '😸' => 'kanamu muus muy xiiru ak bët yuy muuñ',
    '😹' => 'kanamu muus bu ànd ak rangooñi mbégte',
    '😻' => 'kanamu muus buy muuñ ak bëti xol',
    '😼' => 'kanamu muus ak muuñ gu weng',
    '😽' => 'kanamu muus bu tëj bët di fóon',
    '🙀' => 'kanamu muus mu jommi',
    '😿' => 'kanam muus muy jooy',
    '😾' => 'kanamu muus mu mer',
    '🙈' => 'golo budul gis lu bon',
    '🙉' => 'golo budul dégg lu bon',
    '🙊' => 'golo budul wax lu bon',
    '💌' => 'bataaxalu mbëggeel',
    '💘' => 'xol ak fett',
    '💝' => 'xol buñ laxas ribaŋ',
    '💖' => 'xol bu yànj',
    '💗' => 'xol buy màgg',
    '💓' => 'xol buy tëf-tëfi',
    '💞' => 'xol buñ wëndeelu',
    '💕' => 'ñaari xol',
    '💟' => 'taaralukaayu xol',
    '❣' => 'xol esklamaasiyoŋ bu fës',
    '💔' => 'xol bu tasaaroo',
    '❤' => 'xonk xol',
    '🩷' => 'Xol bu rose',
    '🧡' => 'xol bu oraas',
    '💛' => 'xol bu mboq',
    '💚' => 'xol bu wert',
    '💙' => 'xol bu baxa',
    '🩵' => 'xol bu bleu clair',
    '💜' => 'xol bu yolet',
    '🤎' => 'Xol bu sokolaa',
    '🖤' => 'xol bu ñuul',
    '🩶' => 'xol bu doomu-taal',
    '🤍' => 'Xol bu weex',
    '💋' => 'marku fóon',
    '💯' => 'tombi teeméer',
    '💢' => 'màndarga ku mer',
    '💥' => 'mbëkkante',
    '💫' => 'miir',
    '💦' => 'toqu ñaq',
    '💨' => 'dem sa yoon',
    '🕳' => 'pax',
    '💬' => 'rëddu bind kàddu',
    '🗨' => 'bulu bind waxu càmmoñ',
    '🗯' => 'ndijoor mer bul',
    '💭' => 'rëddu bind xalaat',
    '💤' => 'zzz',
    '👋' => 'tàllal loxo',
    '🤚' => 'ginaawu loxo bu jog',
    '🖐' => 'buñ yëkkati loxo ak baaraam yuñ tàllal',
    '✋' => 'loxo bu jog',
    '🖖' => 'loxo xaajale ñeenti baaraam',
    '👌' => 'laxo waaw-kay',
    '🤌' => 'dompat baaraam',
    '✌' => 'loxo ndam',
    '🤞' => 'laxasante ñaari baaraam',
    '🤟' => 'liyaar mbëggeel',
    '🤘' => 'loxo def màndarga béjjen',
    '🤙' => 'loxo nanga ma woo',
    '👈' => 'ginaaw loxo buy joxoñ càmmoñ',
    '👉' => 'ginaaw loxo buy joxoñ ndijoor',
    '👆' => 'ginaaw loxo buy joxoñ ci kaw',
    '🖕' => 'baaraamu digg',
    '👇' => 'ginaaw loxo buy joxoñ ci suuf',
    '☝' => 'baaraamu joxoñ buy joxoñ ci kaw',
    '👍' => 'baaraamu waaw',
    '👎' => 'baaraamu déet',
    '✊' => 'kurfañ bu jog',
    '👊' => 'kurfañ buy ñëw',
    '🤛' => 'kurfañu càmmoñ',
    '🤜' => 'kurfañu ndijoor',
    '👏' => 'loxo yuy tàccu',
    '🙌' => 'yëkkati ay loxo',
    '👐' => 'loxo yu ubbeeku',
    '🤲' => 'tallal loxo ñaan',
    '🤝' => 'joxante loxo',
    '🙏' => 'lem ay loxo',
    '✍' => 'loxo buy bind',
    '💅' => 'jakkal wew',
    '🤳' => 'selfie',
    '💪' => 'wane doole',
    '👂' => 'nopp',
    '👃' => 'bakkan',
    '🧠' => 'yuur',
    '👀' => 'gët',
    '👁' => 'bët',
    '👅' => 'làmmiñ',
    '👄' => 'gémmiñ',
    '👶' => 'liir',
    '🧒' => 'xale',
    '👦' => 'xale bu góor',
    '👧' => 'xale bu jigéen',
    '🧑' => 'nit',
    '👱' => 'nit ku karaw yu weex',
    '👨' => 'góor',
    '🧔' => 'nit am sikkim',
    '👩' => 'jigéen',
    '🧓' => 'mag mu gën a màgget',
    '👴' => 'màgget gu góor',
    '👵' => 'màgget gu jigéen',
    '🙍' => 'nit ku yéen yi lemu',
    '🙎' => 'nit kuy puucatu',
    '🙅' => 'nit ku naan déedet',
    '🙆' => 'nit ku naan waaw-kay',
    '💁' => 'nit kuy joxee wet',
    '🙋' => 'nit kuy yëkkati loxo',
    '🙇' => 'nit kuy sëgg-nuyoo',
    '🤦' => 'nit ku taf loxo ci kanamam',
    '🤷' => 'nit ku aj mbaggam',
    '👮' => 'polisiyee',
    '🕵' => 'detektif',
    '💂' => 'gardiñe',
    '👷' => 'tabaxkat',
    '🤴' => 'doomu-buur bu góor',
    '👸' => 'doomu buur bu jigéen',
    '👳' => 'nit ku kaalawu',
    '👲' => 'góor gu sol mbaxane sinuwaa',
    '🧕' => 'jigéen ju musóoru',
    '🤵' => 'góor gu sol kostim',
    '👰' => 'séet bu móoru',
    '🤰' => 'jigéen ju ëmb',
    '🤱' => 'nàppalee ween',
    '👼' => 'liiru malaaka',
    '🎅' => 'Pere nowel',
    '🤶' => 'meer nowel',
    '🧙' => 'mage',
    '🧚' => 'fee',
    '🧛' => 'wàmpiir',
    '🧜' => 'sireen bu nit',
    '🧝' => 'elfe',
    '🧞' => 'jinne',
    '🧟' => 'zombi',
    '💆' => 'nit ku ñuy dàmp',
    '💇' => 'nit kuy watu',
    '🚶' => 'nit kuy dox',
    '🏃' => 'nit kuy daw',
    '💃' => 'jigéen juy fecc',
    '🕺' => 'góor guy fecc',
    '🕴' => 'góor ci bisnes kostim lewitasiyoŋ',
    '👯' => 'nit ñuy fecc, ak noppi lëk',
    '🧖' => 'nit ci néegu wapër',
    '🧗' => 'nit kuy yéeg',
    '🤺' => 'nit kuy fente',
    '🏇' => 'kursu fas',
    '⛷' => 'skikat',
    '🏂' => 'kuy pateŋ ci nees',
    '🏌' => 'nit kuy golf',
    '🏄' => 'nit kuy sërfe',
    '🚣' => 'nit joow gaal',
    '🏊' => 'nit kuy féey',
    '⛹' => 'nit kuy bondeel bal',
    '🏋' => 'nit kuy yëkkati lu diis',
    '🚴' => 'nit kuy dawal welo',
    '🚵' => 'nit kuy dawal vtt',
    '🤸' => 'nit ñuy ànd bërëŋu',
    '🤼' => 'nit ñuy bëre',
    '🤽' => 'nit kuy polo ci ndox',
    '🤾' => 'nit kuy aanbóol',
    '🤹' => 'nit kuy sànni-kapte',
    '🧘' => 'nit ku farankulaayu',
    '🛀' => 'nit kuy sangu',
    '🛌' => 'nit ci kaw lal',
    '👭' => 'ñaari jigéen yu jàppante loxo',
    '👫' => 'góor ak jigéen jàppante loxo',
    '👬' => 'ñaari góor yu jàppante loxo',
    '💏' => 'fóon',
    '💑' => 'xol ak ñaar ñu bëggante',
    '🗣' => 'wax bopp',
    '👤' => 'yaram takkandeer',
    '👥' => 'ay yaram takkandeer',
    '👪' => 'bokk famiy',
    '👣' => 'fu tànk teguwoon',
    '🐵' => 'kanamu golo',
    '🐒' => 'golo',
    '🦍' => 'dàngin',
    '🐶' => 'boppu xaj',
    '🐕' => 'xaj',
    '🐩' => 'kaj bu ndaw, sëq kawar',
    '🐺' => 'kanamu xaju-tundu',
    '🦊' => 'kanamu rënaar',
    '🐱' => 'kanamu muus',
    '🐈' => 'muus',
    '🦁' => 'kanamu gaynde',
    '🐯' => 'kanamu segg',
    '🐅' => 'segg',
    '🐆' => 'lewopaar',
    '🐴' => 'kanamu fas',
    '🐎' => 'fas',
    '🦄' => 'kanam gu sax béjjen',
    '🦓' => 'zebre',
    '🦌' => 'serf',
    '🐮' => 'kanamu nag',
    '🐂' => 'yékk',
    '🐃' => 'nagu ndox',
    '🐄' => 'nag',
    '🐷' => 'kanamu mbaam-xuux',
    '🐖' => 'mbaam-xuux',
    '🐗' => 'mbaam-àll',
    '🐽' => 'bakkanu mbaam-xuux',
    '🐏' => 'yàppu kuy',
    '🐑' => 'xar bu jigéen',
    '🐐' => 'bëy',
    '🐪' => 'giléem',
    '🐫' => 'gileemu ñaari boos',
    '🦒' => 'giraaf',
    '🐘' => 'ñay',
    '🦏' => 'rinoseros',
    '🐭' => 'kanmu jinax',
    '🐁' => 'jinax',
    '🐀' => 'kaña',
    '🐹' => 'kanamu jinax',
    '🐰' => 'kanamu lëk',
    '🐇' => 'lëk',
    '🐿' => 'cipmànk',
    '🦔' => 'suñeel',
    '🦇' => 'njugub',
    '🐻' => 'kanam urs',
    '🐨' => 'koala',
    '🐼' => 'kanamu panda',
    '🐾' => 'fu tànku rab teguwoon',
    '🦃' => 'koppin',
    '🐔' => 'ginaar',
    '🐓' => 'séq',
    '🐣' => 'cuuj bu génn ci nen',
    '🐤' => 'cuuj',
    '🐥' => 'kanam jàkkarloo ak lexu xale',
    '🐦' => 'picc',
    '🐧' => 'penguweŋ',
    '🕊' => 'kolomb',
    '🦅' => 'céeli',
    '🦆' => 'kanaara',
    '🦉' => 'looy',
    '🐸' => 'kanamu mbott',
    '🐊' => 'jasit',
    '🐢' => 'mbonaat',
    '🦎' => 'sindax',
    '🐍' => 'jaan',
    '🐲' => 'kanamu dragoŋ',
    '🐉' => 'dragoŋ',
    '🦕' => 'soropod',
    '🦖' => 'T-Rex',
    '🐳' => 'baleen bu puucatu',
    '🐋' => 'baleen',
    '🐬' => 'dófeŋ',
    '🐟' => 'jën',
    '🐠' => 'jënu tàngoor',
    '🐡' => 'bun fokkin',
    '🦈' => 'rekeŋ',
    '🐙' => 'oktopis',
    '🐚' => 'xoru espiraal',
    '🦀' => 'junqoob',
    '🦐' => 'krëwet',
    '🦑' => 'kalamaar',
    '🐌' => 'eskargoo',
    '🦋' => 'lëppaalëp',
    '🐛' => 'gunóor',
    '🐜' => 'sànqaleñ',
    '🐝' => 'yamb',
    '🐞' => 'gunóor am tupp yu weex',
    '🦗' => 'kriket',
    '🕷' => 'jargoñ',
    '🕸' => 'lëndu jargoñ',
    '🦂' => 'jiit',
    '💐' => 'takkufulër',
    '🌸' => 'fulóor yu am melo sëriis',
    '💮' => 'fulóor bu weex',
    '🏵' => 'roset',
    '🌹' => 'róos',
    '🥀' => 'fulóor bu waw',
    '🌺' => 'ibiskus',
    '🌻' => 'fulóoru jant',
    '🌼' => 'fulóor',
    '🌷' => 'tulip',
    '🌱' => 'semis',
    '🌲' => 'garab gu am xob yuy dund',
    '🌳' => 'garab gu am xob yuy dee',
    '🌴' => 'garabu-tiir',
    '🌵' => 'gargamboose',
    '🌾' => 'sayu ceeb',
    '🌿' => 'ñax',
    '☘' => 'tereefal',
    '🍀' => 'treefalu ñeenti xob',
    '🍁' => 'kobu kanadaa',
    '🍂' => 'xob yu daanu',
    '🍃' => 'xob wu gelaw yëngal',
    '🍄' => 'sampiñoŋ',
    '🍇' => 'reeseŋ',
    '🍈' => 'mëloŋ',
    '🍉' => 'xaal',
    '🍊' => 'màndarin',
    '🍋' => 'lingom',
    '🍌' => 'banana',
    '🍍' => 'ananas',
    '🍎' => 'pom bu xonk',
    '🍏' => 'pom bu wert',
    '🍐' => 'puwaar',
    '🍑' => 'pes',
    '🍒' => 'sëriis',
    '🍓' => 'frees',
    '🥝' => 'kiwi',
    '🍅' => 'tamaate',
    '🥥' => 'ñamu coco',
    '🥑' => 'awokaa',
    '🍆' => 'basante',
    '🥔' => 'pombiteer',
    '🥕' => 'karot',
    '🌽' => 'noppi mboq',
    '🌶' => 'kaani xeeñ',
    '🥒' => 'komkombar',
    '🥦' => 'brokoli',
    '🥜' => 'gerte',
    '🌰' => 'sateñ',
    '🍞' => 'mburu',
    '🥐' => 'Kurwaasaŋ',
    '🥖' => 'miisu mburu',
    '🥨' => 'bretzel',
    '🥞' => 'krep',
    '🧀' => 'cëru fromaas',
    '🍖' => 'yàpp ci yax',
    '🍗' => 'tànku ginaar',
    '🥩' => 'dogu yàpp',
    '🥓' => 'bekon',
    '🍔' => 'àmburgë',
    '🍟' => 'pombiteer buñ saaf',
    '🍕' => 'pizza',
    '🌭' => 'ot-dog',
    '🥪' => 'sandwich',
    '🌮' => 'tako',
    '🌯' => 'burito',
    '🥙' => 'mburu-farsi',
    '🥚' => 'nen',
    '🍳' => 'togg',
    '🥘' => 'boolu togg bu xóotul',
    '🍲' => 'potu ñam',
    '🥣' => 'bool ak kuddu',
    '🥗' => 'salaad bu wert',
    '🍿' => 'pop korn',
    '🥫' => 'lekk ci kanet',
    '🍱' => 'boyetu bento',
    '🍘' => 'gato ceeb',
    '🍙' => 'balu ceeb',
    '🍚' => 'ceeb buñ togg',
    '🍛' => 'ceebu kari',
    '🍜' => 'toggee ci wapër',
    '🍝' => 'espageti',
    '🍠' => 'pataas buñ roti',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'sippax buñ saaf',
    '🍥' => 'buteeli jën',
    '🍡' => 'dango',
    '🥟' => 'buleet',
    '🥠' => 'mbiskitu musuwaar',
    '🥡' => 'boyetu yóbbaale',
    '🍦' => 'kreem galaas bu am suukar',
    '🍧' => 'galaas guñ dëbb',
    '🍨' => 'kreem galaase',
    '🍩' => 'beñe',
    '🍪' => 'mbiskit',
    '🎂' => 'ngato màggal bisu-judd',
    '🍰' => 'gàttal-yoon',
    '🥧' => 'tàrt',
    '🍫' => 'laatu-sokolaa',
    '🍬' => 'tàngal',
    '🍭' => 'tàngal bant',
    '🍮' => 'kreem',
    '🍯' => 'potu lem',
    '🍼' => 'biberoŋ',
    '🥛' => 'kaasu meew',
    '☕' => 'naan gu tank',
    '🍵' => 'kaasu attaayu bu amul jàppukaay',
    '🍶' => 'buteel bu yaatu gémmiñ',
    '🍾' => 'buteel bu saañ biy naaw',
    '🍷' => 'kaasu sàngara',
    '🍸' => 'kaasu koktel',
    '🍹' => 'naan tàngoor',
    '🍺' => 'kaasu biyeer',
    '🍻' => 'dóorante kaasu biyeer',
    '🥂' => 'dóorante kaas',
    '🥃' => 'kaasu ndox',
    '🥤' => 'kaas ak paay',
    '🥢' => 'baget',
    '🍽' => 'furset and paaka ak asiyet',
    '🍴' => 'furset ak paaka',
    '🥄' => 'kuddu',
    '🔪' => 'paaka waañ',
    '🏺' => 'àmfoor',
    '🌍' => 'glob buy wane ërop ak afrik',
    '🌎' => 'glob buy wane amerik',
    '🌏' => 'glob buy wane asi ak óstraali',
    '🌐' => 'glob buy wane merijeŋ yi',
    '🗺' => 'kàrtu àdduna',
    '🗾' => 'kàrtu sapoŋ',
    '🏔' => 'nees bu muur montaañ',
    '⛰' => 'montaañ',
    '🌋' => 'géeju xal',
    '🗻' => 'tundu fuji',
    '🏕' => 'kampiŋ',
    '🏖' => 'tefes ak parasol',
    '🏜' => 'desert',
    '🏝' => 'desert dun',
    '🏞' => 'park nasyonaal',
    '🏟' => 'estad',
    '🏛' => 'tabaxu cosaan',
    '🏗' => 'tabax ab tabax',
    '🏘' => 'kër yi',
    '🏚' => 'kër gu gent',
    '🏠' => 'kër',
    '🏡' => 'kër ak sardeŋ',
    '🏢' => 'taaxu liggéey',
    '🏣' => 'biro post ci sapoŋ',
    '🏤' => 'biro post',
    '🏥' => 'opitaal',
    '🏦' => 'bànk',
    '🏨' => 'otel',
    '🏩' => 'otelu mbëggeel',
    '🏪' => 'njaay mu yomb',
    '🏫' => 'daara',
    '🏬' => 'rëy magasin',
    '🏭' => 'Isinu-liggéey',
    '🏯' => 'taaxu sapoŋ',
    '🏰' => 'taaxu buur',
    '💒' => 'céet',
    '🗼' => 'tuuru ci tokyo',
    '🗽' => 'estati liberte',
    '⛪' => 'jàngu',
    '🕌' => 'Jàkka',
    '🕍' => 'sinaagog',
    '⛩' => 'armeeli Shinto',
    '🕋' => 'Kaaba',
    '⛲' => 'ndax muy sànni',
    '⛺' => 'tant',
    '🌁' => 'lay',
    '🌃' => 'guddi ak ay biddéew',
    '🏙' => 'cityscape',
    '🌄' => 'jant buy fenk ci tund',
    '🌅' => 'jant buy fenk',
    '🌆' => 'timis ci réewu taax',
    '🌇' => 'jant bu so ci réewu taax',
    '🌉' => 'pom ci guddi',
    '♨' => 'cooroon bu tàng',
    '🎠' => 'fasu kurusel',
    '🎡' => 'pëno bu kawe lool',
    '🎢' => 'tundu risi',
    '💈' => 'tablo watkat',
    '🎪' => 'barabu sirk',
    '🚂' => 'ndaamaar',
    '🚃' => 'otoraay',
    '🚄' => 'otoraay bu gaaw lool',
    '🚅' => 'otoraay bu gaaw lool ak kanam gu sew',
    '🚆' => 'saxaar',
    '🚇' => 'metro',
    '🚈' => 'otoraay bu moome fépp',
    '🚉' => 'gaar',
    '🚊' => 'tram',
    '🚝' => 'monoraay',
    '🚞' => 'raayu tund',
    '🚋' => 'oto tramweey',
    '🚌' => 'otokaar',
    '🚍' => 'kaar buy ñëw',
    '🚎' => 'trolleybus',
    '🚐' => 'minikaar',
    '🚑' => 'àmbilaas',
    '🚒' => 'oto pompiyee',
    '🚓' => 'oto poliis',
    '🚔' => 'oto poliis buy ñëw',
    '🚕' => 'taxi',
    '🚖' => 'taxi buy ñëw',
    '🚗' => 'oto',
    '🚘' => 'oto buy ñëw',
    '🚙' => 'oto njëkkante',
    '🚚' => 'kamiyoŋu bagaas',
    '🚛' => 'kamiyoŋu bu gudd lool',
    '🚜' => 'traktër',
    '🏎' => 'kursu oto',
    '🏍' => 'moto',
    '🛵' => 'eskutër',
    '🚲' => 'welo',
    '🛴' => 'welo benn tànk',
    '🚏' => 'are-kaar',
    '🛣' => 'otoruut',
    '🛤' => 'wagoŋ raay',
    '🛢' => 'bidoŋu diw',
    '⛽' => 'pompu esaas',
    '🚨' => 'làmpu oto poliis',
    '🚥' => 'làmpi estop yu tëdd',
    '🚦' => 'làmpi estop yu taxaw',
    '🛑' => 'màndarga dakkal',
    '🚧' => 'tabax',
    '⚓' => 'serukaayu gaal',
    '⛵' => 'gaalu ngelaw',
    '🛶' => 'kaal gu ndaw',
    '🚤' => 'gaalu motër',
    '🛳' => 'ki mu yab bato',
    '⛴' => 'bak',
    '🛥' => 'gaalu-motër',
    '🚢' => 'gaal gu mag',
    '✈' => 'roppalaan',
    '🛩' => 'roppalaan bu ndaw',
    '🛫' => 'roppalaan buy dem',
    '🛬' => 'roppalaan buy ñëw',
    '💺' => 'toogu',
    '🚁' => 'elikopteer',
    '🚟' => 'raay ci kaw',
    '🚠' => 'teleferik',
    '🚡' => 'tramweey ci kaw',
    '🛰' => 'satelit',
    '🚀' => 'fuse-jawwu',
    '🛸' => 'sukup buy naaw',
    '🛎' => 'joolooli bu ñuy bës',
    '⌛' => 'saabliyee',
    '⏳' => 'saabliyee buy sotti suuf',
    '⌚' => 'seetaan',
    '⏰' => 'waxtukaayu yégle',
    '⏱' => 'kronoo',
    '⏲' => 'montar jël-waxtu',
    '🕰' => 'montaru wékk',
    '🕛' => '12:00',
    '🕧' => '12:30',
    '🕐' => '01:00',
    '🕜' => '01:30',
    '🕑' => '02:00',
    '🕝' => '02:30',
    '🕒' => '03:00',
    '🕞' => '03:30',
    '🕓' => '04:00',
    '🕟' => '04:30',
    '🕔' => '05:00',
    '🕠' => '05:30',
    '🕕' => '06:00',
    '🕡' => '06:30',
    '🕖' => '07:00',
    '🕢' => '07:30',
    '🕗' => '08:00',
    '🕣' => '08:30',
    '🕘' => '09:00',
    '🕤' => '09:30',
    '🕙' => '10:00',
    '🕥' => '10:30',
    '🕚' => '11:00',
    '🕦' => '11:30',
    '🌑' => 'weer wu bees',
    '🌒' => 'xaaju weer buy wàññiku',
    '🌓' => 'xaaju weer wu njëkk',
    '🌔' => 'weer wu sew buy wàññiku',
    '🌕' => 'weer wu fees',
    '🌖' => 'weer wu sew buy yokk',
    '🌗' => 'xaaju weer wu mujj',
    '🌘' => 'xaaju weer buy yokk',
    '🌙' => 'weer wu sew di màgg',
    '🌚' => 'kanamu weer wu bees',
    '🌛' => 'weeru xaaj bu njëkk',
    '🌜' => 'weeru ñeenteelu xaaj',
    '🌡' => 'termomeetar',
    '☀' => 'jant',
    '🌝' => 'weer ñumm bu am kanam',
    '🌞' => 'jant bu am kanam',
    '⭐' => 'biddeew, weexaay bu yam',
    '🌟' => 'biddeew tàkk',
    '🌠' => 'biddeew buy daw',
    '🌌' => 'asamaan aki biddéew',
    '☁' => 'niir',
    '⛅' => 'jant ci ginaaw niir',
    '⛈' => 'niir ak melax ak taw',
    '🌤' => 'jant ci ginaaw niir wu ndaw',
    '🌥' => 'jant ci ginaaw niir wu rëy',
    '🌦' => 'jant ci ginaaw taw niir',
    '🌧' => 'niir ak taw',
    '🌨' => 'niir ak nees',
    '🌩' => 'niir ak melax',
    '🌪' => 'Tawu-ngelaw',
    '🌫' => 'ab lay',
    '🌬' => 'kanamu ngelaw',
    '🌀' => 'ngelaw luy wëndeelu',
    '🌈' => 'xon',
    '🌂' => 'parasol bu tëju',
    '☂' => 'parasol',
    '☔' => 'parasol bu am toqu taw',
    '⛱' => 'parasol ci kaw suuf',
    '⚡' => 'kuuraŋ bu am doole',
    '❄' => 'donju nees',
    '☃' => 'bonomu-nees',
    '⛄' => 'nitu nees bu amul nees',
    '☄' => 'komet',
    '🔥' => 'xal',
    '💧' => 'toqu ndox',
    '🌊' => 'duusu ndox',
    '🎃' => 'naajo alowiin',
    '🎄' => 'garabu nowel',
    '🎆' => 'petaaru artifis',
    '🎇' => 'potu sondeel',
    '✨' => 'ferñeent',
    '🎈' => 'baloŋ',
    '🎉' => 'bombu taabal',
    '🎊' => 'mànqu konfeti',
    '🎋' => 'garabu tanabata',
    '🎍' => 'taaralukaayu sapeŋ',
    '🎎' => 'pupe sapone',
    '🎏' => 'bàndarolu waas',
    '🎐' => 'gittaxu keseŋ-keseŋ',
    '🎑' => 'séentu weer',
    '🎀' => 'ribaŋ',
    '🎁' => 'kado buñ ëmb',
    '🎗' => 'ribaŋu fàttalikaay',
    '🎟' => 'biye dugg',
    '🎫' => 'biye',
    '🎖' => 'medaayu militeer',
    '🏆' => 'kup',
    '🏅' => 'medaayu tàggat-yaram',
    '🥇' => 'medaayu plaas 1',
    '🥈' => 'medaayu plaas 2',
    '🥉' => 'medaayu plaas 3',
    '⚽' => 'balu futbal',
    '⚾' => 'besbóol',
    '🏀' => 'basket',
    '🏐' => 'wolebal',
    '🏈' => 'futbalu amerik',
    '🏉' => 'futbalu rigbi',
    '🎾' => 'tenis',
    '🎳' => 'buliŋ',
    '🏏' => 'powum kriket',
    '🏑' => 'hockey ci ñax',
    '🏒' => 'hockey ci galaas',
    '🏓' => 'ping pong',
    '🏸' => 'badminton',
    '🥊' => 'gaŋu boksër',
    '🥋' => 'kimono defkatu aar',
    '🥅' => 'caaxu kaaŋ',
    '⛳' => 'raaya ci pax',
    '⛸' => 'patee ci galaas',
    '🎣' => 'bantu nappukaay',
    '🎽' => 'mbubu tàggat-yaram',
    '🎿' => 'skis',
    '🛷' => 'trenóo',
    '🥌' => 'xeeru kërliŋ',
    '🎯' => 'dóor bu jub',
    '🔫' => 'pistole',
    '🎱' => 'biyaar 8 bal',
    '🔮' => 'bulu kristaal',
    '🎮' => 'powum wideo',
    '🕹' => 'joystick',
    '🎰' => 'masinu xaalis',
    '🎲' => 'deewu lido',
    '♠' => 'pikk yépp',
    '♥' => 'kër yépp',
    '♦' => 'karo yépp',
    '♣' => 'treefal yépp',
    '🃏' => 'jokeer',
    '🀄' => 'dragon mahjong bu xonk',
    '🎴' => 'kàrti fulër',
    '🎭' => 'yëngu ci aar',
    '🖼' => 'nataal buñ kaadare',
    '🎨' => 'boolu pentiirukaay',
    '🧵' => 'woñ',
    '👓' => 'linet',
    '🕶' => 'nuwaarfime',
    '👔' => 'karawaat',
    '👕' => 'tiset',
    '👖' => 'jiin',
    '🧣' => 'kol',
    '🧤' => 'gant',
    '🧥' => 'màntóo',
    '🧦' => 'kawas',
    '👗' => 'robbu',
    '👘' => 'kimono',
    '👙' => 'bikini',
    '👚' => 'yéere jigéen',
    '👛' => 'nafa',
    '👜' => 'saagu loxo',
    '👝' => 'poset',
    '🛍' => 'saagu ndugg',
    '🎒' => 'saagu ndongo daara',
    '👞' => 'dàllu góor',
    '👟' => 'dàllu daw',
    '👠' => 'koket yu gudd',
    '👡' => 'caraxu jigéen',
    '👢' => 'botu jigééen',
    '👑' => 'kuron',
    '👒' => 'mbaxane jigeen',
    '🎩' => 'mbaxane joniwalkër',
    '🎓' => 'mbaxane lijaasa',
    '🧢' => 'kap',
    '⛑' => 'mbaxane-kaaraange wallukat',
    '📿' => 'kurus',
    '💄' => 'xonkal tuñ',
    '💍' => 'jaaro',
    '💎' => 'xeer wu seer',
    '🔇' => 'oparlër buñ noppiloo',
    '🔈' => 'oparlër buy wax ndànk',
    '🔉' => 'oparlër bu xumbul noonu',
    '🔊' => 'oparlër bu xumbul lool',
    '📢' => 'baafal',
    '📣' => 'megafon',
    '📯' => 'mbiibu bataaxal',
    '🔔' => 'joolooli',
    '🔕' => 'joolooli ak buum',
    '🎼' => 'kle misik',
    '🎵' => 'arafu misik',
    '🎶' => 'arafi misik',
    '🎙' => 'mikrofonu studio',
    '🎚' => 'xàjjalekaayu dayo',
    '🎛' => 'bitoŋu yokk/wàññi',
    '🎤' => 'mikrofon',
    '🎧' => 'kasku misik',
    '📻' => 'rajo',
    '🎷' => 'saksofon',
    '🎺' => 'trompet',
    '🎸' => 'gitaar',
    '🎹' => 'klawiyee misik',
    '🎻' => 'violon',
    '🥁' => 'ndënd',
    '📱' => 'telefon portaabal',
    '📲' => 'telefon portaabal ak fett',
    '☎' => 'telefon',
    '📞' => 'kombine telefon',
    '📟' => 'bipër',
    '📠' => 'faks',
    '🔋' => 'batiri',
    '🔌' => 'priisu kuuraŋ',
    '💻' => 'ordi portaabal',
    '🖥' => 'ordi-biro ordinatër',
    '🖨' => 'emprimaant',
    '⌨' => 'klaawiyee',
    '🖱' => 'suuri ordinatër',
    '🖲' => 'trackball',
    '💽' => 'disku ordi',
    '💾' => 'disket',
    '💿' => 'disk optik',
    '📀' => 'dvd',
    '🎥' => 'kameraa filmu',
    '🎞' => 'kaadaru klise',
    '📽' => 'prosektër filmu',
    '🎬' => 'klapet',
    '📺' => 'tele',
    '📷' => 'nataalukaay',
    '📸' => 'nataalukaay bu ànd ak flaas',
    '📹' => 'nataalukaay wideo',
    '📼' => 'kasetu wideo',
    '🔍' => 'lup bu féete càmmoñ',
    '🔎' => 'lup bu féete ndijoor',
    '🕯' => 'sondeel',
    '💡' => 'àmpul',
    '🔦' => 'làmp-tors',
    '🏮' => 'làntern bu xonk',
    '📔' => 'kàrne bu ànd ak kubéer gu rafet',
    '📕' => 'téere bu tëju',
    '📖' => 'téere bu ubbiku',
    '📗' => 'téere bu wert',
    '📘' => 'téere bu baxa',
    '📙' => 'téere bu oraas',
    '📚' => 'téere yi',
    '📓' => 'kàrne',
    '📒' => 'téere bu rëy',
    '📃' => 'këyit wuñ lem muus wi',
    '📜' => 'tawal',
    '📄' => 'kanam gu téen',
    '📰' => 'këyitu xibaar',
    '🗞' => 'këyitu xibaar buñ lem',
    '📑' => 'boole ci yi ma gënal',
    '🔖' => 'xàmme-téere',
    '🏷' => 'màndarga',
    '💰' => 'saagu xaalis',
    '💴' => 'biye yen',
    '💵' => 'biye dolaar',
    '💶' => 'biye euro',
    '💷' => 'piye pound',
    '💸' => 'xaalis bu am ay laaf',
    '💳' => 'kàrtu keredi',
    '💹' => 'grafiku yen buy yéeg',
    '✉' => 'mbaru-bataaxal',
    '📧' => 'bataaxalu net',
    '📨' => 'mbaru-bataaxal biy ñëw',
    '📩' => 'mbaru-bataaxal, am fett',
    '📤' => 'boyetu-yónne bataaxal',
    '📥' => 'boyetu-jot bataaxal',
    '📦' => 'paket',
    '📫' => 'boyetu-bataaxal buñ tëj, am raaya buñ yëkkati',
    '📪' => 'boyetu-bataaxal buñ tëj, am raaya buñ wàcce',
    '📬' => 'boyetu-bataaxal buñ ubbi, am raaya buñ yëkkati',
    '📭' => 'boyetu-bataaxal buñ ubbi, am raaya buñ wàcce',
    '📮' => 'boyetu-leetar',
    '🗳' => 'boyetu-wote ak kàrtu-wote',
    '✏' => 'kreyoŋ',
    '✒' => 'dik fëtar',
    '🖋' => 'estilo',
    '🖊' => 'bik',
    '🖌' => 'borosu-pentiir',
    '🖍' => 'kreyoŋ kulër',
    '📝' => 'karmat',
    '💼' => 'waliis wu ndaw',
    '📁' => 'ëmbu taxañ',
    '📂' => 'ubbi ëmbu taxañ',
    '🗂' => 'xàjjalekaayu limu kàrt',
    '📅' => 'arminaat',
    '📆' => 'arminaatu xotti-kayit',
    '🗒' => 'bloknot bu am weñ',
    '🗓' => 'arminaat bu am weñ',
    '📇' => 'limu këyit',
    '📈' => 'grafik buy yéeg',
    '📉' => 'tablo buy wàcci',
    '📊' => 'jagraamu bànd',
    '📋' => 'klasëru kepp-kayit',
    '📌' => 'pasarel',
    '📍' => 'bitoŋ bu roŋ',
    '📎' => 'trombon',
    '🖇' => 'trombonu këyit yuñ lëkkale',
    '📏' => 'reegal bu jub',
    '📐' => 'reegal bu am jëmmu triyàngal',
    '✂' => 'siso',
    '🗃' => 'boyetu kàrtu taxañ',
    '🗄' => 'tirwaaru taxañ',
    '🗑' => 'pañe mbalit',
    '🔒' => 'tëj nañu ko',
    '🔓' => 'tijji nañu ko',
    '🔏' => 'tëj nañu ko ak bik',
    '🔐' => 'tëj nañu ko ak caabi',
    '🔑' => 'caabi',
    '🗝' => 'caabi ju yàgg',
    '🔨' => 'marto',
    '🪓' => 'séemeñ',
    '⛏' => 'pik',
    '⚒' => 'marto ak pik',
    '🛠' => 'marto ak kle',
    '🗡' => 'paaka',
    '⚔' => 'bu am kruwaa eppee',
    '💣' => 'bomb',
    '🏹' => 'ark bu ànd ak fett',
    '🛡' => 'kiiraay',
    '🔧' => 'kle',
    '🔩' => 'buloŋ ak wiisam',
    '⚙' => 'piñoŋ',
    '🗜' => 'tënaaj',
    '⚖' => 'balaasu peesekaay',
    '🔗' => 'lëkkalekaay',
    '⛓' => 'ceen',
    '🪝' => 'lonka',
    '⚗' => 'alembik',
    '🔬' => 'mikroskop',
    '🔭' => 'teleskop',
    '📡' => 'àntenu satelit',
    '💉' => 'pikiir',
    '💊' => 'garab',
    '🚪' => 'buntu',
    '🛗' => 'asansëër',
    '🪞' => 'seetu',
    '🪟' => 'palanteer',
    '🛏' => 'lal',
    '🛋' => 'kanape and làmp',
    '🚽' => 'wanag',
    '🚿' => 'duus',
    '🛁' => 'beñuwaar',
    '🪒' => 'raasuwaar',
    '🧹' => 'bale',
    '🧺' => 'pañe',
    '🧼' => 'saabu',
    '🫧' => 'bax',
    '🪥' => 'borosada',
    '🛒' => 'puus-puusu bagaas',
    '🚬' => 'sigaret',
    '⚰' => 'keesu-néew',
    '⚱' => 'urnu dëj',
    '🗿' => 'moai',
    '🏧' => 'màndarga ATM',
    '🚮' => 'màndarga mbalit ci pot',
    '🚰' => 'ndox mu sell',
    '♿' => 'màndarga puus-puus',
    '🚹' => 'néegu góor ñi',
    '🚺' => 'néegu jigéen ñi',
    '🚻' => 'néegu noppalukaay',
    '🚼' => 'màndarga liir',
    '🚾' => 'tuurukaayu ndox',
    '🛂' => 'xool sa paaspoor',
    '🛃' => 'duwaan',
    '🛄' => 'laajte say bagaas',
    '🛅' => 'bagaas yiñ bàyyi',
    '⚠' => 'moytul',
    '🚸' => 'xale yi dañu fiy jaar',
    '⛔' => 'bu fi kenn dugg',
    '🚫' => 'dañu koy tere',
    '🚳' => 'bu fi kenn dawal welo',
    '🚭' => 'bu fi kenn tox',
    '🚯' => 'bu fi kenn sànni mbalit',
    '🚱' => 'ndox mii sellul',
    '🚷' => 'bu kenn dox jaar fii',
    '📵' => 'dañu fi tere portaabal',
    '🔞' => 'ku amul 18 at bokkul',
    '☢' => 'radioaktif',
    '☣' => 'risku-bio',
    '⬆' => 'fettu kaw',
    '↗' => 'fettu ndijooru kaw',
    '➡' => 'fettu ndijoor',
    '↘' => 'suuf-ndijoor fett',
    '⬇' => 'fettu suuf',
    '↙' => 'suuf-càmmoñ fett',
    '⬅' => 'fettu càmmoñ',
    '↖' => 'fettu càmmoñu-kaw',
    '↕' => 'fettu suufu-kaw',
    '↔' => 'fettu càmmoñu-ndijoor',
    '↩' => 'fettu ndijoor lemoo càmmoñ',
    '↪' => 'fettu càmmoñ lemoo ndijoor',
    '⤴' => 'fettu ndijoor lemoo kaw',
    '⤵' => 'fettu ndijoor lemoo suuf',
    '🔃' => 'fett yu ci yoonu montar',
    '🔄' => 'bitoŋu fett yu juuyoo te safaan-montar',
    '🔙' => 'fettu DELLU',
    '🔚' => 'fettu JEEX',
    '🔛' => 'fettu ci TAAL',
    '🔜' => 'fettu CI KANAM',
    '🔝' => 'fettu COLLU',
    '🛐' => 'barabu jaamukaay',
    '⚛' => 'màndarga atom',
    '🕉' => 'om',
    '✡' => 'biddeew of Dawuda',
    '☸' => 'pëno dharma',
    '☯' => 'yin yang',
    '✝' => 'kruwaa lateŋ',
    '☦' => 'kruwaa ortodoks',
    '☪' => 'biddeew ak weer',
    '☮' => 'màndarga jàmm',
    '🕎' => 'menorah',
    '🔯' => 'biddéewu 6 car',
    '♈' => 'Kuy',
    '♉' => 'Nag wu góor',
    '♊' => 'Jemóo',
    '♋' => 'Kàŋseer',
    '♌' => 'Gaynde',
    '♍' => 'Wiyerse',
    '♎' => 'Balaas',
    '♏' => 'Eskorpiyoŋ',
    '♐' => 'Sajiteer',
    '♑' => 'Kaprikorn',
    '♒' => 'Wersóo',
    '♓' => 'Jën yi',
    '⛎' => 'U buñ baare',
    '🔀' => 'bitoŋu jaxase way yi',
    '🔁' => 'bitoŋu baamtu',
    '🔂' => 'bitoŋu benn baamtu',
    '▶' => 'bitoŋu doxal',
    '⏩' => 'bitoŋu jëmale kanam gaaw',
    '⏭' => 'bitoŋu way wi topp',
    '⏯' => 'bitoŋu doxal wala taxawal',
    '◀' => 'bitoŋu delloo ginaaw',
    '⏪' => 'bitoŋu delloo ginaaw gaaw',
    '⏮' => 'bitoŋu way wi mujj',
    '🔼' => 'bitoŋu yéegal',
    '⏫' => 'bitoŋu gaawal yéegal',
    '🔽' => 'bitoŋu wàcce',
    '⏬' => 'bitoŋu gaawal wàcce',
    '⏸' => 'bitoŋu taxawal',
    '⏹' => 'bitoŋu dakkal',
    '⏺' => 'bitoŋu enregistare',
    '⏏' => 'bitoŋu génne',
    '🎦' => 'sinemaa',
    '🔅' => 'bitoŋu lëndëm',
    '🔆' => 'bitoŋu leeraay',
    '📶' => 'baari reso',
    '📳' => 'anamu wiibrër',
    '📴' => 'portaabal buñ fay',
    '♀' => 'màndarga jigéen',
    '♂' => 'màndarga góor',
    '✖' => 'x fuul bu rëy',
    '➕' => 'màndargay yokk bu rëy',
    '➖' => 'màndargay wàññi bu rëy',
    '➗' => 'màndargay xaajale bu rëy',
    '‼' => 'ñaarte màndarga esklamaasiyoŋ',
    '⁉' => 'màndarga esklamaasiyoŋ laajte',
    '❓' => 'tombu laajte',
    '❔' => 'tombu laajte bu weex',
    '❕' => 'tombu esklamaasiyoŋ bu weex',
    '❗' => 'tombu esklamaasiyoŋ',
    '〰' => 'tiire ondule',
    '💱' => 'wecci koppar',
    '💲' => 'màndarga dolaar bu dijj',
    '⚕' => 'màndarga medsin',
    '♻' => 'màndarga defaraat',
    '⚜' => 'flëru-lis',
    '🔱' => 'xeeju ñatti bopp',
    '📛' => 'badsu tur',
    '🔰' => 'màndarga sapone, soog a door',
    '⭕' => 'sarkal bu rëy te diis',
    '✅' => 'màndarga nangu bu weex te rëy',
    '☑' => 'kaasu boyet ak xàmme',
    '✔' => 'màndarga nangu bu rëy',
    '❌' => 'kruwaa',
    '❎' => 'bitoŋ kruwaa',
    '➰' => 'buum gu lemu benn yoon',
    '➿' => 'buum gu lemu ñaari yoon',
    '〽' => 'màndarga beneen wàll',
    '✳' => 'asterisk bu 8 car',
    '✴' => 'biddeewu 8 cat',
    '❇' => 'eklaa',
    '™' => 'turu liggéey',
    '🔠' => 'mbind lateŋ, majiskil',
    '🔡' => 'mbind lateŋ, miniskil',
    '🔢' => 'mbindu nimero',
    '🔣' => 'màndargay mbind',
    '🔤' => 'arafi mbindu lateŋ',
    '🅰' => 'bitoŋu A (xeetu deret)',
    '🆎' => 'bitoŋu AB (xeetu deret)',
    '🅱' => 'bitoŋu B (xeetu deret)',
    '🆑' => 'bitoŋu CL',
    '🆒' => 'bitoŋu KUUL',
    '🆓' => 'bitoŋu AMUL FAY',
    'ℹ' => 'info (xibaar)',
    '🆔' => 'bitoŋu ID (dàntite)',
    'Ⓜ' => 'M bu wërale serkal',
    '🆕' => 'bitoŋu BEES',
    '🆖' => 'bitoŋu NG',
    '🅾' => 'bitoŋ O (xeetu deret)',
    '🆗' => 'bitoŋu waaw-kay',
    '🅿' => 'bitoŋu P',
    '🆘' => 'bitoŋu WALLU',
    '🆙' => 'bitoŋu YEEGAL',
    '🆚' => 'bitoŋu daje',
    '🈁' => 'bitoŋu "fii" bu sapoŋ',
    '🈂' => 'bitoŋu "dafa am juuti" bu sapoŋ',
    '🈷' => 'bitoŋu sapone "lu ñuy fay weer"',
    '🈶' => 'bitoŋu sapone "dafa am juuti"',
    '🈯' => 'bitoŋu "amna boroom" bu sapoŋ',
    '🉐' => 'bitoŋu "waxaale" bu sapoŋ',
    '🈹' => 'bitoŋu "wàññi" bu sapoŋ',
    '🈚' => 'bitoŋu "amul juuti" bu sapoŋ',
    '🈲' => 'bitoŋu "dañu koy tere" bu sapoŋ',
    '🉑' => 'bitoŋu "terewu ñu ko" bu sapoŋ',
    '🈸' => 'bitoŋu "jëfekaay" bu sapoŋ',
    '🈴' => 'bitoŋu "jàll klaas" bu sapoŋ',
    '🈳' => 'bitoŋu "wakaas" bu sapoŋ',
    '㊗' => 'bitoŋu "ndokkale" bu sapoŋ',
    '㊙' => 'bitoŋu "sekkere" bu sapoŋ',
    '🈺' => 'bitoŋ "ku bëgg liggéey" bu sapoŋ',
    '🈵' => 'bitoŋu "amul wakaas" bu sapoŋ',
    '🔴' => 'serkal xonk',
    '🔵' => 'serkal baxa',
    '⚫' => 'serkal ñuul',
    '⚪' => 'serkal bu weex',
    '⬛' => 'kaare bu rëy te ñuul',
    '⬜' => 'kaare bu rëy te weex',
    '◼' => 'kaare bu yam te ñuul',
    '◻' => 'kaare bu yam te weex',
    '◾' => 'kaare yam-ndaw te ñuul',
    '◽' => 'kaare yam-ndaw te weex',
    '▪' => 'kaare bu ndaw te ñuul',
    '▫' => 'kaare bu ndaw te weex',
    '🔶' => 'karo rëy oraas',
    '🔷' => 'karo rëy baxa',
    '🔸' => 'karo ndaw oraas',
    '🔹' => 'karo ndaw baxa',
    '🔺' => 'xonk, tri-àngal, buñ defal tomb',
    '🔻' => 'tri-àngal xonk muuse jëm suuf',
    '💠' => 'karo bu ànd ak tomb',
    '🔘' => 'bitoŋu rajo',
    '🔳' => 'bitoŋu kaare bu weex',
    '🔲' => 'bitoŋu kaare ñuul',
    '🏁' => 'raaya bu am karo damiye',
    '🚩' => 'raaya am jëmmu tri-yàngal',
    '🎌' => 'raaya yu féewaloo',
    '🏴' => 'raaya bu ñuul',
    '🏳' => 'raaya bu weex',
];
